@@ -31,6 +31,8 @@ public final class Color {
 
 	public static final Color WHITE = new Color(1, 1, 1, 1);
 
+	public static final Color GRAY = new Color(0.5, 0.5, 0.5, 1);
+
 
 	public final double r;
 
@@ -43,10 +45,10 @@ public final class Color {
 
 	public Color(double red, double green, double blue, double alpha) {
 		super();
-		r = Math.max(0, Math.min(1, red));
-		g = Math.max(0, Math.min(1, green));
-		b = Math.max(0, Math.min(1, blue));
-		a = Math.max(0, Math.min(1, alpha));
+		r = Double.isNaN(red)   ? 0 : Math.max(0, Math.min(1, red));
+		g = Double.isNaN(green) ? 0 : Math.max(0, Math.min(1, green));
+		b = Double.isNaN(blue)  ? 0 : Math.max(0, Math.min(1, blue));
+		a = Double.isNaN(alpha) ? 1 : Math.max(0, Math.min(1, alpha));
 	}
 
 	public Color(double red, double green, double blue) {
