@@ -27,7 +27,7 @@ public interface IShaderProgram {
 
 	String getName();
 
-	int getProgram();
+	void useProgram(Runnable r);
 
 	int getUniformLocation(String uniformName);
 
