@@ -37,15 +37,17 @@ public @interface Effect {
 	String category() default "";
 
 
-	final String AUDIO				= "ch.kuramo.javie.api.effectCategory.audio";
-	final String KEYING				= "ch.kuramo.javie.api.effectCategory.keying";
-	final String STYLIZE			= "ch.kuramo.javie.api.effectCategory.stylize";
-	final String DISTORT			= "ch.kuramo.javie.api.effectCategory.distort";
-	final String TRANSITION			= "ch.kuramo.javie.api.effectCategory.transition";
-	final String NOISE_AND_GRAIN	= "ch.kuramo.javie.api.effectCategory.noiseGrain";
-	final String BLUR_AND_SHARPEN	= "ch.kuramo.javie.api.effectCategory.blurAndSharpen";
-	final String UTILITY			= "ch.kuramo.javie.api.effectCategory.utility";
-	final String TIME				= "ch.kuramo.javie.api.effectCategory.time";
-	final String COLOR_CORRECTION	= "ch.kuramo.javie.api.effectCategory.colorCorrection";
+	final String EXPRESSION_CONTROLS	= "ch.kuramo.javie.api.effectCategory.expressionControls";
+	final String AUDIO					= "ch.kuramo.javie.api.effectCategory.audio";
+	final String KEYING					= "ch.kuramo.javie.api.effectCategory.keying";
+	final String STYLIZE				= "ch.kuramo.javie.api.effectCategory.stylize";
+	final String DISTORT				= "ch.kuramo.javie.api.effectCategory.distort";
+	final String TRANSITION				= "ch.kuramo.javie.api.effectCategory.transition";
+	final String NOISE_AND_GRAIN		= "ch.kuramo.javie.api.effectCategory.noiseGrain";
+	final String BLUR_AND_SHARPEN		= "ch.kuramo.javie.api.effectCategory.blurAndSharpen";
+	final String UTILITY				= "ch.kuramo.javie.api.effectCategory.utility";
+	final String TIME					= "ch.kuramo.javie.api.effectCategory.time";
+	final String COLOR_CORRECTION		= "ch.kuramo.javie.api.effectCategory.colorCorrection";
+	final String GENERATE				= "ch.kuramo.javie.api.effectCategory.generate";
 
 }
