@@ -23,8 +23,18 @@
 
 package ch.kuramo.javie.api.services;
 
+import javax.media.opengl.GL;
+import javax.media.opengl.glu.GLU;
+
+import ch.kuramo.javie.api.AudioMode;
+import ch.kuramo.javie.api.ColorMode;
+import ch.kuramo.javie.api.IAnimatableLayerReference;
 import ch.kuramo.javie.api.IAnimatableValue;
+import ch.kuramo.javie.api.IAudioBuffer;
+import ch.kuramo.javie.api.IVideoBuffer;
+import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Time;
+import ch.kuramo.javie.api.VideoBounds;
 
 public interface IEffectContext {
 
@@ -34,4 +44,29 @@ public interface IEffectContext {
 
 	<V> V value(IAnimatableValue<V> avalue);
 
+
+	GL getGL();
+
+	GLU getGLU();
+
+	Resolution getVideoResolution();
+
+	ColorMode getColorMode();
+
+	IVideoBuffer createVideoBuffer(VideoBounds bounds);
+
+
+	AudioMode getAudioMode();
+
+	int getAudioFrameCount();
+
+	void setAudioFrameCount(int count);
+
+	IAudioBuffer createAudioBuffer();
+
+
+	IVideoBuffer getLayerVideoFrame(IAnimatableLayerReference layerRef);
+
+	IAudioBuffer getLayerAudioChunk(IAnimatableLayerReference layerRef);
+
 }
