@@ -23,27 +23,11 @@
 
 package ch.kuramo.javie.api.services;
 
-import javax.media.opengl.GL;
-import javax.media.opengl.glu.GLU;
-
-import ch.kuramo.javie.api.ColorMode;
 import ch.kuramo.javie.api.IVideoBuffer;
-import ch.kuramo.javie.api.RenderResolution;
 import ch.kuramo.javie.api.VideoBounds;
 
 public interface IVideoEffectContext extends IEffectContext {
 
-	GL getGL();
-
-	GLU getGLU();
-
-	RenderResolution getRenderResolution();
-
-	ColorMode getColorMode();
-
-
-	IVideoBuffer createVideoBuffer(VideoBounds bounds);
-
 	VideoBounds getPreviousBounds();
 
 	IVideoBuffer doPreviousEffect();
