@@ -164,15 +164,15 @@ public class Activator extends AbstractUIPlugin {
 	public static final String IMG_SWITCH_VIDEO = "IMG_SWITCH_VIDEO";
 	public static final String IMG_SWITCH_AUDIO = "IMG_SWITCH_AUDIO";
 
-	public static final String IMG_SWITCH_UNSHY			= "IMG_SWITCH_UNSHY";
-	public static final String IMG_SWITCH_SHY			= "IMG_SWITCH_SHY";
-	public static final String IMG_SWITCH_EFFECT		= "IMG_SWITCH_EFFECT";
-	public static final String IMG_SWITCH_CTCR			= "IMG_SWITCH_CTCR";
-	public static final String IMG_SWITCH_FBLEND		= "IMG_SWITCH_FBLEND";
-	public static final String IMG_SWITCH_MBLUR			= "IMG_SWITCH_MBLUR";
-	public static final String IMG_SWITCH_3D			= "IMG_SWITCH_3D";
-	public static final String IMG_SWITCH_LINK			= "IMG_SWITCH_LINK";
-	public static final String IMG_SWITCH_TRANSLATE2D	= "IMG_SWITCH_TRANSLATE2D";
+	public static final String IMG_SWITCH_UNSHY				= "IMG_SWITCH_UNSHY";
+	public static final String IMG_SWITCH_SHY				= "IMG_SWITCH_SHY";
+	public static final String IMG_SWITCH_EFFECT			= "IMG_SWITCH_EFFECT";
+	public static final String IMG_SWITCH_CTCR				= "IMG_SWITCH_CTCR";
+	public static final String IMG_SWITCH_FBLEND			= "IMG_SWITCH_FBLEND";
+	public static final String IMG_SWITCH_MBLUR				= "IMG_SWITCH_MBLUR";
+	public static final String IMG_SWITCH_3D				= "IMG_SWITCH_3D";
+	public static final String IMG_SWITCH_LINK				= "IMG_SWITCH_LINK";
+	public static final String IMG_SWITCH_TINY_2D_MANIP		= "IMG_SWITCH_TINY_2D_MANIP";
 
 	public static final String IMG_KF_HOLD					= "IMG_KF_HOLD";
 	public static final String IMG_KF_HOLD_SELECT			= "IMG_KF_HOLD_SELECT";
@@ -181,6 +181,11 @@ public class Activator extends AbstractUIPlugin {
 	public static final String IMG_KF_CATMULL_ROM			= "IMG_KF_CATMULL_ROM";
 	public static final String IMG_KF_CATMULL_ROM_SELECT	= "IMG_KF_CATMULL_ROM_SELECT";
 
+	public static final String IMG_KFNAV_PREV				= "IMG_KFNAV_PREV";
+	public static final String IMG_KFNAV_PREV_DISABLED		= "IMG_KFNAV_PREV_DISABLED";
+	public static final String IMG_KFNAV_NEXT				= "IMG_KFNAV_NEXT";
+	public static final String IMG_KFNAV_NEXT_DISABLED		= "IMG_KFNAV_NEXT_DISABLED";
+
 	public static final String IMG_STOPWATCH_NO_KF	= "IMG_STOPWATCH_NO_KF";
 	public static final String IMG_STOPWATCH_HAS_KF	= "IMG_STOPWATCH_HAS_KF";
 
@@ -231,7 +236,7 @@ public class Activator extends AbstractUIPlugin {
 		registerImage(reg, IMG_SWITCH_EFFECT, "switch_effect.png");
 		registerImage(reg, IMG_SWITCH_3D, "switch_3d.png");
 		registerImage(reg, IMG_SWITCH_LINK, "switch_link.png");
-		registerImage(reg, IMG_SWITCH_TRANSLATE2D, "switch_translate2d.png");
+		registerImage(reg, IMG_SWITCH_TINY_2D_MANIP, "switch_tiny_2d_manip.png");
 
 		registerImage(reg, IMG_KF_HOLD,        "kf_hold.png");
 		registerImage(reg, IMG_KF_HOLD_SELECT, "kf_hold_select.png");
@@ -240,6 +245,11 @@ public class Activator extends AbstractUIPlugin {
 		registerImage(reg, IMG_KF_CATMULL_ROM,        "kf_catmull_rom.png");
 		registerImage(reg, IMG_KF_CATMULL_ROM_SELECT, "kf_catmull_rom_select.png");
 
+		registerImage(reg, IMG_KFNAV_PREV,          "kfnav_prev.png");
+		registerImage(reg, IMG_KFNAV_PREV_DISABLED, "kfnav_prev_disabled.png");
+		registerImage(reg, IMG_KFNAV_NEXT,          "kfnav_next.png");
+		registerImage(reg, IMG_KFNAV_NEXT_DISABLED, "kfnav_next_disabled.png");
+
 		registerImage(reg, IMG_STOPWATCH_NO_KF,  "stopwatch_no_kf.png");
 		registerImage(reg, IMG_STOPWATCH_HAS_KF, "stopwatch_has_kf.png");
 	}
