@@ -35,6 +35,8 @@ public final class CommandIds {
 
 	public static final String NEW_FILE_ITEMS = "ch.kuramo.javie.app.commands.newFileItems";
 
+	public static final String NEW_IMAGE_SEQUENCE = "ch.kuramo.javie.app.commands.newImageSequence";
+
 	public static final String NEW_FOLDER = "ch.kuramo.javie.app.commands.newFolder";
 
 	public static final String OPEN_PROJECT = "ch.kuramo.javie.app.commands.openProject";
@@ -58,6 +60,8 @@ public final class CommandIds {
 
 	public static final String REDO = IWorkbenchCommandConstants.EDIT_REDO;
 
+	public static final String DUPLICATE = "ch.kuramo.javie.app.commands.duplicate";
+
 
 	public static final String NEW_CAMERA_LAYER = "ch.kuramo.javie.app.commands.newCameraLayer";
 
@@ -65,6 +69,8 @@ public final class CommandIds {
 
 	public static final String NEW_TEXT_LAYER = "ch.kuramo.javie.app.commands.newTextLayer";
 
+	public static final String SPLIT_LAYERS = "ch.kuramo.javie.app.commands.splitLayers";
+
 
 	public static final String SHOW_PROJECT_VIEW = "ch.kuramo.javie.app.commands.showProjectView";
 
