@@ -38,8 +38,11 @@ import ch.kuramo.javie.app.widgets.WSWin32;
 import ch.kuramo.javie.core.CompositionItem;
 import ch.kuramo.javie.core.FileItem;
 import ch.kuramo.javie.core.Folder;
+import ch.kuramo.javie.core.ImageSequenceItem;
 import ch.kuramo.javie.core.Interpolation;
 import ch.kuramo.javie.core.Item;
+import ch.kuramo.javie.core.MediaInputPlaceholder;
+import ch.kuramo.javie.core.MediaItem;
 import ch.kuramo.javie.core.SolidColorItem;
 
 public class ImageUtil {
@@ -122,6 +125,16 @@ public class ImageUtil {
 			return PlatformUI.getWorkbench().getSharedImages().getImage(ISharedImages.IMG_OBJ_FOLDER);
 		}
 
+		if ((item instanceof MediaItem) && (((MediaItem) item).getMediaInput() instanceof MediaInputPlaceholder)) {
+			// TODO プレースホルダアイテムのアイコン
+			return PlatformUI.getWorkbench().getSharedImages().getImage(ISharedImages.IMG_OBJS_WARN_TSK);
+		}
+
+		if (item instanceof ImageSequenceItem) {
+			// TODO イメージシーケンス用のアイコン
+			return PlatformUI.getWorkbench().getSharedImages().getImage(ISharedImages.IMG_OBJ_FILE);
+		}
+
 		if (item instanceof FileItem) {
 			return getFileItemIcon((FileItem) item);
 		}
