@@ -39,7 +39,7 @@ import org.eclipse.swt.widgets.Scale;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import ch.kuramo.javie.api.RenderResolution;
+import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.app.Activator;
 import ch.kuramo.javie.app.IntervalTask;
@@ -358,6 +358,14 @@ public class MediaPlayer extends Composite implements PlayerThreadListener, Play
 
 		_timeKeeper.pause();
 
+		// TimeKeeperの時刻が最終フレームの時刻を超えていることがある。その場合は最終フレームの時刻に設定しなおす。
+		if (_duration != null) {
+			Time maxTime = _duration.subtract(_frameDuration);
+			if (_timeKeeper.getTime().after(maxTime)) {
+				_timeKeeper.setTime(maxTime);
+			}
+		}
+
 		// TimeKeeperをpauseした時刻よりも過去のフレームで表示が停止していることがあるので、
 		// pauseした時刻のフレームを確実に表示するために一度forceRenderする。
 		if (_videoCanvas != null) {
@@ -379,11 +387,11 @@ public class MediaPlayer extends Composite implements PlayerThreadListener, Play
 		return (_audioThread != null);
 	}
 
-	public RenderResolution getVideoResolution() {
+	public Resolution getVideoResolution() {
 		return (_videoCanvas != null) ? _videoCanvas.getResolution() : null;
 	}
 
-	public void setVideoResolution(RenderResolution resolution) {
+	public void setVideoResolution(Resolution resolution) {
 		if (_videoCanvas != null) {
 			_videoCanvas.setResolution(resolution);
 		}
