@@ -58,9 +58,10 @@ import org.eclipse.swt.widgets.ScrollBar;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import ch.kuramo.javie.api.AudioMode;
 import ch.kuramo.javie.api.Color;
 import ch.kuramo.javie.api.ColorMode;
-import ch.kuramo.javie.api.RenderResolution;
+import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.VideoBounds;
@@ -69,14 +70,16 @@ import ch.kuramo.javie.app.player.GLCanvasFactory.GLCanvasRecord;
 import ch.kuramo.javie.core.Composition;
 import ch.kuramo.javie.core.CompositionItem;
 import ch.kuramo.javie.core.FrameDuration;
+import ch.kuramo.javie.core.ImageSequenceItem;
 import ch.kuramo.javie.core.MediaInput;
+import ch.kuramo.javie.core.MediaInputPlaceholder;
 import ch.kuramo.javie.core.MediaItem;
 import ch.kuramo.javie.core.SolidColorItem;
 import ch.kuramo.javie.core.TimeCode;
 import ch.kuramo.javie.core.VideoBuffer;
 import ch.kuramo.javie.core.misc.AtiIntelLock;
 import ch.kuramo.javie.core.services.GLGlobal;
-import ch.kuramo.javie.core.services.VideoRenderContext;
+import ch.kuramo.javie.core.services.RenderContext;
 
 import com.google.inject.Inject;
 import com.sun.opengl.util.gl2.GLUT;
@@ -112,7 +115,7 @@ public class VideoCanvas extends Thread implements GLEventListener {
 
 	private volatile Time _frameDuration;
 
-	private volatile RenderResolution _resolution = RenderResolution.FULL;
+	private volatile Resolution _resolution = Resolution.FULL;
 
 	private double _zoom;
 
@@ -149,7 +152,7 @@ public class VideoCanvas extends Thread implements GLEventListener {
 	private final MovingAverage _frameDurationAvg = new MovingAverage(30);
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private GLGlobal _glGlobal;
@@ -286,11 +289,11 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		_frameDuration = frameDuration;
 	}
 
-	public RenderResolution getResolution() {
+	public Resolution getResolution() {
 		return _resolution;
 	}
 
-	public void setResolution(RenderResolution resolution) {
+	public void setResolution(Resolution resolution) {
 		if ((resolution != null && !resolution.equals(_resolution))
 				|| (resolution == null && _resolution != null)) {
 
@@ -510,6 +513,12 @@ public class VideoCanvas extends Thread implements GLEventListener {
 			info.add(String.format("Solid Color: %d x %d, #%02x%02x%02x", bounds.width, bounds.height,
 					(int)(color.r*255), (int)(color.g*255), (int)(color.b*255)));
 
+		} else if (_mediaItem.getMediaInput() instanceof MediaInputPlaceholder) {
+			info.add(String.format("Placeholder: %d x %d", bounds.width, bounds.height));
+
+		} else if (_mediaItem instanceof ImageSequenceItem) {
+			info.add(String.format("Image Sequence: %d x %d", bounds.width, bounds.height));
+
 		} else if (_mediaInput.getVideoFrameDuration() != null) {
 			info.add(String.format("Video: %d x %d", bounds.width, bounds.height));
 
@@ -559,28 +568,33 @@ public class VideoCanvas extends Thread implements GLEventListener {
 	}
 
 	public void run() {
-		_vrContext.activate();
+		AudioMode audioMode = AudioMode.STEREO_48KHZ_INT16;
+
+		_context.activate();
 		try {
 			// TODO DebugGLの使用をやめる。でも当分はこのままにしておく。
+			_context.getGL(); // これをしておかないとRenderContext内でOpenGL関連の初期化が行われず、次のGLContext.getCurrent()がnullになる。
 			GLContext glContext = GLContext.getCurrent();
 			glContext.setGL(new DebugGL2(glContext.getGL().getGL2()));
 
-			GL2 gl = _vrContext.getGL().getGL2();
+			GL2 gl = _context.getGL().getGL2();
 
 			Time duration = _mediaInput.getDuration();
 			if (duration == null) {
-				RenderResolution resolution = _resolution;
+				Resolution resolution = _resolution;
 
-				_vrContext.reset();
-				_vrContext.setRenderResolution(resolution);
-				_vrContext.setColorMode(ColorMode.RGBA8);
-				_vrContext.setFrameDuration(TIME0);
+				_context.reset();
+				_context.setVideoResolution(resolution);
+				_context.setColorMode(ColorMode.RGBA8);
+				_context.setVideoFrameDuration(TIME0);
+				_context.setAudioMode(audioMode);
+				_context.setAudioAnimationRate(audioMode.sampleRate/100);
 
 				VideoBuffer vb = null;
 				try {
 					_atiIntelLock.lock();
 					try {
-						vb = _mediaInput.getVideoFrameImage(TIME0);
+						vb = _mediaInput.getVideoFrame(TIME0);
 					} finally {
 						_atiIntelLock.unlock();
 					}
@@ -620,7 +634,7 @@ public class VideoCanvas extends Thread implements GLEventListener {
 			Time[] timeAndBase;
 			Time prevBase = _timeKeeper.getTimeAndBase()[1];
 			Time delay = TIME0;
-			RenderResolution prevResolution = null;
+			Resolution prevResolution = null;
 
 			while ((timeAndBase = waitForRendering()) != null) {
 				boolean forceRender = !_playing && _forceRender;
@@ -651,7 +665,7 @@ public class VideoCanvas extends Thread implements GLEventListener {
 				Time frameTime = Time.fromFrameNumber(frameNumber, frameDuration);
 
 				boolean fireEndOfDuration = false;
-				if (!frameTime.before(duration)) {
+				if (!frameTime.before(duration) && !forceRender) {
 					Time lastFramePlusOne = duration.add(new Time(frameDuration.timeValue-1, frameDuration.timeScale));
 					frameNumber = Math.max(lastFramePlusOne.toFrameNumber(frameDuration)-1, 0);
 					frameTime = Time.fromFrameNumber(frameNumber, frameDuration);
@@ -665,35 +679,36 @@ public class VideoCanvas extends Thread implements GLEventListener {
 					_timeKeeper.setTime(frameTime);
 				}
 
-				RenderResolution resolution = _resolution;
+				Resolution resolution = _resolution;
 				if (resolution != null) {
 					prevResolution = null;
 				} else if (forceRender) {
-					resolution = RenderResolution.FULL;
+					resolution = Resolution.FULL;
 					prevResolution = null;
 				} else {
 					resolution = autoResolution(prevResolution, frameDuration.toSecond()*1.5);
 					prevResolution = resolution;
 				}
 
-				_vrContext.reset();
-				_vrContext.setRenderResolution(resolution);
-				_vrContext.setColorMode(ColorMode.RGBA8);
-				_vrContext.setFrameDuration(frameDuration);
+				_context.reset();
+				_context.setVideoResolution(resolution);
+				_context.setColorMode(ColorMode.RGBA8);
+				_context.setVideoFrameDuration(frameDuration);
+				_context.setAudioMode(audioMode);
+				_context.setAudioAnimationRate(audioMode.sampleRate/100);
 
 				VideoBuffer vb = null;
 
 				if (_mediaItem instanceof CompositionItem) {
-					// TODO _mediaInput.getDuration() など、他の _mediaInput にアクセスしている箇所も厳密にはロックする必要がある。
 					PlayerLock.readLock().lock();
 					try {
 						// TODO prepareExpressionはプロジェクトに構造的な変更があった場合のみ行えばよい。
 						Composition comp = ((CompositionItem) _mediaItem).getComposition();
-						comp.prepareExpression(_vrContext.createInitialExpressionScope(comp));
+						comp.prepareExpression(_context.createInitialExpressionScope(comp));
 
 						_atiIntelLock.lock();
 						try {
-							vb = _mediaInput.getVideoFrameImage(frameTime);
+							vb = _mediaInput.getVideoFrame(frameTime);
 						} finally {
 							_atiIntelLock.unlock();
 						}
@@ -709,7 +724,7 @@ public class VideoCanvas extends Thread implements GLEventListener {
 					try {
 						_atiIntelLock.lock();
 						try {
-							vb = _mediaInput.getVideoFrameImage(frameTime);
+							vb = _mediaInput.getVideoFrame(frameTime);
 						} finally {
 							_atiIntelLock.unlock();
 						}
@@ -780,7 +795,7 @@ public class VideoCanvas extends Thread implements GLEventListener {
 			}
 			disposeOldVideoBuffers();
 
-			_vrContext.deactivate();
+			_context.deactivate();
 		}
 	}
 
@@ -839,14 +854,14 @@ public class VideoCanvas extends Thread implements GLEventListener {
 				GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, 0, 0);
 	}
 
-	private void setTexParametersForDisplay(VideoBuffer vb, RenderResolution resolution, GL2 gl) {
+	private void setTexParametersForDisplay(VideoBuffer vb, Resolution resolution, GL2 gl) {
 		gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, vb.getTexture());
 
 		// フル解像度のときは、拡大したときにテクスチャの補間が効かないようにする。
 		// フル解像度でないときは補間を有効にするが、補間によってエッジ部分が
 		// 黒とブレンドされないようにラッピングモードを GL_CLAMP_TO_EDGE に設定する。
 
-		if (RenderResolution.FULL.equals(resolution)) {
+		if (Resolution.FULL.equals(resolution)) {
 			// GL_TEXTURE_MAG_FILTER だけ設定すればいいはずだが、
 			// ATIではなぜかダメなようなので MIN/MAG 両方を設定している。
 			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_MIN_FILTER, GL2.GL_NEAREST);
@@ -862,24 +877,24 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, 0);
 	}
 
-	private RenderResolution autoResolution(RenderResolution prevResolution, double avgThreshold) {
+	private Resolution autoResolution(Resolution prevResolution, double avgThreshold) {
 		if (prevResolution == null) {
-			return RenderResolution.FULL;
+			return Resolution.FULL;
 
 		// avgThreshold 以下のときは現在の解像度を維持する。
 		// MovingAverage.getAverage() は要素数が少ないとNaNを返すので不等号の向きに注意。
 		} else if (_delayAverage.getAverage() > avgThreshold) {
 
-			if (prevResolution.equals(RenderResolution.FULL)) {
+			if (prevResolution.equals(Resolution.FULL)) {
 				_delayAverage.reset();
-				return RenderResolution.HALF;
+				return Resolution.HALF;
 
-			} else if (prevResolution.equals(RenderResolution.HALF)) {
+			} else if (prevResolution.equals(Resolution.HALF)) {
 				_delayAverage.reset();
-				return RenderResolution.ONETHIRD;
+				return Resolution.ONETHIRD;
 
 			} else {
-				return RenderResolution.QUARTER;
+				return Resolution.QUARTER;
 			}
 
 		} else {
