@@ -624,9 +624,12 @@ public class ProjectManager implements IOperationHistoryListener {
 		PrintWriter pw = new PrintWriter(new BufferedWriter(
 				new OutputStreamWriter(new FileOutputStream(file), "UTF-8")));
 		try {
-			pw.println("JVP-Version: 0.9");
-			pw.println();
-			pw.println(body);
+			// JSONICの prettyPrint を有効にしたとき、
+			// 改行コードがプラットフォーム固有のものではなくLFのみになるようなので、
+			// 以下では println ではなく print('\n') としている。
+			pw.print("JVP-Version: 0.9\n\n");
+			pw.print(body);
+			pw.print('\n');
 		} finally {
 			pw.close();
 		}
