@@ -35,6 +35,7 @@ import org.eclipse.swt.graphics.Image;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.app.ImageUtil;
 import ch.kuramo.javie.core.FileItem;
+import ch.kuramo.javie.core.ImageSequenceItem;
 import ch.kuramo.javie.core.Item;
 import ch.kuramo.javie.core.MediaInput;
 import ch.kuramo.javie.core.MediaItem;
@@ -92,6 +93,10 @@ public class ItemLabelProvider extends LabelProvider implements ITableLabelProvi
 		}
 
 		File file = ((FileItem) item).getFile();
+		if (!file.isFile()) {
+			return null;
+		}
+
 		double length = file.length();
 
 		String[] suffixes = { "B", "KB", "MB", "GB" };
@@ -129,11 +134,18 @@ public class ItemLabelProvider extends LabelProvider implements ITableLabelProvi
 	}
 
 	private String getFilePath(Item item) {
-		if (!(item instanceof FileItem)) {
+		File file;
+
+		if (item instanceof ImageSequenceItem) {
+			file = ((ImageSequenceItem) item).getFile().getParentFile();
+
+		} else if (item instanceof FileItem) {
+			file = ((FileItem) item).getFile();
+
+		} else {
 			return null;
 		}
 
-		File file = ((FileItem) item).getFile();
 		try {
 			return file.getCanonicalPath();
 		} catch (IOException e) {
