@@ -47,7 +47,9 @@ import org.eclipse.jface.util.LocalSelectionTransfer;
 import org.eclipse.jface.viewers.CellEditor;
 import org.eclipse.jface.viewers.EditingSupport;
 import org.eclipse.jface.viewers.ISelection;
+import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.ITreeSelection;
+import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.jface.viewers.TreeColumnViewerLabelProvider;
 import org.eclipse.jface.viewers.TreePath;
 import org.eclipse.jface.viewers.TreeSelection;
@@ -141,6 +143,8 @@ import ch.kuramo.javie.app.actions.WaveOutputAction;
 import ch.kuramo.javie.app.player.MediaPlayer;
 import ch.kuramo.javie.app.player.PlayerLinkEvent;
 import ch.kuramo.javie.app.player.PlayerLinkListener;
+import ch.kuramo.javie.app.project.DuplicateEffectsOperation;
+import ch.kuramo.javie.app.project.DuplicateLayersOperation;
 import ch.kuramo.javie.app.project.MoveEffectsOperation;
 import ch.kuramo.javie.app.project.NewCameraLayerOperation;
 import ch.kuramo.javie.app.project.NewLayerFromItemOperation;
@@ -168,6 +172,7 @@ import ch.kuramo.javie.app.views.layercomp.LayerCompShyAction;
 import ch.kuramo.javie.app.views.layercomp.LayerElement;
 import ch.kuramo.javie.app.views.layercomp.TimelineManager;
 import ch.kuramo.javie.app.widgets.FontUtil;
+import ch.kuramo.javie.core.AnimatableLayerReference;
 import ch.kuramo.javie.core.AnimatableValue;
 import ch.kuramo.javie.core.CompositionItem;
 import ch.kuramo.javie.core.Effect;
@@ -243,12 +248,6 @@ public class LayerCompositionView extends ViewPart
 
 	private TreeViewerColumn _nameColumn;
 
-	private Action _newCameraLayerAction;
-
-	private Action _newNullLayerAction;
-
-	private Action _newTextLayerAction;
-
 	private Point _mouseDownPoint;
 
 	private volatile Time _time;
@@ -265,6 +264,8 @@ public class LayerCompositionView extends ViewPart
 
 	private TimelineManager _timelineManager;
 
+	private Action _splitLayersAction;
+
 	@Inject
 	private EffectRegistry _effectRegistry;
 
@@ -276,24 +277,6 @@ public class LayerCompositionView extends ViewPart
 		super();
 		InjectorHolder.getInjector().injectMembers(this);
 
-		_newCameraLayerAction = new Action("カメラ") {
-			public void run() {
-				handleNewCameraLayerAction();
-			}
-		};
-
-		_newNullLayerAction = new Action("ヌルオブジェクト") {
-			public void run() {
-				handleNewNullLayerAction();
-			}
-		};
-
-		_newTextLayerAction = new Action("テキスト") {
-			public void run() {
-				handleNewTextLayerAction();
-			}
-		};
-
 		_collector.activate();
 	}
 
@@ -323,9 +306,8 @@ public class LayerCompositionView extends ViewPart
 					if (_timelineManager != null) {
 						_timelineManager.update(_time, true);
 					}
-					if (_timeCodeComposite != null) {
-						_timeCodeComposite.redraw();
-					}
+					_timeCodeComposite.redraw();
+					_splitLayersAction.setEnabled(canSplitSelectedLayers());
 				}
 			}
 		};
@@ -966,15 +948,80 @@ public class LayerCompositionView extends ViewPart
 	}
 
 	private void setupGlobalActionsAndContextMenu() {
+		Action deleteAction = new Action("削除") {
+			{
+				setEnabled(false);
+				_treeViewer.addSelectionChangedListener(new ISelectionChangedListener() {
+					public void selectionChanged(SelectionChangedEvent event) {
+						setEnabled(canRmDupSelectedLayersOrEffects());
+					}
+				});
+			}
+			public void run() {
+				removeSelectedLayersOrEffects();
+			}
+		};
+
+		Action duplicateAction = new Action("複製") {
+			{
+				setEnabled(false);
+				_treeViewer.addSelectionChangedListener(new ISelectionChangedListener() {
+					public void selectionChanged(SelectionChangedEvent event) {
+						setEnabled(canRmDupSelectedLayersOrEffects());
+					}
+				});
+			}
+			public void run() {
+				duplicateSelectedLayersOrEffects();
+			}
+		};
+
+		Action newCameraLayerAction = new Action("カメラ") {
+			public void run() {
+				handleNewCameraLayerAction();
+			}
+		};
+
+		Action newNullLayerAction = new Action("ヌルオブジェクト") {
+			public void run() {
+				handleNewNullLayerAction();
+			}
+		};
+
+		Action newTextLayerAction = new Action("テキスト") {
+			public void run() {
+				handleNewTextLayerAction();
+			}
+		};
+
+		_splitLayersAction = new Action("レイヤーの分割") {
+			{
+				setEnabled(false);
+				_treeViewer.addSelectionChangedListener(new ISelectionChangedListener() {
+					public void selectionChanged(SelectionChangedEvent event) {
+						setEnabled(canSplitSelectedLayers());
+					}
+				});
+			}
+			public void run() {
+				splitSelectedLayers();
+			}
+		};
+
+
 		// GlobalActions
 
 		IViewSite site = getViewSite();
 		IActionBars actionBars = site.getActionBars();
 		IWorkbenchWindow window = site.getWorkbenchWindow();
 
-		actionBars.setGlobalActionHandler(CommandIds.NEW_CAMERA_LAYER, _newCameraLayerAction);
-		actionBars.setGlobalActionHandler(CommandIds.NEW_NULL_LAYER, _newNullLayerAction);
-		actionBars.setGlobalActionHandler(CommandIds.NEW_TEXT_LAYER, _newTextLayerAction);
+		actionBars.setGlobalActionHandler("delete", deleteAction);
+		actionBars.setGlobalActionHandler(CommandIds.DUPLICATE, duplicateAction);
+		actionBars.setGlobalActionHandler(CommandIds.SPLIT_LAYERS, _splitLayersAction);
+
+		actionBars.setGlobalActionHandler(CommandIds.NEW_CAMERA_LAYER, newCameraLayerAction);
+		actionBars.setGlobalActionHandler(CommandIds.NEW_NULL_LAYER, newNullLayerAction);
+		actionBars.setGlobalActionHandler(CommandIds.NEW_TEXT_LAYER, newTextLayerAction);
 		if (AVIOutputAction.isAvailable()) {
 			actionBars.setGlobalActionHandler(CommandIds.AVI_OUTPUT, new AVIOutputAction(this));
 		}
@@ -1007,12 +1054,15 @@ public class LayerCompositionView extends ViewPart
 		menuMgr.add(animeMenu);
 		menuMgr.add(new Separator());
 		menuMgr.add(new RenameLayerOrEffectAction(this, _treeViewer));
+		menuMgr.add(deleteAction);
+		menuMgr.add(duplicateAction);
+		menuMgr.add(_splitLayersAction);
 		menuMgr.add(new ResetAnimatableValuesAction(window, _treeViewer));
 		menuMgr.add(new GroupMarker(IWorkbenchActionConstants.MB_ADDITIONS));
 
-		newMenu.add(_newCameraLayerAction);
-		newMenu.add(_newNullLayerAction);
-		newMenu.add(_newTextLayerAction);
+		newMenu.add(newCameraLayerAction);
+		newMenu.add(newNullLayerAction);
+		newMenu.add(newTextLayerAction);
 		timeMenu.add(new TimeRemapAction(window, _treeViewer));
 		timeMenu.add(new ReverseLayerTimeAction(_treeViewer));
 		setupEffectContextMenu(effectMenu, effectActions);
@@ -1023,7 +1073,7 @@ public class LayerCompositionView extends ViewPart
 		interpolationMenu.add(new KeyframeInterpolationAction(_treeViewer, Interpolation.LINEAR));
 		interpolationMenu.add(new KeyframeInterpolationAction(_treeViewer, Interpolation.CATMULL_ROM));
 
-		getSite().registerContextMenu(menuMgr, _treeViewer);
+		site.registerContextMenu(menuMgr, _treeViewer);
 
 		Control treeViewControl = _treeViewer.getControl();
 		Menu treeViewMenu = menuMgr.createContextMenu(treeViewControl);
@@ -1144,17 +1194,9 @@ public class LayerCompositionView extends ViewPart
 				List<EffectElement> list = Util.newList();
 				ITreeSelection selection = LocalSelectionWrapper.getSelection(selectionTransfer, _treeViewer);
 				if (selection != null) {
-					Layer layer = null;
 					for (Object o : selection.toList()) {
 						if (o instanceof EffectElement) {
-							EffectElement ee = (EffectElement) o;
-							LayerElement le = (LayerElement) ee.parent.parent;
-							if (layer == null) {
-								layer = le.layer;
-							} else if (le.layer != layer) {
-								return null;
-							}
-							list.add(ee);
+							list.add((EffectElement) o);
 						} else {
 							return null;
 						}
@@ -1164,6 +1206,18 @@ public class LayerCompositionView extends ViewPart
 			}
 
 			public void dragOver(DropTargetEvent event) {
+				int operations = event.operations;
+				if (WIN32) {
+					try {
+						Class<?> os = Class.forName("org.eclipse.swt.internal.win32.OS");
+						Method m = os.getMethod("GetKeyState", int.class);
+						short keyState = (Short)m.invoke(null, 0x11);	// 0x11=OS.VK_CONTROL
+						operations &= ((keyState < 0) ? DND.DROP_COPY : DND.DROP_MOVE) | DND.DROP_LINK;
+					} catch (Exception e) {
+						_logger.warn("error getting key state", e);
+					}
+				}
+
 				if (!selectionTransfer.isSupportedType(event.currentDataType)) {
 					event.detail = DND.DROP_NONE;
 					event.feedback = DND.FEEDBACK_NONE;
@@ -1175,7 +1229,8 @@ public class LayerCompositionView extends ViewPart
 						event.detail = DND.DROP_NONE;
 						event.feedback = DND.FEEDBACK_NONE;
 					} else {
-						event.detail = event.operations & DND.DROP_MOVE;
+						event.detail = ((operations & DND.DROP_MOVE) == DND.DROP_MOVE)
+								? DND.DROP_MOVE : (operations & DND.DROP_COPY);
 						event.feedback = (event.feedback | DND.FEEDBACK_INSERT_BEFORE)
 									& ~DND.FEEDBACK_SELECT & ~DND.FEEDBACK_EXPAND;
 					}
@@ -1187,7 +1242,7 @@ public class LayerCompositionView extends ViewPart
 						event.detail = DND.DROP_NONE;
 						event.feedback = DND.FEEDBACK_NONE;
 					} else {
-						event.detail = event.operations & DND.DROP_LINK;
+						event.detail = operations & DND.DROP_LINK;
 						event.feedback = (event.feedback | DND.FEEDBACK_INSERT_BEFORE)
 									& ~DND.FEEDBACK_SELECT & ~DND.FEEDBACK_EXPAND;
 					}
@@ -1196,14 +1251,14 @@ public class LayerCompositionView extends ViewPart
 
 				if (getSourceEffectElements(event) != null && event.item != null) {
 					if (getTargetElement(event, EffectsElement.class) != null) {
-						event.detail = ((event.operations & DND.DROP_MOVE) == DND.DROP_MOVE)
-								? DND.DROP_MOVE : (event.operations & DND.DROP_COPY);
+						event.detail = ((operations & DND.DROP_MOVE) == DND.DROP_MOVE)
+								? DND.DROP_MOVE : (operations & DND.DROP_COPY);
 						event.feedback = (event.feedback | DND.FEEDBACK_SELECT)
 								& ~DND.FEEDBACK_EXPAND;
 
 					} else if (getTargetElement(event, EffectElement.class) != null) {
-						event.detail = ((event.operations & DND.DROP_MOVE) == DND.DROP_MOVE)
-								? DND.DROP_MOVE : (event.operations & DND.DROP_COPY);
+						event.detail = ((operations & DND.DROP_MOVE) == DND.DROP_MOVE)
+								? DND.DROP_MOVE : (operations & DND.DROP_COPY);
 						event.feedback = (event.feedback | DND.FEEDBACK_INSERT_BEFORE)
 								& ~DND.FEEDBACK_SELECT & ~DND.FEEDBACK_EXPAND;
 
@@ -1225,7 +1280,11 @@ public class LayerCompositionView extends ViewPart
 			public void drop(DropTargetEvent event) {
 				List<LayerElement> sourceLayerElements = getSourceLayerElements(event);
 				if (sourceLayerElements != null) {
-					moveLayers(sourceLayerElements, getTargetElement(event, LayerElement.class));
+					if (event.detail == DND.DROP_COPY) {
+						duplicateLayers(sourceLayerElements, getTargetElement(event, LayerElement.class));
+					} else {
+						moveLayers(sourceLayerElements, getTargetElement(event, LayerElement.class));
+					}
 					return;
 				}
 
@@ -1250,7 +1309,7 @@ public class LayerCompositionView extends ViewPart
 					if (effectsElement != null) {
 						EffectableLayer dstLayer = (EffectableLayer) ((LayerElement) effectsElement.parent).layer;
 						if (event.detail == DND.DROP_COPY) {
-							//copyEffects(sourceEffectElements, dstLayer, targetIndex);
+							duplicateEffects(sourceEffectElements, dstLayer, targetIndex);
 						} else {
 							moveEffects(sourceEffectElements, dstLayer, targetIndex);
 						}
@@ -1350,6 +1409,7 @@ public class LayerCompositionView extends ViewPart
 			_treeViewer.setData(LAYER_NAME_MODE, layerNameMode);
 			_nameColumn.getColumn().setText(layerNameMode ? "レイヤー名" : "ソース名");
 			_treeViewer.refresh();
+			redrawLayerReferences();
 		}
 	}
 
@@ -1599,25 +1659,23 @@ public class LayerCompositionView extends ViewPart
 	}
 
 	private void handleKeyPressed(KeyEvent e) {
-		if (e.stateMask == 0 && (e.keyCode == SWT.DEL || (COCOA && e.keyCode == SWT.BS))) {
-			removeSelectedObjects();
+		// DELキーは削除のショートカットに割り当てられてるので、ここでは処理しない。
+		if (e.stateMask == 0 && (/*e.keyCode == SWT.DEL ||*/ (COCOA && e.keyCode == SWT.BS))) {
+			removeSelectedLayersOrEffects();
 		}
 	}
 
-	private void removeSelectedObjects() {
-		if (_timelineManager.hasKeyframeSelection()) {
-			_timelineManager.removeSelectedKeyframes();
-			return;
-		}
+	private boolean canRmDupSelectedLayersOrEffects() {
+		return canRmDupSelectedLayersOrEffects(Util.<LayerElement>newSet(), Util.<EffectElement>newSet());
+	}
 
-		TreeSelection selection = (TreeSelection) _treeViewer.getSelection();
-		if (selection.isEmpty()) {
-			return;
-		}
+	private boolean canRmDupSelectedLayersOrEffects(
+			Set<LayerElement> layerElements, Set<EffectElement> effectElements) {
 
-		List<LayerElement> layerElements = Util.newList();
-		List<EffectElement> effectElements = Util.newList();
-		for (Object o : selection.toList()) {
+		layerElements.clear();
+		effectElements.clear();
+
+		for (Object o : ((TreeSelection) _treeViewer.getSelection()).toList()) {
 			if (o instanceof LayerElement) {
 				layerElements.add((LayerElement) o);
 			} else if (o instanceof EffectElement) {
@@ -1626,23 +1684,84 @@ public class LayerCompositionView extends ViewPart
 				for (Element child : ((EffectsElement) o).getChildren()) {
 					effectElements.add((EffectElement) child);
 				}
+			} else {
+				return false;
 			}
 		}
 
-		if (effectElements.size() > 0) {
-			List<Object[]> effects = Util.newList();
-			for (EffectElement ee : effectElements) {
-				effects.add(new Object[] { ((LayerElement) ee.parent.parent).layer, ee.effect });
-			}
-			_projectManager.postOperation(new RemoveEffectsOperation(_projectManager, effects));
+		return layerElements.isEmpty() ^ effectElements.isEmpty();
+	}
 
-		} else if (layerElements.size() > 0) {
-			List<Layer> layers = Util.newList();
-			for (LayerElement le : layerElements) {
-				layers.add(le.layer);
+	private void removeSelectedLayersOrEffects() {
+		Set<LayerElement> layerElements = Util.newSet();
+		Set<EffectElement> effectElements = Util.newSet();
+
+		if (canRmDupSelectedLayersOrEffects(layerElements, effectElements)) {
+			if (!effectElements.isEmpty()) {
+				List<Object[]> effects = Util.newList();
+				for (EffectElement ee : effectElements) {
+					effects.add(new Object[] { ((LayerElement) ee.parent.parent).layer, ee.effect });
+				}
+				_projectManager.postOperation(new RemoveEffectsOperation(_projectManager, effects));
+			} else {
+				List<Layer> layers = Util.newList();
+				for (LayerElement le : layerElements) {
+					layers.add(le.layer);
+				}
+				_projectManager.postOperation(new RemoveLayersOperation(_projectManager, layers));
 			}
-			Collections.reverse(layers); // UI上での表示順とデータの並び順は逆なので。
-			_projectManager.postOperation(new RemoveLayersOperation(_projectManager, layers));
+		}
+	}
+
+	private void duplicateSelectedLayersOrEffects() {
+		Set<LayerElement> layerElements = Util.newSet();
+		Set<EffectElement> effectElements = Util.newSet();
+
+		if (canRmDupSelectedLayersOrEffects(layerElements, effectElements)) {
+			if (!effectElements.isEmpty()) {
+				duplicateEffects(effectElements);
+			} else {
+				duplicateLayers(layerElements); 
+			}
+		}
+	}
+
+	private boolean canSplitSelectedLayers() {
+		return canSplitSelectedLayers(Util.<LayerElement>newSet(), new Time[1]);
+	}
+
+	private boolean canSplitSelectedLayers(Set<LayerElement> layerElements, Time[] time) {
+		layerElements.clear();
+
+		Time t = _time;
+
+		for (Object o : ((TreeSelection) _treeViewer.getSelection()).toList()) {
+			if (o instanceof LayerElement) {
+				Layer layer = ((LayerElement) o).layer;
+				if (t.after(layer.getInPoint()) && t.before(layer.getOutPoint())) {
+					layerElements.add((LayerElement) o);
+				}
+			}
+		}
+
+		if (layerElements.isEmpty()) {
+			return false;
+		} else {
+			time[0] = t;
+			return true;
+		}
+	}
+
+	private void splitSelectedLayers() {
+		Set<LayerElement> layerElements = Util.newSet();
+		Time[] time = new Time[1];
+
+		if (canSplitSelectedLayers(layerElements, time)) {
+			Set<Layer> layers = Util.newSet();
+			for (LayerElement e : layerElements) {
+				layers.add(e.layer);
+			}
+			_projectManager.postOperation(new DuplicateLayersOperation(_projectManager, layers, time[0]));
 		}
 	}
 
@@ -1657,7 +1776,6 @@ public class LayerCompositionView extends ViewPart
 
 
 		// 選択中の行が全てレイヤー、もしくは全てエフェクトの場合のみドラッグ可
-		// さらに、エフェクトの場合は全てが同じレイヤーのエフェクトの場合のみドラッグ可。
 
 		TreeSelection selection = (TreeSelection) _treeViewer.getSelection();
 		if (selection.isEmpty()) {
@@ -1672,10 +1790,8 @@ public class LayerCompositionView extends ViewPart
 			return true;
 
 		} else if (first instanceof EffectElement) {
-			Element parent = ((Element) first).parent;
 			for (Object o : selection.toList()) {
 				if (!(o instanceof EffectElement)) return false;
-				if (((Element) o).parent != parent) return false;
 			}
 			return true;
 
@@ -1750,6 +1866,28 @@ public class LayerCompositionView extends ViewPart
 		_projectManager.postOperation(new ReorderLayersOperation(_projectManager, newOrder, layers));
 	}
 
+	private void duplicateLayers(Collection<LayerElement> layerElements) {
+		duplicateLayers(layerElements, -1);
+	}
+
+	private void duplicateLayers(Collection<LayerElement> layerElements, LayerElement insertBefore) {
+		if (insertBefore != null) {
+			// Treeの表示順は内部データと逆順なので、１加える必要がある。
+			int insertIndex = _composition.getLayers().indexOf(insertBefore.layer) + 1;
+			duplicateLayers(layerElements, insertIndex);
+		} else {
+			duplicateLayers(layerElements, 0);
+		}
+	}
+
+	private void duplicateLayers(Collection<LayerElement> layerElements, int insertIndex) {
+		Set<Layer> layers = Util.newSet();
+		for (LayerElement e : layerElements) {
+			layers.add(e.layer);
+		}
+		_projectManager.postOperation(new DuplicateLayersOperation(_projectManager, layers, insertIndex));
+	}
+
 	private void newLayers(List<Item> items, LayerElement insertBefore) {
 		List<LayerElement> current = getLayerElements();
 		int insertIndex = -1;
@@ -1778,18 +1916,31 @@ public class LayerCompositionView extends ViewPart
 	}
 
 	private void moveEffects(List<EffectElement> effectElements, EffectableLayer dstLayer, int moveBefore) {
-		LayerElement le = (LayerElement) effectElements.get(0).parent.parent;
-		EffectableLayer srcLayer = (EffectableLayer) le.layer;
+		List<EffectableLayer> srcLayers = Util.newList();
 		List<Effect> effects = Util.newList();
 
 		for (EffectElement ee : effectElements) {
-			if (((LayerElement) ee.parent.parent).layer != srcLayer) {
-				throw new IllegalArgumentException();
-			}
+			srcLayers.add((EffectableLayer) ((LayerElement) ee.parent.parent).layer);
 			effects.add(ee.effect);
 		}
 
-		_projectManager.postOperation(new MoveEffectsOperation(_projectManager, srcLayer, effects, dstLayer, moveBefore));
+		_projectManager.postOperation(new MoveEffectsOperation(_projectManager, srcLayers, effects, dstLayer, moveBefore));
+	}
+
+	private void duplicateEffects(Collection<EffectElement> effectElements) {
+		duplicateEffects(effectElements, null, 0);
+	}
+
+	private void duplicateEffects(Collection<EffectElement> effectElements, EffectableLayer dstLayer, int insertBefore) {
+		List<EffectableLayer> srcLayers = Util.newList();
+		List<Effect> effects = Util.newList();
+
+		for (EffectElement ee : effectElements) {
+			srcLayers.add((EffectableLayer) ((LayerElement) ee.parent.parent).layer);
+			effects.add(ee.effect);
+		}
+
+		_projectManager.postOperation(new DuplicateEffectsOperation(_projectManager, srcLayers, effects, dstLayer, insertBefore));
 	}
 
 	private void collectAnimatableValues() {
@@ -1827,6 +1978,24 @@ public class LayerCompositionView extends ViewPart
 		}
 	}
 
+	private void redrawLayerReferences() {
+		redrawLayerReferences(_treeViewer.getTree().getItems());
+	}
+
+	private void redrawLayerReferences(TreeItem[] treeItems) {
+		for (TreeItem item : treeItems) {
+			Object element = item.getData();
+			if (element instanceof AnimatableValueElement
+					&& ((AnimatableValueElement) element).getAnimatableValue() instanceof AnimatableLayerReference) {
+				Rectangle bounds = item.getBounds(VALUE_COL);
+				_treeViewer.getTree().redraw(bounds.x, bounds.y, bounds.width, bounds.height, false);
+			}
+			if (item.getExpanded()) {
+				redrawLayerReferences(item.getItems());
+			}
+		}
+	}
+
 	private TreeItem findLayerAnimatableValueItem(TreeItem layerItem, final String property) {
 		return new Object() {
 			TreeItem find(TreeItem treeItem) {
@@ -2005,13 +2174,15 @@ public class LayerCompositionView extends ViewPart
 			Set<Element> elements = Util.newSet();
 			for (TreeItem treeItem : treeItems) {
 				LayerElement layerElement = (LayerElement) treeItem.getData();
-				if (layerElement.layer.getParent() == event.layer) {
+				if (_composition.getParentLayer(layerElement.layer) == event.layer) {
 					elements.add(layerElement);
 				}
 			}
 			if (!elements.isEmpty()) {
 				_treeViewer.update(elements.toArray(), null);
 			}
+
+			redrawLayerReferences();
 		}
 
 		for (TreeItem treeItem : treeItems) {
@@ -2027,8 +2198,8 @@ public class LayerCompositionView extends ViewPart
 						_treeViewer.update(layerElement, null);
 					}
 
-					// 表示／非表示のスイッチなどは、なぜか redraw をしないと再描画されない。上の update だけじゃダメなの？
-					// しかも win32 だと TreeItem#getBounds() が返す Rectangle ではダメだし...
+					// 表示／非表示のスイッチなどは独自に描画しているため、redraw もする必要がある。
+					// また、win32 だと TreeItem#getBounds() が返す Rectangle ではダメ。
 
 					Rectangle bounds = treeItem.getBounds();
 					if (WIN32) {
@@ -2105,6 +2276,9 @@ public class LayerCompositionView extends ViewPart
 			_treeViewer.getTree().setRedraw(true);
 		}
 
+		// 追加削除により選択状態が変化するため、_splitLayersAction の状態も更新されるはずだが、念のため。
+		_splitLayersAction.setEnabled(canSplitSelectedLayers());
+
 		collectAnimatableValues();
 	}
 
@@ -2114,6 +2288,11 @@ public class LayerCompositionView extends ViewPart
 		}
 
 		Item item = ProjectEvent.getItem(event);
+		if (item == _compItem) {
+			setPartName(_compItem.getName());
+			return;	// コンポ内に自分自身を含んでいることはないので、これ以降の処理は不要。
+		}
+
 		Set<Element> elements = Util.newSet();
 
 		for (TreeItem treeItem : _treeViewer.getTree().getItems()) {
@@ -2126,9 +2305,9 @@ public class LayerCompositionView extends ViewPart
 				}
 			}
 
-			if (element.layer.getParent() instanceof ItemLayer) {
-				ItemLayer parentLayer = (ItemLayer) element.layer.getParent();
-				if (parentLayer.getItem() == item) {
+			Layer parentLayer = _composition.getParentLayer(element.layer);
+			if (parentLayer instanceof ItemLayer) {
+				if (((ItemLayer) parentLayer).getItem() == item) {
 					elements.add(element);
 				}
 			}
@@ -2325,6 +2504,7 @@ public class LayerCompositionView extends ViewPart
 		}
 
 		_timelineManager.redraw();
+		_splitLayersAction.setEnabled(canSplitSelectedLayers());
 		selectAndReveal(treeItems);
 		collectAnimatableValues();
 	}
@@ -2416,8 +2596,8 @@ public class LayerCompositionView extends ViewPart
 
 			_treeViewer.update(treeItem.getData(), null);
 
-			// なぜか redraw をしないと再描画されない。上の update だけじゃダメなの？
-			// しかも win32 だと TreeItem#getBounds() が返す Rectangle ではダメだし...
+			// タイムラインは独自に描画しているため、redraw もする必要がある？
+			// また、win32 だと TreeItem#getBounds() が返す Rectangle ではダメ。
 
 			Rectangle bounds = treeItem.getBounds();
 			if (WIN32) {
@@ -2509,6 +2689,8 @@ public class LayerCompositionView extends ViewPart
 			collectAnimatableValues(time);
 			_timelineManager.update(time, true);
 			_timeCodeComposite.redraw();
+			_splitLayersAction.setEnabled(canSplitSelectedLayers());
+
 		} else {
 			collectAnimatableValues(time);
 			refreshPlayer(time);
