@@ -76,8 +76,13 @@ public class EffectElement extends Element {
 
 	public String getColumnText(int columnIndex) {
 		switch (columnIndex) {
-			case LayerCompositionView.NAME_COL:
-				return effect.getName();
+			case LayerCompositionView.NAME_COL: {
+				String name = effect.getName();
+				if (effect.getEffectDescriptor().isUnknown()) {
+					name += "（不明なエフェクト）";
+				}
+				return name;
+			}
 
 			default:
 				return null;
