@@ -210,7 +210,7 @@ public class LayerElement extends Element {
 
 			case LayerCompositionView.PARENT_COL: {
 				String parentName;
-				Layer parent = layer.getParent();
+				Layer parent = composition.getParentLayer(layer);
 				if (parent == null) {
 					parentName = " - ";
 				} else if (!(parent instanceof ItemLayer) || isLayerNameMode()) {
@@ -439,6 +439,7 @@ public class LayerElement extends Element {
 				if (parentEditor == null) {
 					parentEditor = new ComboBoxViewerCellEditor(viewer.getTree(), SWT.READ_ONLY);
 					parentEditor.setContenProvider(ArrayContentProvider.getInstance());
+					parentEditor.setLabelProvider(new ParentLabelProvider());
 					parentEditor.setActivationStyle(ComboBoxViewerCellEditor.DROP_DOWN_ON_PROGRAMMATIC_ACTIVATION);
 
 					((Combo) parentEditor.getControl()).addSelectionListener(new SelectionAdapter() {
@@ -447,8 +448,6 @@ public class LayerElement extends Element {
 						}
 					});
 				}
-				parentEditor.setInput(null);
-				parentEditor.setLabelProvider(new ParentLabelProvider(isLayerNameMode()));
 				parentEditor.setInput(getLayersForParentEditor());
 				return parentEditor;
 
@@ -469,7 +468,7 @@ public class LayerElement extends Element {
 				return ((MediaLayer) layer).getTrackMatte();
 
 			case LayerCompositionView.PARENT_COL:
-				Layer parent = layer.getParent();
+				Layer parent = composition.getParentLayer(layer);
 				return (parent != null) ? parent : NO_PARENT;
 
 			default:
@@ -520,19 +519,28 @@ public class LayerElement extends Element {
 	private class TrackMatteLabelProvider extends LabelProvider {
 		public String getText(Object element) {
 			TrackMatte trackMatte = (TrackMatte) element;
-			return (trackMatte == TrackMatte.NONE) ? trackMatte.label()
-					: String.format("%s - %s", trackMatte.label(), getTrackMatteLayer().getName());
+			if (trackMatte == TrackMatte.NONE) {
+				return trackMatte.label();
+			} else {
+				String name;
+				MediaLayer trackMatteLayer = getTrackMatteLayer();
+				if (!(trackMatteLayer instanceof ItemLayer) || isLayerNameMode()) {
+					name = trackMatteLayer.getName();
+				} else {
+					name = ((ItemLayer) trackMatteLayer).getItem().getName();
+				}
+				return String.format("%s - %s", trackMatte.label(), name);
+			}
 		}
 	}
 
 	private Object[] getLayersForParentEditor() {
 		List<Object> layers = Util.newList();
 
-		LayerComposition comp = (LayerComposition) viewer.getData(LayerCompositionView.LAYER_COMPOSITION);
-		for (Layer l : comp.getLayers()) {
+		for (Layer l : composition.getLayers()) {
 			Layer tmp = l;
 			while (tmp != null && tmp != layer) {
-				tmp = tmp.getParent();
+				tmp = composition.getParentLayer(tmp);
 			}
 			if (tmp == null) {
 				layers.add(l);
@@ -547,18 +555,11 @@ public class LayerElement extends Element {
 
 	private static final Object NO_PARENT = new Object();
 
-	private static class ParentLabelProvider extends LabelProvider {
-
-		private final boolean layerNameMode;
-
-		private ParentLabelProvider(boolean layerNameMode) {
-			this.layerNameMode = layerNameMode;
-		}
-
+	private class ParentLabelProvider extends LabelProvider {
 		public String getText(Object element) {
 			if (element == NO_PARENT) {
 				return "なし";
-			} else if (!(element instanceof ItemLayer) || layerNameMode) {
+			} else if (!(element instanceof ItemLayer) || isLayerNameMode()) {
 				return ((Layer) element).getName();
 			} else {
 				return ((ItemLayer) element).getItem().getName();
