@@ -136,7 +136,8 @@ public class SwitchGroup {
 
 		Image image = s.getImage();
 		if (image != null) {
-			gc.drawImage(image, x+1, y+1);
+			Rectangle bounds = image.getBounds();
+			gc.drawImage(image, x+(15-bounds.width)/2, y+(15-bounds.height)/2);
 		}
 	}
 
