@@ -34,7 +34,6 @@ import ch.kuramo.javie.app.views.LayerCompositionView;
 import ch.kuramo.javie.core.AnimatableDouble;
 import ch.kuramo.javie.core.LayerComposition;
 import ch.kuramo.javie.core.LayerNature;
-import ch.kuramo.javie.core.MediaInput;
 import ch.kuramo.javie.core.MediaLayer;
 import ch.kuramo.javie.core.TimeCode;
 
@@ -70,9 +69,8 @@ class TimeRemapElementDelegate extends AnimatableDoubleElementDelegate {
 		super(element, name, avalue);
 		this.layer = layer;
 
-		MediaInput input = layer.getMediaInput();
-		if (input.isVideoAvailable()) {
-			frameDuration = input.getVideoFrameDuration();
+		if (LayerNature.isVideoNature(layer)) {
+			frameDuration = layer.getMediaInput().getVideoFrameDuration();
 		} else {
 			LayerComposition comp = (LayerComposition) element.viewer.getData(LayerCompositionView.LAYER_COMPOSITION);
 			frameDuration = comp.getFrameDuration();
