@@ -27,7 +27,10 @@ import java.lang.reflect.Method;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.SortedMap;
+import java.util.SortedSet;
+import java.util.TreeSet;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.MouseAdapter;
@@ -89,7 +92,7 @@ public class TimelineManager {
 	private static final boolean COCOA = SWT.getPlatform().equals("cocoa");
 
 	private static final int FRAME_WIDTH = 50;
-	private static final int LEFT_MARGIN = 20;
+	private static final int LEFT_MARGIN = 30;
 	private static final int RIGHT_MARGIN = 40;
 
 
@@ -237,6 +240,9 @@ public class TimelineManager {
 		this.toTime = pixelsToTime(scrollSlider.getSelection() + colWidth, frameDuration, zoom);
 
 		redraw();
+
+		// キーフレームナビゲータも再描画する。
+		redrawShowhideColumn();
 	}
 
 	public void redraw() {
@@ -247,6 +253,18 @@ public class TimelineManager {
 		meter.redraw();
 	}
 
+	private void redrawShowhideColumn() {
+		Tree tree = timelineColumn.getParent();
+		int col = LayerCompositionView.SHOWHIDE_COL;
+		int x = 0;
+		for (int i = 0; i < col; ++i) {
+			x += tree.getColumn(i).getWidth();
+		}
+		int width = tree.getColumn(col).getWidth();
+		Rectangle clientArea = tree.getClientArea();
+		tree.redraw(x, clientArea.y, width, clientArea.height, true);
+	}
+
 	private int timeToPixels(Time time, Time frameDuration, double zoom) {
 		return (int)Math.round(FRAME_WIDTH * zoom * time.toSecond() / frameDuration.toSecond()) + LEFT_MARGIN;
 	}
@@ -332,19 +350,22 @@ public class TimelineManager {
 	}
 
 	private void mouseDownOnMeter(final MouseEvent e) {
+		final SortedSet<Time> snapTimes = collectSnapTimes(false, true, false, false);
+
 		setWrapMode(false);
-		updateView(e.x);
+		updateView(e.x, (e.stateMask & SWT.SHIFT) != 0, snapTimes);
 
 		final Control control = (Control) e.widget;
 		final Display display = e.display;
 
 		class MeterMouseTracker implements Runnable, Listener {
 			private int x = e.x;
+			private boolean snap = (e.stateMask & SWT.SHIFT) != 0;
 			private boolean end;
 
 			public void run() {
 				if (!end) {
-					updateView(x);
+					updateView(x, snap, snapTimes);
 					display.timerExec(30, this);
 				}
 			}
@@ -358,7 +379,8 @@ public class TimelineManager {
 							}
 
 							x = control.toControl(display.getCursorLocation()).x;
-							updateView(x);
+							snap = (e.stateMask & SWT.SHIFT) != 0;
+							updateView(x, snap, snapTimes);
 							break;
 						}
 						// fall through
@@ -382,7 +404,7 @@ public class TimelineManager {
 		display.addFilter(SWT.Deactivate, tracker);
 	}
 
-	private void updateView(int x) {
+	private void updateView(int x, boolean snap, SortedSet<Time> snapTimes) {
 		Time frameDuration = composition.getFrameDuration();
 		int scroll = scrollSlider.getSelection();
 
@@ -394,11 +416,24 @@ public class TimelineManager {
 			time = composition.getDuration().subtract(frameDuration);
 		}
 
-		time = Time.fromFrameNumber(time.toFrameNumber(frameDuration), frameDuration);
+		if (snap) {
+			SortedSet<Time> head = snapTimes.headSet(time);
+			SortedSet<Time> tail = snapTimes.tailSet(time);
 
-		if (!time.equals(currentTime)) {
-			view.update(time);
+			Time prev = head.isEmpty() ? null : head.last();
+			int dxPrev = (prev != null) ? Math.abs(timeToPixels(prev, frameDuration, zoom)-scroll-x) : Integer.MAX_VALUE;
+			if (dxPrev < 20) {
+				time = prev;
+			}
+
+			Time next = tail.isEmpty() ? null : tail.first();
+			int dxNext = (next != null) ? Math.abs(timeToPixels(next, frameDuration, zoom)-scroll-x) : Integer.MAX_VALUE;
+			if (dxNext < 20 && dxNext < dxPrev) {
+				time = next;
+			}
 		}
+
+		setTime(time);
 	}
 
 	public void drawLayer(Event e, Layer layer) {
@@ -515,15 +550,15 @@ public class TimelineManager {
 
 		if (x1-3 < x && x < x1+3) {
 			clearKeyframeSelection();
-			dragGestureEditor = new DragGestureInPointShifter(e, pixelsToTime(x, frameDuration, zoom));
+			dragGestureEditor = new DragGestureInPointShifter(e, layer, pixelsToTime(x, frameDuration, zoom));
 
 		} else if (x2-3 < x && x < x2+3) {
 			clearKeyframeSelection();
-			dragGestureEditor = new DragGestureOutPointShifter(e, pixelsToTime(x, frameDuration, zoom));
+			dragGestureEditor = new DragGestureOutPointShifter(e, layer, pixelsToTime(x, frameDuration, zoom));
 
 		} else if (x1 <= x && x < x2) {
 			clearKeyframeSelection();
-			dragGestureEditor = new DragGestureLayerTimeShifter(e, pixelsToTime(x, frameDuration, zoom));
+			dragGestureEditor = new DragGestureLayerTimeShifter(e, layer, pixelsToTime(x, frameDuration, zoom));
 
 		} else if (layer instanceof MediaItemLayer && !LayerNature.isTimeRemapEnabled(layer)) {
 			MediaInput input = ((MediaItemLayer) layer).getMediaInput();
@@ -537,7 +572,7 @@ public class TimelineManager {
 					x2 = timeToPixels(endTime, frameDuration, zoom);
 
 					if (x1 <= x && x < x2) {
-						dragGestureEditor = new DragGestureSlipEditor(e, pixelsToTime(x, frameDuration, zoom));
+						dragGestureEditor = new DragGestureSlipEditor(e, layer, pixelsToTime(x, frameDuration, zoom));
 					}
 				}
 			}
@@ -557,7 +592,7 @@ public class TimelineManager {
 		int y = e.y + e.height/2 - 1;
 		GC gc = e.gc;
 
-		for (Keyframe<?> kf : avalue.getKeyframes(fromTime, toTime)) {
+		for (Keyframe<?> kf : avalue.getKeyframeMap().subMap(fromTime, toTime).values()) {
 			int x = ex + timeToPixels(kf.time, frameDuration, zoom) - scroll;
 			Image icon = ImageUtil.getKeyframeIcon(kf.interpolation, keyframeSelection.containsKey(kf));
 			if (icon != null) {
@@ -581,9 +616,9 @@ public class TimelineManager {
 		Time frameDuration = composition.getFrameDuration();
 
 		Time time1 = pixelsToTime(x-4+scroll, frameDuration, zoom);
-		Time time2 = pixelsToTime(x+5+scroll, frameDuration, zoom);	// headKeyframeMap は引数の時刻を「含まない」ので
+		Time time2 = pixelsToTime(x+5+scroll, frameDuration, zoom);	// headMap は引数の時刻を「含まない」ので
 																	// time2 は x+4 ではなく x+5 の時刻で計算する。 
-		SortedMap<Time, ?> head = avalue.headKeyframeMap(time2);
+		SortedMap<Time, ?> head = avalue.getKeyframeMap().headMap(time2);
 		if (head.isEmpty()) {
 			return null;
 		}
@@ -616,7 +651,7 @@ public class TimelineManager {
 		if (kf != null && keyframeSelection.containsKey(kf)
 				&& e.button == 1 && dragGestureEditor == null) {
 
-			dragGestureEditor = new DragGestureKeyframeShifter(e, kf.time);
+			dragGestureEditor = new DragGestureKeyframeShifter(e, kf);
 		}
 	}
 
@@ -724,6 +759,106 @@ public class TimelineManager {
 		return currentTime;
 	}
 
+	public void setTime(Time time) {
+		Time frameDuration = composition.getFrameDuration();
+		time = Time.fromFrameNumber(time.toFrameNumber(frameDuration), frameDuration);
+
+		if (!time.equals(currentTime)) {
+			view.update(time);
+		}
+	}
+
+	private SortedSet<Time> collectSnapTimes(
+			boolean includesCurrentTime, boolean includesKeyframes,
+			boolean excludesSelectedLayers, boolean excludesSelectedKeyframes) {
+
+		Set<Layer> layers = Util.newSet();
+		final Set<Keyframe<?>> keyframes = Util.newSet();
+
+		Tree tree = timelineColumn.getParent();
+		Rectangle clientArea = tree.getClientArea();
+		final int clientTop = clientArea.y + tree.getHeaderHeight();
+		final int clientBottom = clientArea.y + clientArea.height;
+
+		TreeItem[] items = tree.getItems();
+		for (int i = items.length-1; i >= 0; --i) {
+			TreeItem item = items[i];
+			Rectangle b = item.getBounds(LayerCompositionView.TIMELINE_COL);
+
+			// clientAreaよりも下にある場合何もせずにひとつ上の行に移る。
+			if (b.y >= clientBottom) {
+				continue;
+			}
+
+			// レイヤー行の下辺がclientAreaの下辺よりも上にある場合、レイヤー行の子要素を調べる。
+			// ただし、キーフレームにもスナップする場合のみ。
+			if (includesKeyframes && b.y+b.height < clientBottom) {
+				new Object() {
+					void collectKeyframeTimes(TreeItem item) {
+						if (item.getExpanded()) {
+							for (TreeItem child : item.getItems()) {
+								Object element = child.getData();
+								if (element instanceof AnimatableValueElement) {
+									Rectangle b = child.getBounds(LayerCompositionView.TIMELINE_COL);
+									if (b.y < clientBottom && b.y+b.height > clientTop) {
+										AnimatableValue<?> avalue = ((AnimatableValueElement) element).getAnimatableValue();
+										keyframes.addAll(avalue.getKeyframeMap().values());
+									}
+								} else {
+									collectKeyframeTimes(child);
+								}
+							}
+						}
+					}
+				}.collectKeyframeTimes(item);
+			}
+
+			// レイヤー行の下辺がclientAreaの上辺よりも下にある場合、レイヤーのインポイントとアウトポイントを追加する。
+			if (b.y+b.height > clientTop) {
+				Object element = item.getData();
+				layers.add(((LayerElement) element).layer);
+			}
+
+			// レイヤー行の上側がclientAreaの上辺と一致するか上にある場合、残りの行は処理する必要がない。
+			if (b.y <= clientTop) {
+				break;
+			}
+		}
+
+		if (excludesSelectedLayers) {
+			for (TreeItem item : tree.getSelection()) {
+				Object element = item.getData();
+				if (element instanceof LayerElement) {
+					layers.remove(((LayerElement) element).layer);
+				}
+			}
+		}
+
+		if (excludesSelectedKeyframes) {
+			keyframes.removeAll(keyframeSelection.keySet());
+		}
+
+		TreeSet<Time> snapTimes = new TreeSet<Time>();
+
+		for (Layer layer : layers) {
+			snapTimes.add(layer.getInPoint());
+			snapTimes.add(layer.getOutPoint());
+		}
+
+		for (Keyframe<?> kf : keyframes) {
+			snapTimes.add(kf.time);
+		}
+
+		if (includesCurrentTime) {
+			snapTimes.add(currentTime);
+		}
+
+		snapTimes.add(Time.fromFrameNumber(0, composition.getFrameDuration()));
+		snapTimes.add(composition.getDuration());
+
+		return snapTimes;
+	}
+
 
 	// TODO getCocoaCurrentButtonState は AnimatableValueElementDelegate にも同じものがある。
 
@@ -749,6 +884,8 @@ public class TimelineManager {
 
 		private final Time baseTime;
 
+		private final SortedSet<Time> snapTimes;
+
 		private final String relation = Util.randomId();
 
 		private final long downTime;
@@ -760,10 +897,12 @@ public class TimelineManager {
 		private Time prevTime;
 
 
-		private AbstractDragGestureEditor(MouseEvent event, Time baseTime) {
+		private AbstractDragGestureEditor(MouseEvent event, Time baseTime, SortedSet<Time> snapTimes) {
 			Time frameDuration = composition.getFrameDuration();
 			this.baseTime = prevTime = Time.fromFrameNumber(baseTime.toFrameNumber(frameDuration), frameDuration);
 
+			this.snapTimes = snapTimes;
+
 			Control control = (Control) event.widget;
 			downTime = System.currentTimeMillis();
 			downX = event.x;
@@ -790,7 +929,7 @@ public class TimelineManager {
 								}
 
 								if (dragDetected) {
-									drag(x);
+									drag(x, (e.stateMask & SWT.SHIFT) != 0);
 								}
 
 								break;
@@ -814,27 +953,77 @@ public class TimelineManager {
 			display.addFilter(SWT.Deactivate, listener);
 		}
 
-		private void drag(int x) {
+		private void drag(int x, boolean snap) {
 			Time frameDuration = composition.getFrameDuration();
 			Time time = pixelsToTime(x-timelineColumnX()+scrollSlider.getSelection(), frameDuration, zoom);
 			time = Time.fromFrameNumber(time.toFrameNumber(frameDuration), frameDuration);
 			if (!time.equals(prevTime)) {
-				projectManager.postOperation(createOperation(time, prevTime, baseTime, relation));
+				projectManager.postOperation(createOperation(time, prevTime, baseTime, relation, snap));
 				prevTime = time;
 			}
 		}
 
-		protected abstract ProjectOperation createOperation(Time time, Time prevTime, Time baseTime, String relation);
+		protected abstract ProjectOperation createOperation(
+				Time time, Time prevTime, Time baseTime, String relation, boolean snap);
+
+
+		protected Time adjustDeltaTime(Time deltaTime, boolean snap, Time...oldTimes) {
+			Time oldTime = oldTimes[0];
+			Time newTime = deltaTime.add(oldTime);	// deltaTimeにoldTimeを加えているのは、deltaTimeのタイムスケールで計算するため。
+
+			Time frameDuration = composition.getFrameDuration();
+
+			if (snap) {
+				int dxMin = 20;
+
+				for (Time oldTime2 : oldTimes) {
+					Time newTime2 = deltaTime.add(oldTime2);
+					int x = timeToPixels(newTime2, frameDuration, zoom);
+
+					SortedSet<Time> head = snapTimes.headSet(newTime2);
+					SortedSet<Time> tail = snapTimes.tailSet(newTime2);
+
+					Time prev = head.isEmpty() ? null : head.last();
+					int dxPrev = (prev != null) ? Math.abs(timeToPixels(prev, frameDuration, zoom)-x) : Integer.MAX_VALUE;
+					if (dxPrev < dxMin) {
+						dxMin = dxPrev;
+						oldTime = oldTime2;
+						newTime = prev;
+					}
+
+					Time next = tail.isEmpty() ? null : tail.first();
+					int dxNext = (next != null) ? Math.abs(timeToPixels(next, frameDuration, zoom)-x) : Integer.MAX_VALUE;
+					if (dxNext < dxMin) {
+						dxMin = dxNext;
+						oldTime = oldTime2;
+						newTime = next;
+					}
+				}
+			}
+
+			Time t = Time.fromFrameNumber(newTime.toFrameNumber(frameDuration), frameDuration);
+			if (newTime.subtract(t).toSecond()*2 < frameDuration.toSecond()) {
+				newTime = t;
+			} else {
+				newTime = t.add(frameDuration);
+			}
+
+			// TODO この計算で誤差が発生するかも(oldTimeとnewTimeのタイムスケールが異なることによる)
+			return newTime.subtract(oldTime);
+		}
 	}
 
 
 	private class DragGestureInPointShifter extends AbstractDragGestureEditor {
 
+		private final Time baseInPoint;
+
 		private final Object[][] layersAndInPoints;
 
 
-		private DragGestureInPointShifter(MouseEvent event, Time baseTime) {
-			super(event, baseTime);
+		private DragGestureInPointShifter(MouseEvent event, Layer baseLayer, Time baseTime) {
+			super(event, baseTime, collectSnapTimes(true, true/*flase*/, true, false));
+			baseInPoint = baseLayer.getInPoint();
 			layersAndInPoints = getLayersAndInPoints();
 		}
 
@@ -851,20 +1040,24 @@ public class TimelineManager {
 		}
 
 		@Override
-		protected ProjectOperation createOperation(Time time, Time prevTime, Time baseTime, String relation) {
+		protected ProjectOperation createOperation(Time time, Time prevTime, Time baseTime, String relation, boolean snap) {
+			Time deltaTime = adjustDeltaTime(time.subtract(baseTime), snap, baseInPoint);
 			return new ModifyLayerInPointOperation(
-					projectManager, composition, layersAndInPoints, time.subtract(baseTime), relation);
+					projectManager, composition, layersAndInPoints, deltaTime, relation);
 		}
 
 	}
 
 	private class DragGestureOutPointShifter extends AbstractDragGestureEditor {
 
+		private final Time baseOutPoint;
+
 		private final Object[][] layersAndOutPoints;
 
 
-		private DragGestureOutPointShifter(MouseEvent event, Time baseTime) {
-			super(event, baseTime);
+		private DragGestureOutPointShifter(MouseEvent event, Layer baseLayer, Time baseTime) {
+			super(event, baseTime, collectSnapTimes(true, true/*flase*/, true, false));
+			baseOutPoint = baseLayer.getOutPoint();
 			layersAndOutPoints = getLayersAndOutPoints();
 		}
 
@@ -881,15 +1074,18 @@ public class TimelineManager {
 		}
 
 		@Override
-		protected ProjectOperation createOperation(Time time, Time prevTime, Time baseTime, String relation) {
+		protected ProjectOperation createOperation(Time time, Time prevTime, Time baseTime, String relation, boolean snap) {
+			Time deltaTime = adjustDeltaTime(time.subtract(baseTime), snap, baseOutPoint);
 			return new ModifyLayerOutPointOperation(
-					projectManager, composition, layersAndOutPoints, time.subtract(baseTime), relation);
+					projectManager, composition, layersAndOutPoints, deltaTime, relation);
 		}
 
 	}
 
 	private class DragGestureSlipEditor extends AbstractDragGestureEditor {
 
+		private final Time baseStartTime;
+
 		private final Object[][] layersAndStartTimes;
 
 		private final Object[][] selectedKeyframeData;
@@ -897,8 +1093,9 @@ public class TimelineManager {
 		private final String[] baseAnimatableValues;
 
 
-		private DragGestureSlipEditor(MouseEvent event, Time baseTime) {
-			super(event, baseTime);
+		private DragGestureSlipEditor(MouseEvent event, Layer baseLayer, Time baseTime) {
+			super(event, baseTime, new TreeSet<Time>());
+			baseStartTime = baseLayer.getStartTime();
 			layersAndStartTimes = getLayersAndStartTimes();
 			selectedKeyframeData = createSelectedKeyframeData();
 			baseAnimatableValues = createBaseAnimatableValues(selectedKeyframeData);
@@ -917,21 +1114,28 @@ public class TimelineManager {
 		}
 
 		@Override
-		protected ProjectOperation createOperation(Time time, Time prevTime, Time baseTime, String relation) {
+		protected ProjectOperation createOperation(Time time, Time prevTime, Time baseTime, String relation, boolean snap) {
+			Time deltaTime = adjustDeltaTime(time.subtract(baseTime), false, baseStartTime);
 			return new LayerSlipOperation(
 					projectManager, composition,
 					layersAndStartTimes, selectedKeyframeData, baseAnimatableValues,
-					time.subtract(baseTime), relation);
+					deltaTime, relation);
 		}
 
 	}
 
 	private class DragGestureLayerTimeShifter extends AbstractDragGestureEditor {
 
+		private final Time baseInPoint;
+
+		private final Time baseOutPoint;
+
 		private final List<Layer> layers = Util.newList();
 
-		private DragGestureLayerTimeShifter(MouseEvent event, Time baseTime) {
-			super(event, baseTime);
+		private DragGestureLayerTimeShifter(MouseEvent event, Layer baseLayer, Time baseTime) {
+			super(event, baseTime, collectSnapTimes(true, true, true, false));
+			baseInPoint = baseLayer.getInPoint();
+			baseOutPoint = baseLayer.getOutPoint();
 			for (TreeItem treeItem : timelineColumn.getParent().getSelection()) {
 				Object element = treeItem.getData();
 				if (element instanceof LayerElement) {
@@ -941,32 +1145,34 @@ public class TimelineManager {
 		}
 
 		@Override
-		protected ProjectOperation createOperation(Time time, Time prevTime, Time baseTime, String relation) {
-			return new ShiftLayerTimesOperation(
-					projectManager, composition, layers,
-					time.subtract(prevTime), relation);
+		protected ProjectOperation createOperation(Time time, Time prevTime, Time baseTime, String relation, boolean snap) {
+			Time deltaTime = adjustDeltaTime(time.subtract(baseTime), snap, baseInPoint, baseOutPoint);
+			return new ShiftLayerTimesOperation(projectManager, composition, layers, deltaTime, relation);
 		}
 
 	}
 
 	private class DragGestureKeyframeShifter extends AbstractDragGestureEditor {
 
+		private final Keyframe<?> baseKeyframe;
+
 		private final Object[][] selectedKeyframeData;
 
 		private final String[] baseAnimatableValues;
 
 
-		private DragGestureKeyframeShifter(MouseEvent event, Time baseTime) {
-			super(event, baseTime);
+		private DragGestureKeyframeShifter(MouseEvent event, Keyframe<?> baseKeyframe) {
+			super(event, baseKeyframe.time, collectSnapTimes(true, true, false, true));
+			this.baseKeyframe = baseKeyframe;
 			selectedKeyframeData = createSelectedKeyframeData();
 			baseAnimatableValues = createBaseAnimatableValues(selectedKeyframeData);
 		}
 
 		@Override
-		protected ProjectOperation createOperation(Time time, Time prevTime, Time baseTime, String relation) {
+		protected ProjectOperation createOperation(Time time, Time prevTime, Time baseTime, String relation, boolean snap) {
+			Time deltaTime = adjustDeltaTime(time.subtract(baseTime), snap, baseKeyframe.time);
 			return new ShiftKeyframesOperation(
-					projectManager, composition, selectedKeyframeData, baseAnimatableValues,
-					time.subtract(baseTime), relation);
+					projectManager, composition, selectedKeyframeData, baseAnimatableValues, deltaTime, relation);
 		}
 
 	}
