@@ -55,10 +55,10 @@ public abstract class AbstractAnimatableEnum<E extends Enum<E>>
 		return Enum.valueOf(_enumType, (String) Context.jsToJava(jsValue, String.class));
 	}
 
-	public StringProperty createExpressionElement(final RenderContext renderContext) {
+	public StringProperty createExpressionElement(final CoreContext context) {
 		return new StringProperty() {
-			public String getValue()			{ return value(renderContext).name(); }
-			public String valueAtTime(double t)	{ return AbstractAnimatableEnum.this.valueAtTime(t, renderContext).name(); }
+			public String getValue()			{ return value(context).name(); }
+			public String valueAtTime(double t)	{ return AbstractAnimatableEnum.this.valueAtTime(t, context).name(); }
 		};
 	}
 
