@@ -26,13 +26,13 @@ package ch.kuramo.javie.core;
 import java.util.Collection;
 
 import org.mozilla.javascript.Context;
-import org.mozilla.javascript.NativeJavaArray;
-import org.mozilla.javascript.ScriptRuntime;
+import org.mozilla.javascript.NativeArray;
 import org.mozilla.javascript.Scriptable;
+import org.mozilla.javascript.Wrapper;
 
 import ch.kuramo.javie.api.Color;
 import ch.kuramo.javie.api.IAnimatableColor;
-import ch.kuramo.javie.core.exprelems.DoubleProperty;
+import ch.kuramo.javie.core.exprelems.ColorProperty;
 
 public class AnimatableColor extends ArithmeticalAnimatableValue<Color> implements IAnimatableColor {
 
@@ -51,17 +51,26 @@ public class AnimatableColor extends ArithmeticalAnimatableValue<Color> implemen
 	}
 
 	public Color jsToJava(Object jsValue) {
-		if (jsValue instanceof NativeJavaArray) {
-			// anchorPoint や position などをそのまま参照した場合 (例: thisComp.layer(3).position)
+		if (jsValue instanceof Wrapper) {
+			Object javaObj = ((Wrapper) jsValue).unwrap();
 
-			Object[] value = (Object[]) ((NativeJavaArray) jsValue).unwrap();
-			double[] array = new double[] { 0, 0, 0, 1 };
-			for (int i = 0, n = Math.min(4, value.length); i < n; ++i) {
-				array[i] = (Double) Context.jsToJava(value[i], double.class);
+			if (javaObj instanceof ColorProperty) {
+				javaObj = ((ColorProperty) javaObj).getValue();
 			}
-			return valueOf(array);
 
-		} else /*if (jsValue instanceof NativeArray)*/ {
+			if (javaObj instanceof Color) {
+				return (Color) javaObj;
+
+			} else if (javaObj instanceof Object[]) {
+				Object[] value = (Object[]) javaObj;
+				double[] array = new double[] { 0, 0, 0, 1 };
+				for (int i = 0, n = Math.min(4, value.length); i < n; ++i) {
+					array[i] = (Double) Context.jsToJava(value[i], double.class);
+				}
+				return valueOf(array);
+			}
+
+		} else if (jsValue instanceof NativeArray) {
 			// 配列表現を用いた場合 (例: [time*10, 200, 0])
 
 			double[] array = (double[]) Context.jsToJava(jsValue, double[].class);
@@ -73,7 +82,13 @@ public class AnimatableColor extends ArithmeticalAnimatableValue<Color> implemen
 				}
 			}
 			return valueOf(array);
+
+		} else if (jsValue == null) {
+			return Color.BLACK;
 		}
+
+		double d = (Double) Context.jsToJava(jsValue, double.class);
+		return new Color(d, d, d, 1);
 	}
 
 	@Override
@@ -86,33 +101,12 @@ public class AnimatableColor extends ArithmeticalAnimatableValue<Color> implemen
 		return new Color(d[0], d[1], d[2], d[3]);
 	}
 
-	public Scriptable[] createExpressionElement(final RenderContext renderContext) {
-		DoubleProperty r = new DoubleProperty() {
-			public double getValue()			{ return value(renderContext).r; }
-			public double valueAtTime(double t)	{ return AnimatableColor.this.valueAtTime(t, renderContext).r; }
-		};
-
-		DoubleProperty g = new DoubleProperty() {
-			public double getValue()			{ return value(renderContext).g; }
-			public double valueAtTime(double t)	{ return AnimatableColor.this.valueAtTime(t, renderContext).g; }
-		};
-
-		DoubleProperty b = new DoubleProperty() {
-			public double getValue()			{ return value(renderContext).b; }
-			public double valueAtTime(double t)	{ return AnimatableColor.this.valueAtTime(t, renderContext).b; }
-		};
-
-		DoubleProperty a = new DoubleProperty() {
-			public double getValue()			{ return value(renderContext).a; }
-			public double valueAtTime(double t)	{ return AnimatableColor.this.valueAtTime(t, renderContext).a; }
-		};
-
-		return new Scriptable[] {
-				renderContext.toNativeJavaObject(r, ScriptRuntime.NumberClass),
-				renderContext.toNativeJavaObject(g, ScriptRuntime.NumberClass),
-				renderContext.toNativeJavaObject(b, ScriptRuntime.NumberClass),
-				renderContext.toNativeJavaObject(a, ScriptRuntime.NumberClass)
+	public Scriptable createExpressionElement(final CoreContext context) {
+		ColorProperty cp = new ColorProperty() {
+			public Color getValue()				{ return value(context); }
+			public Color valueAtTime(double t)	{ return AnimatableColor.this.valueAtTime(t, context); }
 		};
+		return context.toNativeJavaObject(cp, null);
 	}
 
 }
