@@ -44,10 +44,10 @@ public class AnimatableString extends AbstractAnimatableValue<String> implements
 		return (String) Context.jsToJava(jsValue, String.class);
 	}
 
-	public StringProperty createExpressionElement(final RenderContext renderContext) {
+	public StringProperty createExpressionElement(final CoreContext context) {
 		return new StringProperty() {
-			public String getValue()			{ return value(renderContext); }
-			public String valueAtTime(double t)	{ return AnimatableString.this.valueAtTime(t, renderContext); }
+			public String getValue()			{ return value(context); }
+			public String valueAtTime(double t)	{ return AnimatableString.this.valueAtTime(t, context); }
 		};
 	}
 
