@@ -26,13 +26,15 @@ package ch.kuramo.javie.core;
 import java.util.Collection;
 
 import org.mozilla.javascript.Context;
-import org.mozilla.javascript.NativeJavaArray;
-import org.mozilla.javascript.ScriptRuntime;
+import org.mozilla.javascript.NativeArray;
 import org.mozilla.javascript.Scriptable;
+import org.mozilla.javascript.Wrapper;
 
 import ch.kuramo.javie.api.IAnimatableVec2d;
 import ch.kuramo.javie.api.Vec2d;
-import ch.kuramo.javie.core.exprelems.DoubleProperty;
+import ch.kuramo.javie.api.Vec3d;
+import ch.kuramo.javie.core.exprelems.Vec2dProperty;
+import ch.kuramo.javie.core.exprelems.Vec3dProperty;
 
 public class AnimatableVec2d extends ArithmeticalAnimatableValue<Vec2d> implements IAnimatableVec2d {
 
@@ -54,18 +56,32 @@ public class AnimatableVec2d extends ArithmeticalAnimatableValue<Vec2d> implemen
 	}
 
 	public Vec2d jsToJava(Object jsValue) {
-		if (jsValue instanceof NativeJavaArray) {
-			// Vec2dの値をそのまま参照した場合 (例: thisComp.layer(3).audioLevels)
-			// (Vec3dの値も参照可能)
+		if (jsValue instanceof Wrapper) {
+			Object javaObj = ((Wrapper) jsValue).unwrap();
 
-			Object[] value = (Object[]) ((NativeJavaArray) jsValue).unwrap();
-			double[] array = new double[2];
-			for (int i = 0, n = Math.min(2, value.length); i < n; ++i) {
-				array[i] = (Double) Context.jsToJava(value[i], double.class);
+			if (javaObj instanceof Vec2dProperty) {
+				javaObj = ((Vec2dProperty) javaObj).getValue();
+			} else if (javaObj instanceof Vec3dProperty) {
+				javaObj = ((Vec3dProperty) javaObj).getValue();
 			}
-			return valueOf(array);
 
-		} else /*if (jsValue instanceof NativeArray)*/ {
+			if (javaObj instanceof Vec2d) {
+				return (Vec2d) javaObj;
+
+			} else if (javaObj instanceof Vec3d) {
+				Vec3d v3d = (Vec3d) javaObj;
+				return new Vec2d(v3d.x, v3d.y);
+
+			} else if (javaObj instanceof Object[]) {
+				Object[] value = (Object[]) javaObj;
+				double[] array = new double[2];
+				for (int i = 0, n = Math.min(2, value.length); i < n; ++i) {
+					array[i] = (Double) Context.jsToJava(value[i], double.class);
+				}
+				return valueOf(array);
+			}
+
+		} else if (jsValue instanceof NativeArray) {
 			// 配列表現を用いた場合 (例: [time*10, 200])
 
 			double[] array = (double[]) Context.jsToJava(jsValue, double[].class);
@@ -77,7 +93,13 @@ public class AnimatableVec2d extends ArithmeticalAnimatableValue<Vec2d> implemen
 				}
 			}
 			return valueOf(array);
+
+		} else if (jsValue == null) {
+			return Vec2d.ZERO;
 		}
+
+		double d = (Double) Context.jsToJava(jsValue, double.class);
+		return new Vec2d(d, d);
 	}
 
 	@Override
@@ -90,21 +112,12 @@ public class AnimatableVec2d extends ArithmeticalAnimatableValue<Vec2d> implemen
 		return new Vec2d(d[0], d[1]);
 	}
 
-	public Scriptable[] createExpressionElement(final RenderContext renderContext) {
-		DoubleProperty x = new DoubleProperty() {
-			public double getValue()			{ return value(renderContext).x; }
-			public double valueAtTime(double t)	{ return AnimatableVec2d.this.valueAtTime(t, renderContext).x; }
-		};
-
-		DoubleProperty y = new DoubleProperty() {
-			public double getValue()			{ return value(renderContext).y; }
-			public double valueAtTime(double t)	{ return AnimatableVec2d.this.valueAtTime(t, renderContext).y; }
-		};
-
-		return new Scriptable[] {
-				renderContext.toNativeJavaObject(x, ScriptRuntime.NumberClass),
-				renderContext.toNativeJavaObject(y, ScriptRuntime.NumberClass)
+	public Scriptable createExpressionElement(final CoreContext context) {
+		Vec2dProperty v2p = new Vec2dProperty() {
+			public Vec2d getValue()				{ return value(context); }
+			public Vec2d valueAtTime(double t)	{ return AnimatableVec2d.this.valueAtTime(t, context); }
 		};
+		return context.toNativeJavaObject(v2p, null);
 	}
 
 }
