@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -24,6 +24,7 @@
 package ch.kuramo.javie.core;
 
 import ch.kuramo.javie.api.Size2i;
+import ch.kuramo.javie.api.Vec3d;
 
 public interface Camera {
 
@@ -37,4 +38,6 @@ public interface Camera {
 
 	double[] getProjection3D();
 
+	Vec3d getPosition();
+
 }
