@@ -40,7 +40,7 @@ public interface MediaInput {
 
 	VideoBounds getVideoFrameBounds();
 
-	VideoBuffer getVideoFrameImage(Time mediaTime);
+	VideoBuffer getVideoFrame(Time mediaTime);
 
 	AudioBuffer getAudioChunk(Time mediaTime);
 
