@@ -70,8 +70,9 @@ public interface MediaLayer extends TransformableLayer, EffectableLayer {
 
 	void setupVideoRenderer(
 			VideoLayerComposer composer, Camera camera, CollapseTransformation ct,
-			MotionBlur motionBlur, boolean frameBlendEnabled);
+			MotionBlur motionBlur, boolean frameBlendEnabled,
+			boolean withEffects, boolean withTransformation);
 
-	AudioBuffer renderAudioChunk();
+	AudioBuffer renderAudioChunk(boolean withEffects, boolean withLevelsAndInOut);
 
 }
