@@ -29,7 +29,7 @@ import java.util.List;
 import ch.kuramo.javie.api.AudioMode;
 import ch.kuramo.javie.api.ColorMode;
 import ch.kuramo.javie.api.IObjectArray;
-import ch.kuramo.javie.api.RenderResolution;
+import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.Vec2d;
@@ -44,6 +44,8 @@ import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.BlendMode;
 import ch.kuramo.javie.core.Camera;
 import ch.kuramo.javie.core.CollapseTransformation;
+import ch.kuramo.javie.core.Composition;
+import ch.kuramo.javie.core.CoreContext;
 import ch.kuramo.javie.core.DepthBuffer;
 import ch.kuramo.javie.core.Effect;
 import ch.kuramo.javie.core.ExpressionScope;
@@ -55,7 +57,6 @@ import ch.kuramo.javie.core.MediaLayer;
 import ch.kuramo.javie.core.MotionBlur;
 import ch.kuramo.javie.core.Project;
 import ch.kuramo.javie.core.ProjectDecodeException;
-import ch.kuramo.javie.core.RenderContext;
 import ch.kuramo.javie.core.TrackMatte;
 import ch.kuramo.javie.core.Util;
 import ch.kuramo.javie.core.VectorMediaInput;
@@ -65,11 +66,10 @@ import ch.kuramo.javie.core.VideoLayerComposer;
 import ch.kuramo.javie.core.VideoLayerRenderer;
 import ch.kuramo.javie.core.WrappedOperation;
 import ch.kuramo.javie.core.services.AudioEffectPipeline;
-import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
 import ch.kuramo.javie.core.services.GLGlobal;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoEffectPipeline;
-import ch.kuramo.javie.core.services.VideoRenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
@@ -105,7 +105,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	private AnimatableDouble _timeRemap = new AnimatableDouble(0.0);
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private VideoRenderSupport _vrSupport;
@@ -116,9 +116,6 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	@Inject
 	private GLGlobal _glGlobal;
 
-	@Inject
-	private AudioRenderContext _arContext;
-
 	@Inject
 	private AudioRenderSupport _arSupport;
 
@@ -290,9 +287,10 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 
 	public void setupVideoRenderer(
 			VideoLayerComposer composer, Camera camera, CollapseTransformation ct,
-			MotionBlur motinBlur, boolean frameBlendEnabled) {
+			MotionBlur motinBlur, boolean frameBlendEnabled,
+			boolean withEffects, boolean withTransformation) {
 
-		// トラックマット適用時にこのチェックがあるとまずいので。同じチェックはコンポ側でもしている。
+		// トラックマット適用時やエフェクトからの参照時にこのチェックがあるとまずいので。同じチェックはコンポ側でもしている。
 		//if (!LayerNature.isVideoEnabled(this)) {
 		//	return;
 		//}
@@ -303,9 +301,9 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		}
 
 		if (isVectorLayer() && LayerNature.isCTCR(this)) {
-			setupVideoRendererCR(composer, camera, ct, motinBlur);
+			setupVideoRendererCR(composer, camera, ct, motinBlur, withEffects);
 		} else {
-			setupVideoRendererNormal(composer, camera, ct, motinBlur, frameBlendEnabled);
+			setupVideoRendererNormal(composer, camera, ct, motinBlur, frameBlendEnabled, withEffects, withTransformation);
 		}
 	}
 
@@ -313,10 +311,10 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		Time time;
 
 		if (LayerNature.isTimeRemapEnabled(this)) {
-			double t0 = _timeRemap.value(_vrContext);
+			double t0 = _timeRemap.value(_context);
 
-			Time ctxTime = _vrContext.getTime();
-			double t1 = _timeRemap.valueAtTime(new Time(ctxTime.timeValue + 1, ctxTime.timeScale), _vrContext);
+			Time ctxTime = _context.getTime();
+			double t1 = _timeRemap.valueAtTime(new Time(ctxTime.timeValue + 1, ctxTime.timeScale), _context);
 
 			Time mediaFrameDuration = input.getVideoFrameDuration();
 			int mediaTimeScale = mediaFrameDuration.timeScale;
@@ -329,7 +327,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			}
 
 		} else {
-			time = _vrContext.getTime().subtract(getStartTime());
+			time = _context.getTime().subtract(getStartTime());
 
 			double rate = getRate();
 			Time mediaFrameDuration = input.getVideoFrameDuration();
@@ -362,38 +360,49 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 
 	private void setupVideoRendererNormal(
 			VideoLayerComposer composer, final Camera camera, final CollapseTransformation ct,
-			final MotionBlur motionBlur, final boolean frameBlendEnabled) {
+			final MotionBlur motionBlur, final boolean frameBlendEnabled,
+			final boolean withEffects, final boolean withTransformation) {
 
 		final MediaInput input = getMediaInput();
-		final RenderResolution resolution = _vrContext.getRenderResolution();
+		final Resolution resolution = _context.getVideoResolution();
 
-		WrappedOperation<VideoBounds> inputBoundsOperation = new WrappedOperation<VideoBounds>() {
+		final WrappedOperation<VideoBounds> inputBoundsOperation = new WrappedOperation<VideoBounds>() {
 			public VideoBounds execute() {
 				return resolution.scale(input.getVideoFrameBounds());
 			}
 		};
 
-		VideoBounds bounds = _vePipeline.getVideoBounds(
-				_effectsEnabled ? _effects : Collections.<Effect>emptyList(), inputBoundsOperation);
+		final List<Effect> effects = (withEffects && _effectsEnabled) ? _effects : Collections.<Effect>emptyList();
+
+		VideoBounds bounds = _vePipeline.getVideoBounds(effects, inputBoundsOperation);
 		final Vec2d offset = new Vec2d(-bounds.x/resolution.scale, -bounds.y/resolution.scale);
 
-		final double[] mvMatrix = new double[16];
-		final double[] prjMatrix = new double[16];
-		createMatrix(camera, ct, offset, mvMatrix, prjMatrix);
+		final double[] mvMatrix;
+		final double[] prjMatrix;
+		if (withTransformation) {
+			mvMatrix = new double[16];
+			prjMatrix = new double[16];
+			createMatrix(camera, ct, offset, mvMatrix, prjMatrix);
+		} else {
+			mvMatrix = null;
+			prjMatrix = null;
+		}
 
 
-		final Time time = _vrContext.getTime();
+		final Time time = _context.getTime();
+		final Composition comp = _context.getComposition();
 
 		VideoLayerRenderer r = new VideoLayerRenderer() {
 			public VideoLayerBuffer render(boolean withDepthBuffer) {
-				// コラップスしているときはここで時刻を再度設定する必要がある。
-				_vrContext.setTime(time);
+				// コラップスしているときはここで時刻とコンポを再度設定する必要がある。
+				_context.setTime(time);
+				_context.setComposition(comp);
 
 				final double opacity;
 				if (ct == null) {
-					opacity = _opacity.value(_vrContext) / 100d;
+					opacity = _opacity.value(_context) / 100d;
 				} else {
-					opacity = _opacity.value(_vrContext) / 100d * ct.getOpacity();
+					opacity = _opacity.value(_context) / 100d * ct.getOpacity();
 				}
 
 				VideoBuffer effectedBuffer = null;
@@ -408,41 +417,49 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 									return blendFrames(frameBlend);
 								}
 							}
-							return input.getVideoFrameImage(calcVideoMediaTime(input));
+							return input.getVideoFrame(calcVideoMediaTime(input));
 						}
 					};
 
-					effectedBuffer = _vePipeline.doVideoEffects(
-							_effectsEnabled ? _effects : Collections.<Effect>emptyList(), inputBufferOperation);
+					effectedBuffer = _vePipeline.doVideoEffects(effects, inputBoundsOperation, inputBufferOperation);
 
-					if (motionBlur != null && LayerNature.isMotionBlurEnabled(AbstractMediaLayer.this)) {
-						if (withDepthBuffer) {
-							depthBuffer = _vrSupport.createDepthBuffer(camera.getViewportSize());
-							_vrSupport.fillDepth(depthBuffer, mvMatrix, prjMatrix);
-						}
-
-						final VideoBuffer mblurSrcBuf = effectedBuffer;
-						MotionBlurSampler sampler = new MotionBlurSampler() {
-							public void sample(double[] mvMatrix, double[] prjMatrix, VideoBuffer buffer) {
-								_vrSupport.transform(mblurSrcBuf, buffer, null, mvMatrix, prjMatrix);
+					if (withTransformation) {
+						if (motionBlur != null && LayerNature.isMotionBlurEnabled(AbstractMediaLayer.this)) {
+							if (withDepthBuffer) {
+								depthBuffer = _vrSupport.createDepthBuffer(camera.getViewportSize());
+								_vrSupport.fillDepth(depthBuffer, mvMatrix, prjMatrix);
 							}
-						};
-						trnsfrmdBuffer = renderWithMotionBlur(camera, ct, motionBlur, offset, time, sampler);
 
-					} else {
-						trnsfrmdBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), camera.getViewportSize());
-						trnsfrmdBuffer.allocateAsTexture();
-						trnsfrmdBuffer.clear();
+							final VideoBuffer mblurSrcBuf = effectedBuffer;
+							MotionBlurSampler sampler = new MotionBlurSampler() {
+								public void sample(double[] mvMatrix, double[] prjMatrix, VideoBuffer buffer) {
+									_vrSupport.transform(mblurSrcBuf, buffer, null, mvMatrix, prjMatrix);
+								}
+							};
+							trnsfrmdBuffer = renderWithMotionBlur(camera, ct, motionBlur, offset, time, sampler);
 
-						if (withDepthBuffer) {
-							depthBuffer = _vrSupport.createDepthBuffer(camera.getViewportSize());
-							_vrSupport.transform(effectedBuffer, trnsfrmdBuffer, depthBuffer, mvMatrix, prjMatrix);
 						} else {
-							_vrSupport.transform(effectedBuffer, trnsfrmdBuffer, null, mvMatrix, prjMatrix);
+							trnsfrmdBuffer = _vrSupport.createVideoBuffer(_context.getColorMode(), camera.getViewportSize());
+							trnsfrmdBuffer.allocateAsTexture();
+							trnsfrmdBuffer.clear();
+
+							if (withDepthBuffer) {
+								depthBuffer = _vrSupport.createDepthBuffer(camera.getViewportSize());
+								_vrSupport.transform(effectedBuffer, trnsfrmdBuffer, depthBuffer, mvMatrix, prjMatrix);
+							} else {
+								_vrSupport.transform(effectedBuffer, trnsfrmdBuffer, null, mvMatrix, prjMatrix);
+							}
 						}
+					} else {
+						if (withDepthBuffer) {
+							throw new IllegalArgumentException("can't create DepthBuffer when withTransformation is false");
+						}
+						trnsfrmdBuffer = effectedBuffer;
+						effectedBuffer = null;
 					}
 
-					VideoLayerBuffer vlb = new VideoLayerBufferImpl(trnsfrmdBuffer, depthBuffer, _blendMode, opacity);
+					VideoLayerBuffer vlb = new VideoLayerBufferImpl(trnsfrmdBuffer, depthBuffer,
+							_blendMode, opacity, getId().hashCode() + getName().hashCode());
 					trnsfrmdBuffer = null;
 					depthBuffer = null;
 					return vlb;
@@ -455,8 +472,8 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			}
 		};
 
-		if (LayerNature.isThreeD(this)) {
-			Vec2d depthBase2d = _depthBase.value(_vrContext);
+		if (withTransformation && LayerNature.isThreeD(this)) {
+			Vec2d depthBase2d = _depthBase.value(_context);
 			Vec3d depthBase = new Vec3d(depthBase2d.x + offset.x, depthBase2d.y + offset.y);
 			depthBase = resolution.scale(depthBase);
 
@@ -468,7 +485,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 				_vrSupport.project(new Vec3d(bounds.x + bounds.width, bounds.y + bounds.height), mvMatrix, prjMatrix, vp),
 				_vrSupport.project(new Vec3d(bounds.x               , bounds.y + bounds.height), mvMatrix, prjMatrix, vp)
 			};
-			composer.add3D(r, vertices, _intersectionGroup.value(_vrContext));
+			composer.add3D(r, vertices, _intersectionGroup.value(_context));
 
 		} else {
 			composer.add2D(r);
@@ -476,10 +493,11 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	}
 
 	private void setupVideoRendererCR(
-			VideoLayerComposer composer, final Camera camera, final CollapseTransformation ct, final MotionBlur motionBlur) {
+			VideoLayerComposer composer, final Camera camera, final CollapseTransformation ct,
+			final MotionBlur motionBlur, final boolean withEffects) {
 
 		final VectorMediaInput input = (VectorMediaInput) getMediaInput();
-		RenderResolution resolution = _vrContext.getRenderResolution();
+		Resolution resolution = _context.getVideoResolution();
 
 		VideoBounds bounds = resolution.scale(input.getVideoFrameBounds());
 
@@ -488,18 +506,20 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		createMatrix(camera, ct, null, mvMatrix, prjMatrix);
 
 
-		final Time time = _vrContext.getTime();
+		final Time time = _context.getTime();
+		final Composition comp = _context.getComposition();
 
 		VideoLayerRenderer r = new VideoLayerRenderer() {
 			public VideoLayerBuffer render(boolean withDepthBuffer) {
-				// コラップスしているときはここで時刻を再度設定する必要がある。
-				_vrContext.setTime(time);
+				// コラップスしているときはここで時刻とコンポを再度設定する必要がある。
+				_context.setTime(time);
+				_context.setComposition(comp);
 
 				final double opacity;
 				if (ct == null) {
-					opacity = _opacity.value(_vrContext) / 100d;
+					opacity = _opacity.value(_context) / 100d;
 				} else {
-					opacity = _opacity.value(_vrContext) / 100d * ct.getOpacity();
+					opacity = _opacity.value(_context) / 100d * ct.getOpacity();
 				}
 
 				VideoBuffer effectedBuffer = null;
@@ -511,6 +531,12 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 						_vrSupport.fillDepth(depthBuffer, mvMatrix, prjMatrix);
 					}
 
+					WrappedOperation<VideoBounds> inputBoundsOperation = new WrappedOperation<VideoBounds>() {
+						public VideoBounds execute() {
+							return new VideoBounds(camera.getViewportSize());
+						}
+					};
+
 					WrappedOperation<VideoBuffer> inputBufferOperation = new WrappedOperation<VideoBuffer>() {
 						public VideoBuffer execute() {
 							VideoBuffer rasterizedBuffer = null;
@@ -521,10 +547,10 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 											input.rasterize(buffer, mvMatrix, prjMatrix, calcVideoMediaTime(input));
 										}
 									};
-									rasterizedBuffer = renderWithMotionBlur(camera, ct, motionBlur, null, _vrContext.getTime(), sampler);
+									rasterizedBuffer = renderWithMotionBlur(camera, ct, motionBlur, null, _context.getTime(), sampler);
 
 								} else {
-									rasterizedBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), camera.getViewportSize());
+									rasterizedBuffer = _vrSupport.createVideoBuffer(_context.getColorMode(), camera.getViewportSize());
 									rasterizedBuffer.allocateAsTexture();
 									rasterizedBuffer.clear();
 
@@ -541,21 +567,27 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 						}
 					};
 
-					effectedBuffer = _vePipeline.doVideoEffects(
-							_effectsEnabled ? _effects : Collections.<Effect>emptyList(), inputBufferOperation);
+					if (withEffects) {
+						effectedBuffer = _vePipeline.doVideoEffects(
+								_effectsEnabled ? _effects : Collections.<Effect>emptyList(),
+								inputBoundsOperation, inputBufferOperation);
 
-					VideoBounds resultBounds = new VideoBounds(camera.getViewportSize());
-					if (effectedBuffer.getBounds().equals(resultBounds)) {
-						resultBuffer = effectedBuffer;
-						effectedBuffer = null;
+						VideoBounds resultBounds = new VideoBounds(camera.getViewportSize());
+						if (effectedBuffer.getBounds().equals(resultBounds)) {
+							resultBuffer = effectedBuffer;
+							effectedBuffer = null;
+						} else {
+							resultBuffer = _vrSupport.createVideoBuffer(_context.getColorMode(), resultBounds);
+							resultBuffer.allocateAsTexture();
+							resultBuffer.clear();
+							_vrSupport.copy(effectedBuffer, resultBuffer);
+						}
 					} else {
-						resultBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), resultBounds);
-						resultBuffer.allocateAsTexture();
-						resultBuffer.clear();
-						_vrSupport.copy(effectedBuffer, resultBuffer);
+						resultBuffer = _context.saveAndExecute(inputBufferOperation);
 					}
 
-					VideoLayerBuffer vlb = new VideoLayerBufferImpl(resultBuffer, depthBuffer, _blendMode, opacity);
+					VideoLayerBuffer vlb = new VideoLayerBufferImpl(resultBuffer, depthBuffer,
+							_blendMode, opacity, getId().hashCode() + getName().hashCode());
 					resultBuffer = null;
 					depthBuffer = null;
 					return vlb;
@@ -569,7 +601,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		};
 
 		if (LayerNature.isThreeD(this)) {
-			Vec2d depthBase2d = _depthBase.value(_vrContext);
+			Vec2d depthBase2d = _depthBase.value(_context);
 			Vec3d depthBase = new Vec3d(depthBase2d.x, depthBase2d.y);
 			depthBase = resolution.scale(depthBase);
 
@@ -581,7 +613,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 				_vrSupport.project(new Vec3d(bounds.x + bounds.width, bounds.y + bounds.height), mvMatrix, prjMatrix, vp),
 				_vrSupport.project(new Vec3d(bounds.x               , bounds.y + bounds.height), mvMatrix, prjMatrix, vp)
 			};
-			composer.add3D(r, vertices, _intersectionGroup.value(_vrContext));
+			composer.add3D(r, vertices, _intersectionGroup.value(_context));
 
 		} else {
 			composer.add2D(r);
@@ -602,7 +634,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 					_vrSupport.setMatrix(camera.getModelView2D(), camera.getProjection2D());
 				}
 
-				LayerMatrixUtil.multModelViewMatrix(AbstractMediaLayer.this, offset, ct, _vrContext, _vrSupport);
+				LayerMatrixUtil.multModelViewMatrix(AbstractMediaLayer.this, offset, ct, _context, _vrSupport);
 
 				_vrSupport.getMatrix(mvMatrix, prjMatrix);
 				return null;
@@ -619,16 +651,16 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		MediaInput input = getMediaInput();
 		Time mediaFrameDuration = input.getVideoFrameDuration();
 
-		Time ctxTime = _vrContext.getTime();
+		Time ctxTime = _context.getTime();
 		Time mediaTime0 = calcVideoMediaTime(input);
-		_vrContext.setTime(ctxTime.add(_vrContext.getFrameDuration()));
+		_context.setTime(ctxTime.add(_context.getVideoFrameDuration()));
 		Time mediaTime1 = calcVideoMediaTime(input);
-		_vrContext.setTime(ctxTime);
+		_context.setTime(ctxTime);
 
 		Time mediaTimeDiff = mediaTime1.subtract(mediaTime0);
 		double fpsRatio = mediaTimeDiff.toSecond() / mediaFrameDuration.toSecond();
 		if (fpsRatio == 1) {
-			return input.getVideoFrameImage(ctxTime);
+			return input.getVideoFrame(ctxTime);
 		}
 
 		fpsRatio = Math.abs(fpsRatio);
@@ -637,7 +669,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		List<VideoBuffer> buffers = Util.newList();
 		VideoBuffer buf32f = null;
 		try {
-			RenderResolution resolution = _vrContext.getRenderResolution();
+			Resolution resolution = _context.getVideoResolution();
 			VideoBounds bounds = resolution.scale(input.getVideoFrameBounds());
 
 			buf32f = _vrSupport.createVideoBuffer(ColorMode.RGBA32_FLOAT, bounds);
@@ -670,7 +702,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 				for (int n = intWeights.size(), i = -n+1; i < n; ++i) {
 					Time t = mediaTime0.add(new Time(mediaFrameDuration.timeValue*i, mediaFrameDuration.timeScale));
 
-					buffers.add(input.getVideoFrameImage(t));
+					buffers.add(input.getVideoFrame(t));
 					weights.add(intWeights.get(Math.abs(i))/255.0);
 
 					if (buffers.size() >= maxUnits) {
@@ -693,7 +725,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 				long tv0 = mediaTime0.subtract(t0).timeValue;
 				long tv1 = t1.subtract(mediaTime0).timeValue;
 
-				buffers.add(input.getVideoFrameImage(t0));
+				buffers.add(input.getVideoFrame(t0));
 				weights.add((double)tv1/(tv0+tv1));
 
 				// maxUnitsが1の場合はあるのか？　無いのなら次のifブロックは不要。
@@ -704,7 +736,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 					weights.clear();
 				}
 
-				buffers.add(input.getVideoFrameImage(t1));
+				buffers.add(input.getVideoFrame(t1));
 				weights.add((double)tv0/(tv0+tv1));
 			}
 			if (!buffers.isEmpty()) {
@@ -712,11 +744,11 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			}
 
 			VideoBuffer resultBuffer;
-			if (_vrContext.getColorMode() == ColorMode.RGBA32_FLOAT) {
+			if (_context.getColorMode() == ColorMode.RGBA32_FLOAT) {
 				resultBuffer = buf32f;
 				buf32f = null;
 			} else {
-				resultBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), buf32f.getBounds());
+				resultBuffer = _vrSupport.createVideoBuffer(_context.getColorMode(), buf32f.getBounds());
 				resultBuffer.allocateAsTexture();
 				_vrSupport.copy(buf32f, resultBuffer);
 			}
@@ -746,7 +778,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			double shutterAngle = motionBlur.getShutterAngle();
 			double shutterPhase = motionBlur.getShutterPhase();
 			int samples = motionBlur.getSamples();
-			Time frameDuration = _vrContext.getFrameDuration();
+			Time frameDuration = _context.getVideoFrameDuration();
 			int maxUnits = _glGlobal.getMaxTextureImageUnits();
 
 			double[] mvMatrix = new double[16];
@@ -755,11 +787,11 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			for (int i = 0; i < samples; ++i) {
 				double angle = shutterPhase + shutterAngle*i/samples;
 				Time t = time.add(new Time((long)(frameDuration.timeValue*angle/360), frameDuration.timeScale));
-				_vrContext.setTime(t);
+				_context.setTime(t);
 
 				createMatrix(camera, ct, offset, mvMatrix, prjMatrix);
 
-				buf = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), camera.getViewportSize());
+				buf = _vrSupport.createVideoBuffer(_context.getColorMode(), camera.getViewportSize());
 				buf.allocateAsTexture();
 				buf.clear();
 
@@ -779,11 +811,11 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			}
 
 			VideoBuffer resultBuffer;
-			if (_vrContext.getColorMode() == ColorMode.RGBA32_FLOAT) {
+			if (_context.getColorMode() == ColorMode.RGBA32_FLOAT) {
 				resultBuffer = buf32f;
 				buf32f = null;
 			} else {
-				resultBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), buf32f.getBounds());
+				resultBuffer = _vrSupport.createVideoBuffer(_context.getColorMode(), buf32f.getBounds());
 				resultBuffer.allocateAsTexture();
 				_vrSupport.copy(buf32f, resultBuffer);
 			}
@@ -802,13 +834,13 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		IObjectArray<Double> times = null;
 
 		try {
-			AudioMode audioMode = _arContext.getAudioMode();
+			AudioMode audioMode = _context.getAudioMode();
 			int sampleRate = audioMode.sampleRate;
 
 			ab1 = _arSupport.createAudioBuffer();
 
 			times = _arrayPools.getObjectArray(ab1.getFrameCount());
-			_timeRemap.values(times, audioMode.sampleDuration, _arContext.getEvaluationResolution(), _arContext);
+			_timeRemap.values(times, audioMode.sampleDuration, _context.getAudioAnimationRate(), _context);
 
 
 			// 音声データを取得する範囲を求める。
@@ -823,7 +855,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 
 
 			// 上で求めた範囲の音声データをMediaInputから取得。
-			_arContext.setFrameCount((int)(timeValueMax - timeValueMin) + 1);
+			_context.setAudioFrameCount((int)(timeValueMax - timeValueMin) + 1);
 
 			ab2 = input.getAudioChunk(new Time(timeValueMin, sampleRate));
 			if (ab2 == null) return null;
@@ -884,7 +916,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		AudioBuffer ab2 = null;
 
 		try {
-			AudioMode audioMode = _arContext.getAudioMode();
+			AudioMode audioMode = _context.getAudioMode();
 			int sampleRate = audioMode.sampleRate;
 
 			ab1 = _arSupport.createAudioBuffer();
@@ -896,17 +928,17 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			if (rate >= 0) {
 				timeValueMin = (long) Math.floor(time.toSecond() * sampleRate * rate);
 
-				Time t = time.add(new Time(_arContext.getFrameCount(), sampleRate));
+				Time t = time.add(new Time(_context.getAudioFrameCount(), sampleRate));
 				timeValueMax = (long) Math.ceil(t.toSecond() * sampleRate * rate);
 
 			} else {
 				timeValueMax =  (long) Math.ceil(duration * sampleRate + time.toSecond() * sampleRate * rate);
 
-				Time t = time.add(new Time(_arContext.getFrameCount(), sampleRate));
+				Time t = time.add(new Time(_context.getAudioFrameCount(), sampleRate));
 				timeValueMin = (long) Math.floor(duration * sampleRate + t.toSecond() * sampleRate * rate);
 			}
 
-			_arContext.setFrameCount((int)(timeValueMax - timeValueMin) + 1);
+			_context.setAudioFrameCount((int)(timeValueMax - timeValueMin) + 1);
 
 			ab2 = input.getAudioChunk(new Time(timeValueMin, sampleRate));
 			if (ab2 == null) return null;
@@ -963,10 +995,11 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		}
 	}
 
-	public AudioBuffer renderAudioChunk() {
-		if (!LayerNature.isAudioEnabled(this)) {
-			return null;
-		}
+	public AudioBuffer renderAudioChunk(boolean withEffects, boolean withLevelsAndInOut) {
+		// エフェクトからの参照時にこのチェックがあるとまずいので。同じチェックはコンポ側でもしている。
+		//if (!LayerNature.isAudioEnabled(this)) {
+		//	return null;
+		//}
 
 		final MediaInput input = getMediaInput();
 		if (input == null || !input.isAudioAvailable()) {
@@ -979,7 +1012,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 					return getTimeRemappedAudioChunk(input);
 
 				} else {
-					Time time = _arContext.getTime().subtract(getStartTime());
+					Time time = _context.getTime().subtract(getStartTime());
 					double rate = getRate();
 					if (rate == 1.0) {
 						return input.getAudioChunk(time);
@@ -991,38 +1024,41 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		};
 
 		AudioBuffer ab = _aePipeline.doAudioEffects(
-				_effectsEnabled ? _effects : Collections.<Effect>emptyList(), inputOperation);
+				(withEffects && _effectsEnabled) ? _effects : Collections.<Effect>emptyList(), inputOperation);
 
-		if (_audioLevels.hasKeyframe() || _audioLevels.getExpression() != null
-				|| !_audioLevels.getStaticValue().equals(Vec2d.ZERO)) {
+		if (withLevelsAndInOut) {
+			if (_audioLevels.hasKeyframe() || _audioLevels.getExpression() != null
+					|| !_audioLevels.getStaticValue().equals(Vec2d.ZERO)) {
 
-			IObjectArray<Vec2d> audioLevels = _arrayPools.getObjectArray(ab.getFrameCount());
+				IObjectArray<Vec2d> audioLevels = _arrayPools.getObjectArray(ab.getFrameCount());
 
-			_audioLevels.values(audioLevels, ab.getAudioMode().sampleDuration,
-								_arContext.getEvaluationResolution(), _arContext);
-			_arSupport.amplify(ab, audioLevels);
+				_audioLevels.values(audioLevels, ab.getAudioMode().sampleDuration,
+									_context.getAudioAnimationRate(), _context);
+				_arSupport.amplify(ab, audioLevels);
 
-			audioLevels.release();
-		}
+				audioLevels.release();
+			}
 
-		// インポイントよりも手前とアウトポイント以降はゼロクリアする
-		Time time = _arContext.getTime();
-		Time sampleDuration = _arContext.getAudioMode().sampleDuration;
+			// インポイントよりも手前とアウトポイント以降はゼロクリアする
+			Time time = _context.getTime();
+			Time sampleDuration = _context.getAudioMode().sampleDuration;
 
-		int clearFrameCount = (int) getInPoint().subtract(time).toFrameNumber(sampleDuration);
-		if (clearFrameCount > 0) {
-			_arSupport.clear(ab, 0, clearFrameCount);
-		}
+			int clearFrameCount = (int) getInPoint().subtract(time).toFrameNumber(sampleDuration);
+			if (clearFrameCount > 0) {
+				_arSupport.clear(ab, 0, clearFrameCount);
+			}
 
-		int clearFrameOffset = (int) getOutPoint().subtract(time).toFrameNumber(sampleDuration);
-		clearFrameCount = _arContext.getFrameCount() - clearFrameOffset;
-		if (clearFrameCount > 0) {
-			_arSupport.clear(ab, clearFrameOffset, clearFrameCount);
+			int clearFrameOffset = (int) getOutPoint().subtract(time).toFrameNumber(sampleDuration);
+			clearFrameCount = _context.getAudioFrameCount() - clearFrameOffset;
+			if (clearFrameCount > 0) {
+				_arSupport.clear(ab, clearFrameOffset, clearFrameCount);
+			}
 		}
 
 		return ab;
 	}
 
+	@Override
 	public void afterDecode(Project p, LayerComposition c) throws ProjectDecodeException {
 		super.afterDecode(p, c);
 
@@ -1031,14 +1067,14 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		}
 	}
 
-	public Object createExpressionElement(RenderContext renderContext) {
-		return new MediaLayerExpressionElement(renderContext);
+	public Object createExpressionElement(CoreContext context) {
+		return new MediaLayerExpressionElement(context);
 	}
 
 	public class MediaLayerExpressionElement extends TransformableLayerExpressionElement {
 
-		public MediaLayerExpressionElement(RenderContext renderContext) {
-			super(renderContext);
+		public MediaLayerExpressionElement(CoreContext context) {
+			super(context);
 		}
 
 		public Object getDepthBase()			{ return elem(_depthBase); }
@@ -1049,7 +1085,16 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 
 		public Object effect(int index) {
 			Effect effect = _effects.get(index - 1);
-			return renderContext.getExpressionElement(effect);
+			return context.getExpressionElement(effect);
+		}
+
+		public Object effect(String name) {
+			for (Effect e : _effects) {
+				if (e.getName().equals(name)) {
+					return context.getExpressionElement(e);
+				}
+			}
+			return null;
 		}
 	}
 
