@@ -37,8 +37,7 @@ import ch.kuramo.javie.core.ProjectDecodeException;
 import ch.kuramo.javie.core.VideoBuffer;
 import ch.kuramo.javie.core.WrappedOperation;
 import ch.kuramo.javie.core.annotations.ProjectElement;
-import ch.kuramo.javie.core.services.AudioRenderContext;
-import ch.kuramo.javie.core.services.VideoRenderContext;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
@@ -53,14 +52,11 @@ public class CompositionItemImpl extends AbstractItem implements CompositionItem
 	private final CompositionInput _input = new CompositionInput();
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private VideoRenderSupport _vrSupport;
 
-	@Inject
-	private AudioRenderContext _arContext;
-
 
 	public CompositionItemImpl() {
 		super();
@@ -140,10 +136,10 @@ public class CompositionItemImpl extends AbstractItem implements CompositionItem
 			return new VideoBounds(size.width, size.height);  // TODO 毎回newするのは無駄
 		}
 
-		public VideoBuffer getVideoFrameImage(final Time mediaTime) {
-			VideoBuffer vb = _vrContext.saveAndExecute(new WrappedOperation<VideoBuffer>() {
+		public VideoBuffer getVideoFrame(final Time mediaTime) {
+			VideoBuffer vb = _context.saveAndExecute(new WrappedOperation<VideoBuffer>() {
 				public VideoBuffer execute() {
-					_vrContext.setTime(mediaTime);
+					_context.setTime(mediaTime);
 					return _composition.renderVideoFrame();
 				}
 			});
@@ -152,9 +148,9 @@ public class CompositionItemImpl extends AbstractItem implements CompositionItem
 		}
 
 		public AudioBuffer getAudioChunk(final Time mediaTime) {
-			return _arContext.saveAndExecute(new WrappedOperation<AudioBuffer>() {
+			return _context.saveAndExecute(new WrappedOperation<AudioBuffer>() {
 				public AudioBuffer execute() {
-					_arContext.setTime(mediaTime);
+					_context.setTime(mediaTime);
 					return _composition.renderAudioChunk();
 				}
 			});
