@@ -41,14 +41,14 @@ import java.util.concurrent.ConcurrentMap;
 import javax.imageio.ImageIO;
 
 import ch.kuramo.javie.api.ColorMode;
-import ch.kuramo.javie.api.RenderResolution;
+import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.MediaFileInput;
 import ch.kuramo.javie.core.VideoBuffer;
-import ch.kuramo.javie.core.services.VideoRenderContext;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
@@ -75,10 +75,10 @@ public class JavaImageInput implements MediaFileInput {
 	private ColorMode _srcColorMode;
 
 	// TODO キャッシュを実装したらそれを使う。
-	private final ConcurrentMap<RenderResolution, Entry> _cache = new ConcurrentHashMap<RenderResolution, Entry>();
+	private final ConcurrentMap<Resolution, Entry> _cache = new ConcurrentHashMap<Resolution, Entry>();
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private VideoRenderSupport _vrSupport;
@@ -106,7 +106,7 @@ public class JavaImageInput implements MediaFileInput {
 		}
 
 		// TODO 大きな画像の場合には時間がかかるので、バックグラウンドスレッドで処理した方が良いかも。
-		_cache.put(RenderResolution.FULL, new Entry(_srcSize, toInternalFormat(_srcImage, _srcSize)));
+		_cache.put(Resolution.FULL, new Entry(_srcSize, toInternalFormat(_srcImage, _srcSize)));
 
 		return true;
 	}
@@ -150,8 +150,8 @@ public class JavaImageInput implements MediaFileInput {
 		return _srcBounds;
 	}
 
-	public VideoBuffer getVideoFrameImage(Time mediaTime) {
-		RenderResolution resolution = _vrContext.getRenderResolution();
+	public VideoBuffer getVideoFrame(Time mediaTime) {
+		Resolution resolution = _context.getVideoResolution();
 
 		// 以下、_cache に対する get と put がアトミックでないが (_cache自体はConcurrentMap)、
 		// 別スレッドが put で上書きしたとしても、同じ内容で上書きするだけなので支障はない。
@@ -162,7 +162,7 @@ public class JavaImageInput implements MediaFileInput {
 			_cache.put(resolution, entry);
 		}
 
-		ColorMode contextColorMode = _vrContext.getColorMode();
+		ColorMode contextColorMode = _context.getColorMode();
 		VideoBuffer videoBuffer = _vrSupport.createVideoBuffer(contextColorMode, entry.size);
 		videoBuffer.allocateAsTexture();
 
