@@ -46,8 +46,8 @@ import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.JavieRuntimeException;
 import ch.kuramo.javie.core.MediaFileInput;
 import ch.kuramo.javie.core.VideoBuffer;
-import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
+import ch.kuramo.javie.core.services.RenderContext;
 
 import com.google.inject.Inject;
 
@@ -67,7 +67,7 @@ public class JavaSoundInput implements MediaFileInput {
 	private long _streamPosition;
 
 	@Inject
-	private AudioRenderContext _arContext;
+	private RenderContext _context;
 
 	@Inject
 	private AudioRenderSupport _arSupport;
@@ -136,10 +136,10 @@ public class JavaSoundInput implements MediaFileInput {
 
 	public synchronized AudioBuffer getAudioChunk(Time mediaTime) {
 		try {
-			AudioMode audioMode = _arContext.getAudioMode();
+			AudioMode audioMode = _context.getAudioMode();
 			long frameNumber = mediaTime.toFrameNumber(audioMode.sampleDuration);
 
-			if (-frameNumber >= _arContext.getFrameCount() || !mediaTime.before(_duration)) {
+			if (-frameNumber >= _context.getAudioFrameCount() || !mediaTime.before(_duration)) {
 				AudioBuffer ab = _arSupport.createAudioBuffer();
 				_arSupport.clear(ab);
 				return ab;
@@ -170,7 +170,7 @@ public class JavaSoundInput implements MediaFileInput {
 		// 変換の必要が無い場合、AudioSystem.getAudioInputStream は元のストリームをそのまま返すようなので
 		// 以下のように無条件に変換を試みても無駄な変換は発生しないようである。
 
-		_audioMode = _arContext.getAudioMode();
+		_audioMode = _context.getAudioMode();
 		int bits = _audioMode.sampleSize * 8;
 		int ch = _audioMode.channels;
 		boolean bigEndian = ByteOrder.nativeOrder().equals(ByteOrder.BIG_ENDIAN);
@@ -299,7 +299,7 @@ public class JavaSoundInput implements MediaFileInput {
 		throw new UnsupportedOperationException("video is not available");
 	}
 
-	public VideoBuffer getVideoFrameImage(Time mediaTime) {
+	public VideoBuffer getVideoFrame(Time mediaTime) {
 		throw new UnsupportedOperationException("video is not available");
 	}
 
