@@ -30,20 +30,22 @@ import ch.kuramo.javie.api.ColorMode;
 import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.Vec3d;
+import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.core.AbstractComposition;
 import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.Camera;
 import ch.kuramo.javie.core.CameraLayer;
 import ch.kuramo.javie.core.CollapseTransformation;
+import ch.kuramo.javie.core.CoreContext;
 import ch.kuramo.javie.core.ExpressionScope;
 import ch.kuramo.javie.core.Layer;
 import ch.kuramo.javie.core.LayerComposition;
 import ch.kuramo.javie.core.LayerNature;
+import ch.kuramo.javie.core.MediaInput;
 import ch.kuramo.javie.core.MediaLayer;
 import ch.kuramo.javie.core.MotionBlur;
 import ch.kuramo.javie.core.Project;
 import ch.kuramo.javie.core.ProjectDecodeException;
-import ch.kuramo.javie.core.RenderContext;
 import ch.kuramo.javie.core.TrackMatte;
 import ch.kuramo.javie.core.Util;
 import ch.kuramo.javie.core.VideoBuffer;
@@ -52,9 +54,8 @@ import ch.kuramo.javie.core.VideoLayerComposer;
 import ch.kuramo.javie.core.VideoLayerRenderer;
 import ch.kuramo.javie.core.WrappedOperation;
 import ch.kuramo.javie.core.annotations.ProjectElement;
-import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
-import ch.kuramo.javie.core.services.VideoRenderContext;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
@@ -83,14 +84,11 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 	private List<Layer> _layers = Util.newList();
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private VideoRenderSupport _vrSupport;
 
-	@Inject
-	private AudioRenderContext _arContext;
-
 	@Inject
 	private AudioRenderSupport _arSupport;
 
@@ -164,6 +162,16 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 		return null;
 	}
 
+	public Layer getParentLayer(Layer layer) {
+		String parentId = layer.getParentId();
+		return (parentId != null) ? getLayer(parentId) : null;
+	}
+
+	public void setParentLayer(Layer layer, Layer parent) {
+		// 引数のレイヤーと親がどちらもこのコンポジションに属しているかどうかのチェックをすべきか？
+		layer.setParentId((parent != null) ? parent.getId() : null);
+	}
+
 	public void afterDecode(Project p) throws ProjectDecodeException {
 		for (Layer layer : _layers) {
 			layer.afterDecode(p, this);
@@ -179,17 +187,18 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 	}
 
 	public VideoBuffer renderVideoFrame() {
-		ColorMode colorMode = getColorMode();
-		Size2i size = _vrContext.getRenderResolution().scale(getSize());
-		Time time = _vrContext.getTime();
+		_context.setComposition(this);
 
-		_vrContext.setColorMode(colorMode);
+		ColorMode colorMode = getColorMode();
+		_context.setColorMode(colorMode);
+
+		Time time = _context.getTime();
 
 		if (isFrameDurationPreserved()) {
 			Time frameDuration = getFrameDuration();
 			time = Time.fromFrameNumber(time.toFrameNumber(frameDuration), frameDuration);
-			_vrContext.setTime(time);
-			_vrContext.setFrameDuration(frameDuration);
+			_context.setTime(time);
+			_context.setVideoFrameDuration(frameDuration);
 		}
 
 		// 上のレイヤーから(リスト内では末尾から)順に有効なカメラレイヤーを探し、見つかればそれを使う。
@@ -203,11 +212,13 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 			}
 		}
 
+		Size2i renderSize = _context.getVideoResolution().scale(getSize());
+
 		final CameraImpl camera = new CameraImpl(
-				_vrContext, _vrSupport, cameraLayer, getSize(), size);
+				_context, _vrSupport, cameraLayer, getSize(), renderSize);
 
 		final VideoLayerComposerImpl composer = new VideoLayerComposerImpl(
-				_vrContext, _vrSupport, colorMode, size, camera.getPosition());
+				_context, _vrSupport, colorMode, renderSize, camera.getPosition());
 
 		final MotionBlur motionBlur = _motionBlurEnabled ? _motionBlur : null;
 
@@ -233,9 +244,9 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 					}
 				}
 
-				_vrContext.saveAndExecute(new WrappedOperation<Object>() {
+				_context.saveAndExecute(new WrappedOperation<Object>() {
 					public Object execute() {
-						ml.setupVideoRenderer(composer, camera, null, motionBlur, _frameBlendEnabled);
+						ml.setupVideoRenderer(composer, camera, null, motionBlur, _frameBlendEnabled, true, true);
 						return null;
 					}
 				});
@@ -248,7 +259,9 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 	public void setupCollapseTransformation(
 			final VideoLayerComposer composer, final Camera camera, final CollapseTransformation ct, final MotionBlur motionBlur) {
 
-		Time time = _vrContext.getTime();
+		_context.setComposition(this);
+
+		Time time = _context.getTime();
 
 		for (int i = 0, n = _layers.size(); i < n; ++i) {
 			Layer layer = _layers.get(i);
@@ -272,9 +285,9 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 					}
 				}
 
-				_vrContext.saveAndExecute(new WrappedOperation<Object>() {
+				_context.saveAndExecute(new WrappedOperation<Object>() {
 					public Object execute() {
-						ml.setupVideoRenderer(composer, camera, ct, motionBlur, _frameBlendEnabled);
+						ml.setupVideoRenderer(composer, camera, ct, motionBlur, _frameBlendEnabled, true, true);
 						return null;
 					}
 				});
@@ -290,22 +303,22 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 		final Vec3d[][] vertices = new Vec3d[1][];
 		final String[] intersectionGroup = new String[1];
 
-		_vrContext.saveAndExecute(new WrappedOperation<Object>() {
+		_context.saveAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
 				fillLayer.setupVideoRenderer(new VideoLayerComposer() {
 					public void add2D(VideoLayerRenderer r)							{ renderers[0] = r; }
 					public void add3D(VideoLayerRenderer r, Vec3d[] v, String ig)	{ renderers[0] = r; vertices[0] = v; intersectionGroup[0] = ig; }
-				}, camera, ct, motionBlur, _frameBlendEnabled);
+				}, camera, ct, motionBlur, _frameBlendEnabled, true, true);
 				return null;
 			}
 		});
 
-		_vrContext.saveAndExecute(new WrappedOperation<Object>() {
+		_context.saveAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
 				matteLayer.setupVideoRenderer(new VideoLayerComposer() {
 					public void add2D(VideoLayerRenderer r)							{ renderers[1] = r; }
 					public void add3D(VideoLayerRenderer r, Vec3d[] v, String ig)	{ renderers[1] = r; }
-				}, camera, ct, motionBlur, _frameBlendEnabled);
+				}, camera, ct, motionBlur, _frameBlendEnabled, true, true);
 				return null;
 			}
 		});
@@ -341,7 +354,8 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 							trackMatte, matteBuffer.getOpacity());
 
 					VideoLayerBuffer newBuffer = new VideoLayerBufferImpl(
-							resultBuffer, fillBuffer.getDepthBuffer(), fillBuffer.getBlendMode(), fillBuffer.getOpacity());
+							resultBuffer, fillBuffer.getDepthBuffer(),
+							fillBuffer.getBlendMode(), fillBuffer.getOpacity(), fillBuffer.getDissolveSeed());
 					fillBuffer = null;
 					return newBuffer;
 
@@ -368,11 +382,80 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 		}
 	}
 
+	public VideoBuffer getLayerVideoFrame(Layer layer, final boolean withEffects, final boolean withTransformation) {
+		if (_context.getComposition() != this) {
+			throw new IllegalStateException("this composition is not the context composition.");
+		}
+
+		if (layer == null) {
+			throw new NullPointerException();
+		}
+
+		if (!_layers.contains(layer)) {
+			throw new IllegalArgumentException("no such layer found in this LayerComposition");
+		}
+
+		if (!LayerNature.isVideoNature(layer)) {
+			return null;
+		}
+
+		if (layer instanceof MediaLayer) {
+			final MediaLayer ml = (MediaLayer) layer;
+
+			MediaInput input = ml.getMediaInput();
+			if (input == null) {
+				return null;
+			}
+
+			VideoBounds bounds = input.getVideoFrameBounds();
+			Size2i layerSize = LayerNature.isCTCR(layer) ? getSize() : new Size2i(bounds.width, bounds.height);
+			Size2i viewportSize = _context.getVideoResolution().scale(layerSize);
+
+			if (viewportSize.width == 0 || viewportSize.height == 0) {
+				VideoBuffer vb = _vrSupport.createVideoBuffer(_context.getColorMode(), viewportSize);
+				vb.clear();
+				return vb;
+			}
+
+			final VideoLayerRenderer[] renderers = new VideoLayerRenderer[1];
+
+			final VideoLayerComposer composer = new VideoLayerComposer() {
+				public void add2D(VideoLayerRenderer r)							{ renderers[0] = r; }
+				public void add3D(VideoLayerRenderer r, Vec3d[] v, String ig)	{ renderers[0] = r; }
+			};
+
+			final CameraImpl camera = new CameraImpl(
+					_context, _vrSupport, null, layerSize, viewportSize);
+
+			final MotionBlur motionBlur = _motionBlurEnabled ? _motionBlur : null;
+
+			_context.saveAndExecute(new WrappedOperation<Object>() {
+				public Object execute() {
+					ml.setupVideoRenderer(
+							composer, camera, null, motionBlur, _frameBlendEnabled,
+							withEffects, withTransformation);
+					return null;
+				}
+			});
+
+			VideoLayerBuffer vlb = renderers[0].render(false);
+			return vlb.getVideoBuffer();
+		}
+
+		return null;
+	}
+
 	public AudioBuffer renderAudioChunk() {
+		_context.setComposition(this);
+
+		if (isFrameDurationPreserved()) {
+			_context.setVideoFrameDuration(getFrameDuration());
+		}
+
 		AudioBuffer ab = null;
-		Time time = _arContext.getTime();
+		Time time = _context.getTime();
 		Time chunkDuration = Time.fromFrameNumber(
-				_arContext.getFrameCount(), _arContext.getAudioMode().sampleDuration);
+				_context.getAudioFrameCount(), _context.getAudioMode().sampleDuration);
 
 		for (Layer layer : _layers) {
 			if (!LayerNature.isAudioEnabled(layer)) {
@@ -386,9 +469,9 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 			if (layer instanceof MediaLayer) {
 				final MediaLayer al = (MediaLayer) layer;
 
-				AudioBuffer alab = _arContext.saveAndExecute(new WrappedOperation<AudioBuffer>() {
+				AudioBuffer alab = _context.saveAndExecute(new WrappedOperation<AudioBuffer>() {
 					public AudioBuffer execute() {
-						return al.renderAudioChunk();
+						return al.renderAudioChunk(true, true);
 					}
 				});
 
@@ -415,21 +498,66 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 		return ab;
 	}
 
-	public Object createExpressionElement(RenderContext renderContext) {
-		return new LayerCompositionExpressionElement(renderContext);
+	public AudioBuffer getLayerAudioChunk(Layer layer, final boolean withEffects, final boolean withLevelsAndInOut) {
+		if (_context.getComposition() != this) {
+			throw new IllegalStateException("this composition is not the context composition.");
+		}
+
+		if (layer == null) {
+			throw new NullPointerException();
+		}
+
+		if (!_layers.contains(layer)) {
+			throw new IllegalArgumentException("no such layer found in this LayerComposition");
+		}
+
+		if (!LayerNature.isAudioNature(layer)) {
+			return null;
+		}
+
+		if (layer instanceof MediaLayer) {
+			final MediaLayer ml = (MediaLayer) layer;
+
+			MediaInput input = ml.getMediaInput();
+			if (input == null) {
+				return null;
+			}
+
+			return _context.saveAndExecute(new WrappedOperation<AudioBuffer>() {
+				public AudioBuffer execute() {
+					return ml.renderAudioChunk(withEffects, withLevelsAndInOut);
+				}
+			});
+		}
+
+		return null;
+	}
+
+	public Object createExpressionElement(CoreContext context) {
+		return new LayerCompositionExpressionElement(context);
 	}
 
 	public class LayerCompositionExpressionElement {
 
-		protected final RenderContext renderContext;
+		protected final CoreContext context;
 
-		public LayerCompositionExpressionElement(RenderContext renderContext) {
-			this.renderContext = renderContext;
+		public LayerCompositionExpressionElement(CoreContext context) {
+			this.context = context;
 		}
 
 		public Object layer(int index) {
 			Layer layer = _layers.get(_layers.size() - index);
-			return renderContext.getExpressionElement(layer);
+			return context.getExpressionElement(layer);
+		}
+
+		public Object layer(String name) {
+			for (ListIterator<Layer> it = _layers.listIterator(_layers.size()); it.hasPrevious(); ) {
+				Layer layer = it.previous();
+				if (layer.getName().equals(name)) {
+					return context.getExpressionElement(layer);
+				}
+			}
+			return null;
 		}
 
 		public int getHeight() {
