@@ -23,26 +23,27 @@
 
 package ch.kuramo.javie.core.internal;
 
-import ch.kuramo.javie.api.RenderResolution;
+import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Vec2d;
 import ch.kuramo.javie.api.Vec3d;
 import ch.kuramo.javie.core.CameraLayer;
 import ch.kuramo.javie.core.CollapseTransformation;
 import ch.kuramo.javie.core.Layer;
+import ch.kuramo.javie.core.LayerComposition;
 import ch.kuramo.javie.core.LayerNature;
 import ch.kuramo.javie.core.MediaItemLayer;
 import ch.kuramo.javie.core.TransformableLayer;
 import ch.kuramo.javie.core.WrappedOperation;
-import ch.kuramo.javie.core.services.VideoRenderContext;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 class LayerMatrixUtil {
 
 	static void multModelViewMatrix(
 			TransformableLayer layer, Vec2d offset, CollapseTransformation ct,
-			VideoRenderContext vrContext, VideoRenderSupport vrSupport) {
+			RenderContext context, VideoRenderSupport vrSupport) {
 
-		LayerMatrixUtil util = new LayerMatrixUtil(vrContext, vrSupport);
+		LayerMatrixUtil util = new LayerMatrixUtil(context, vrSupport);
 
 		if (ct != null) {
 			util.multCollapseTransformation(ct, LayerNature.isThreeD(layer));
@@ -52,25 +53,25 @@ class LayerMatrixUtil {
 	}
 
 	static void multParentMatrix(
-			CameraLayer cameraLayer, VideoRenderContext vrContext, VideoRenderSupport vrSupport) {
+			CameraLayer cameraLayer, RenderContext context, VideoRenderSupport vrSupport) {
 
-		Layer parent = cameraLayer.getParent();
+		Layer parent = ((LayerComposition) context.getComposition()).getParentLayer(cameraLayer);
 		if (parent != null) {
-			new LayerMatrixUtil(vrContext, vrSupport)
+			new LayerMatrixUtil(context, vrSupport)
 					.multModelViewMatrixInverse(parent, null, true);
 		}
 	}
 
 
 
-	private final VideoRenderContext _vrContext;
+	private final RenderContext _context;
 
 	private final VideoRenderSupport _vrSupport;
 
 
-	private LayerMatrixUtil(VideoRenderContext vrContext, VideoRenderSupport vrSupport) {
+	private LayerMatrixUtil(RenderContext context, VideoRenderSupport vrSupport) {
 		super();
-		_vrContext = vrContext;
+		_context = context;
 		_vrSupport = vrSupport;
 	}
 
@@ -81,9 +82,9 @@ class LayerMatrixUtil {
 			multCollapseTransformation(ct.getParent(), threeD && LayerNature.isThreeD(layer));
 		}
 
-		_vrContext.saveAndExecute(new WrappedOperation<Object>() {
+		_context.saveAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
-				_vrContext.setTime(ct.getTime());
+				_context.setTime(ct.getTime());
 				multModelViewMatrix(layer, null, threeD);
 				return null;
 			}
@@ -93,7 +94,7 @@ class LayerMatrixUtil {
 	private void multModelViewMatrix(Layer layer, Vec2d offset, boolean threeD) {
 		threeD &= LayerNature.isThreeD(layer);
 
-		Layer parent = layer.getParent();
+		Layer parent = ((LayerComposition) _context.getComposition()).getParentLayer(layer);
 		if (parent != null) {
 			multModelViewMatrix(parent, null, threeD);
 		}
@@ -114,7 +115,7 @@ class LayerMatrixUtil {
 			multCameraLayerMatrix((CameraLayer) layer, threeD, true);
 		}
 
-		Layer parent = layer.getParent();
+		Layer parent = ((LayerComposition) _context.getComposition()).getParentLayer(layer);
 		if (parent != null) {
 			multModelViewMatrixInverse(parent, null, threeD);
 		}
@@ -127,32 +128,32 @@ class LayerMatrixUtil {
 			return;
 		}
 
-		Vec3d anchorPoint = tlayer.getAnchorPoint().value(_vrContext);
+		Vec3d anchorPoint = tlayer.getAnchorPoint().value(_context);
 		if (offset != null) {
 			anchorPoint = new Vec3d(anchorPoint.x + offset.x, anchorPoint.y + offset.y, anchorPoint.z);
 		}
 
-		Vec3d scale = tlayer.getScale().value(_vrContext);
+		Vec3d scale = tlayer.getScale().value(_context);
 		Vec3d orientation;
 		Vec3d rotation;
-		Vec3d position = tlayer.getPosition().value(_vrContext);
+		Vec3d position = tlayer.getPosition().value(_context);
 
 		if (threeD) {
-			orientation = tlayer.getOrientation().value(_vrContext);
+			orientation = tlayer.getOrientation().value(_context);
 			rotation = new Vec3d(
-					tlayer.getRotationX().value(_vrContext),
-					tlayer.getRotationY().value(_vrContext),
-					tlayer.getRotationZ().value(_vrContext));
+					tlayer.getRotationX().value(_context),
+					tlayer.getRotationY().value(_context),
+					tlayer.getRotationZ().value(_context));
 
 		} else {
 			anchorPoint = new Vec3d(anchorPoint.x, anchorPoint.y, 0);
 			scale = new Vec3d(scale.x, scale.y, 100);
 			orientation = new Vec3d(0, 0, 0);
-			rotation = new Vec3d(0, 0, tlayer.getRotationZ().value(_vrContext));
+			rotation = new Vec3d(0, 0, tlayer.getRotationZ().value(_context));
 			position = new Vec3d(position.x, position.y, 0);
 		}
 
-		RenderResolution resolution = _vrContext.getRenderResolution();
+		Resolution resolution = _context.getVideoResolution();
 
 		if (inverse) {
 			_vrSupport.multModelViewMatrixInverse(
@@ -164,17 +165,17 @@ class LayerMatrixUtil {
 	}
 
 	private void multCameraLayerMatrix(final CameraLayer clayer, final boolean threeD, final boolean inverse) {
-		RenderResolution resolution = _vrContext.getRenderResolution();
+		Resolution resolution = _context.getVideoResolution();
 
-		Vec3d position = clayer.getPosition().value(_vrContext);
-		Vec3d pointOfInterest = clayer.getPointOfInterest().value(_vrContext);
+		Vec3d position = clayer.getPosition().value(_context);
+		Vec3d pointOfInterest = clayer.getPointOfInterest().value(_context);
 
 		if (threeD) {
-			Vec3d orientation = clayer.getOrientation().value(_vrContext);
+			Vec3d orientation = clayer.getOrientation().value(_context);
 			Vec3d rotation = new Vec3d(
-					clayer.getRotationX().value(_vrContext),
-					clayer.getRotationY().value(_vrContext),
-					clayer.getRotationZ().value(_vrContext));
+					clayer.getRotationX().value(_context),
+					clayer.getRotationY().value(_context),
+					clayer.getRotationZ().value(_context));
 
 			// This is OK: カメラレイヤーを親にしたときの変換は、カメラ自身の変換の逆変換となる。
 			if (inverse) {
@@ -192,7 +193,7 @@ class LayerMatrixUtil {
 			Vec3d anchorPoint = new Vec3d(pointOfInterest.x, pointOfInterest.y, 0);
 			Vec3d scale = new Vec3d(100, 100, 100);
 			Vec3d orientation = new Vec3d(0, 0, 0);
-			Vec3d rotation = new Vec3d(0, 0, clayer.getRotationZ().value(_vrContext));
+			Vec3d rotation = new Vec3d(0, 0, clayer.getRotationZ().value(_context));
 			position = new Vec3d(position.x, position.y, 0);
 
 			if (inverse) {
