@@ -41,8 +41,8 @@ import ch.kuramo.javie.core.MediaFileInput;
 import ch.kuramo.javie.core.VideoBuffer;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
 import ch.kuramo.javie.core.services.GLGlobal;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.SynchronousTaskThread;
-import ch.kuramo.javie.core.services.VideoRenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 import ch.kuramo.javie.core.services.SynchronousTaskThread.Task;
 import ch.kuramo.javie.core.services.SynchronousTaskThread.TaskWithoutResult;
@@ -80,7 +80,7 @@ public class MacOSXQTCoreVideoInput implements MediaFileInput {
 	private GLGlobal _glGlobal;
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private VideoRenderSupport _vrSupport;
@@ -229,13 +229,13 @@ public class MacOSXQTCoreVideoInput implements MediaFileInput {
 		return _bounds;
 	}
 
-	public VideoBuffer getVideoFrameImage(Time mediaTime) {
+	public VideoBuffer getVideoFrame(Time mediaTime) {
 		if (_videoInput == 0) {
 			return null;
 		}
 
-		final VideoBounds bounds = _vrContext.getRenderResolution().scale(_bounds);
-		VideoBuffer vb = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), bounds);
+		final VideoBounds bounds = _context.getVideoResolution().scale(_bounds);
+		VideoBuffer vb = _vrSupport.createVideoBuffer(_context.getColorMode(), bounds);
 		vb.allocateAsTexture();
 
 		if (mediaTime.timeValue < 0 || !mediaTime.before(_duration)) {
