@@ -26,13 +26,13 @@ package ch.kuramo.javie.core.internal;
 import java.util.List;
 
 import ch.kuramo.javie.core.AbstractTransformableLayer;
+import ch.kuramo.javie.core.CoreContext;
 import ch.kuramo.javie.core.Effect;
 import ch.kuramo.javie.core.ExpressionScope;
 import ch.kuramo.javie.core.LayerComposition;
 import ch.kuramo.javie.core.NullLayer;
 import ch.kuramo.javie.core.Project;
 import ch.kuramo.javie.core.ProjectDecodeException;
-import ch.kuramo.javie.core.RenderContext;
 import ch.kuramo.javie.core.Util;
 import ch.kuramo.javie.core.annotations.ProjectElement;
 
@@ -88,8 +88,8 @@ public class NullLayerImpl extends AbstractTransformableLayer implements NullLay
 		}
 	}
 
-	public Object createExpressionElement(RenderContext renderContext) {
-		return new TransformableLayerExpressionElement(renderContext);
+	public Object createExpressionElement(CoreContext context) {
+		return new TransformableLayerExpressionElement(context);
 	}
 
 }
