@@ -36,7 +36,7 @@ import ch.kuramo.javie.core.SolidColorItem;
 import ch.kuramo.javie.core.VectorMediaInput;
 import ch.kuramo.javie.core.VideoBuffer;
 import ch.kuramo.javie.core.annotations.ProjectElement;
-import ch.kuramo.javie.core.services.VideoRenderContext;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
@@ -53,7 +53,7 @@ public class SolidColorItemImpl extends AbstractItem implements SolidColorItem {
 	private final SolidColorInput _input = new SolidColorInput();
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private VideoRenderSupport _vrSupport;
@@ -132,9 +132,9 @@ public class SolidColorItemImpl extends AbstractItem implements SolidColorItem {
 			return _bounds;
 		}
 
-		public VideoBuffer getVideoFrameImage(Time mediaTime) {
-			ColorMode colorMode = _vrContext.getColorMode();
-			Size2i size = _vrContext.getRenderResolution().scale(_size);
+		public VideoBuffer getVideoFrame(Time mediaTime) {
+			ColorMode colorMode = _context.getColorMode();
+			Size2i size = _context.getVideoResolution().scale(_size);
 
 			VideoBuffer vb = _vrSupport.createVideoBuffer(colorMode, size);
 			vb.allocateAsTexture();
@@ -145,7 +145,7 @@ public class SolidColorItemImpl extends AbstractItem implements SolidColorItem {
 		}
 
 		public void rasterize(VideoBuffer resultBuffer, double[] mvMatrix, double[] prjMatrix, Time mediaTime) {
-			Size2i size = _vrContext.getRenderResolution().scale(_size);
+			Size2i size = _context.getVideoResolution().scale(_size);
 			_vrSupport.fillRectCR(resultBuffer, mvMatrix, prjMatrix, size, _color);
 		}
 
