@@ -27,7 +27,7 @@ import java.util.regex.Pattern;
 
 import net.arnx.jsonic.JSONHint;
 import ch.kuramo.javie.api.Color;
-import ch.kuramo.javie.api.RenderResolution;
+import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.core.AnimatableColor;
@@ -36,10 +36,10 @@ import ch.kuramo.javie.core.AnimatableHorizontalAlignment;
 import ch.kuramo.javie.core.AnimatableInteger;
 import ch.kuramo.javie.core.AnimatableString;
 import ch.kuramo.javie.core.AudioBuffer;
+import ch.kuramo.javie.core.CoreContext;
 import ch.kuramo.javie.core.ExpressionScope;
 import ch.kuramo.javie.core.HorizontalAlignment;
 import ch.kuramo.javie.core.MediaInput;
-import ch.kuramo.javie.core.RenderContext;
 import ch.kuramo.javie.core.TextLayer;
 import ch.kuramo.javie.core.VectorMediaInput;
 import ch.kuramo.javie.core.VideoBuffer;
@@ -47,7 +47,7 @@ import ch.kuramo.javie.core.annotations.ProjectElement;
 import ch.kuramo.javie.core.services.Font;
 import ch.kuramo.javie.core.services.FontList;
 import ch.kuramo.javie.core.services.FontManager;
-import ch.kuramo.javie.core.services.VideoRenderContext;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
@@ -75,7 +75,7 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 	private AnimatableDouble _leading = new AnimatableDouble(-1.0);
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private VideoRenderSupport _vrSupport;
@@ -177,14 +177,14 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 	}
 
 	@Override
-	public Object createExpressionElement(RenderContext renderContext) {
-		return new TextLayerExpressionElement(renderContext);
+	public Object createExpressionElement(CoreContext context) {
+		return new TextLayerExpressionElement(context);
 	}
 
 	public class TextLayerExpressionElement extends MediaLayerExpressionElement {
 
-		public TextLayerExpressionElement(RenderContext renderContext) {
-			super(renderContext);
+		public TextLayerExpressionElement(CoreContext context) {
+			super(context);
 		}
 
 		public Object getSourceText()			{ return elem(_sourceText); }
@@ -221,22 +221,24 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 		}
 
 		public VideoBounds getVideoFrameBounds() {
-			if (!_vrContext.isActive()) {
+			if (!_context.isActive()) {
+				// TODO RenderContextImpl#initGL がまだ呼ばれていない可能性がある。
+				//      その場合、この後のFontManagerのアクセスに失敗するはず。
 				return null;
 			}
 
-			String sourceText = _sourceText.value(_vrContext);
-			String psName = _font.value(_vrContext);
-			int fontSize = _fontSize.value(_vrContext);
+			String sourceText = _sourceText.value(_context);
+			String psName = _font.value(_context);
+			int fontSize = _fontSize.value(_context);
 			FTGLfont font = getFont(psName, fontSize);
 
 			if (sourceText.length() == 0 || font == null) {
 				return new VideoBounds(0, 0);
 			}
 
-			HorizontalAlignment halign = _horizontalAlignment.value(_vrContext);
+			HorizontalAlignment halign = _horizontalAlignment.value(_context);
 
-			double leading = _leading.value(_vrContext);
+			double leading = _leading.value(_context);
 			if (leading < 0) leading = fontSize * 1.2;	// AEは「自動」のときにはフォントサイズの1.2倍になってるっぽい。
 
 			double upper = 0, lower = Double.MAX_VALUE, advanced = 0;
@@ -278,22 +280,22 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 			return new VideoBounds(x, -upper, width, (int)(upper + Math.ceil(leading*(texts.length-1)) - lower));
 		}
 
-		public VideoBuffer getVideoFrameImage(Time mediaTime) {
-			RenderResolution resolution = _vrContext.getRenderResolution();
+		public VideoBuffer getVideoFrame(Time mediaTime) {
+			Resolution resolution = _context.getVideoResolution();
 			VideoBounds bounds = resolution.scale(getVideoFrameBounds());
 
-			VideoBuffer vb = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), bounds);
+			VideoBuffer vb = _vrSupport.createVideoBuffer(_context.getColorMode(), bounds);
 			vb.allocateAsTexture();
 			vb.clear();
 
-			String psName = _font.value(_vrContext);
-			int fontSize = _fontSize.value(_vrContext);
+			String psName = _font.value(_context);
+			int fontSize = _fontSize.value(_context);
 			FTGLfont font = getFont(psName, fontSize);
 			if (font != null) {
-				String sourceText = _sourceText.value(_vrContext);
-				Color fillColor = _fillColor.value(_vrContext);
-				HorizontalAlignment halign = _horizontalAlignment.value(_vrContext);
-				double leading = _leading.value(_vrContext);
+				String sourceText = _sourceText.value(_context);
+				Color fillColor = _fillColor.value(_context);
+				HorizontalAlignment halign = _horizontalAlignment.value(_context);
+				double leading = _leading.value(_context);
 
 				String[] texts = LF.split(sourceText);
 
@@ -309,16 +311,16 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 		}
 
 		public void rasterize(VideoBuffer resultBuffer, double[] mvMatrix, double[] prjMatrix, Time mediaTime) {
-			RenderResolution resolution = _vrContext.getRenderResolution();
+			Resolution resolution = _context.getVideoResolution();
 
-			String psName = _font.value(_vrContext);
-			int fontSize = _fontSize.value(_vrContext);
+			String psName = _font.value(_context);
+			int fontSize = _fontSize.value(_context);
 			FTGLfont font = getFont(psName, fontSize);
 			if (font != null) {
-				String sourceText = _sourceText.value(_vrContext);
-				Color fillColor = _fillColor.value(_vrContext);
-				HorizontalAlignment halign = _horizontalAlignment.value(_vrContext);
-				double leading = _leading.value(_vrContext);
+				String sourceText = _sourceText.value(_context);
+				Color fillColor = _fillColor.value(_context);
+				HorizontalAlignment halign = _horizontalAlignment.value(_context);
+				double leading = _leading.value(_context);
 
 				String[] texts = LF.split(sourceText);
 
@@ -351,7 +353,7 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 		private double[][] calcTextOffsets(
 				FTGLfont font, String[] texts,
 				HorizontalAlignment halign, double leading,
-				RenderResolution resolution) {
+				Resolution resolution) {
 
 			double[][] offsets = new double[texts.length][2];
 
