@@ -38,12 +38,18 @@ class VideoLayerBufferImpl implements VideoLayerBuffer {
 
 	private final double _opacity;
 
+	private final int _dissolveSeed;
+
+
+	VideoLayerBufferImpl(
+			VideoBuffer videoBuffer, DepthBuffer depthBuffer,
+			BlendMode blendMode, double opacity, int dissolveSeed) {
 
-	VideoLayerBufferImpl(VideoBuffer videoBuffer, DepthBuffer depthBuffer, BlendMode blendMode, double opacity) {
 		_videoBuffer = videoBuffer;
 		_depthBuffer = depthBuffer;
 		_blendMode = blendMode;
 		_opacity = opacity;
+		_dissolveSeed = dissolveSeed;
 	}
 
 	public void dispose() {
@@ -73,4 +79,8 @@ class VideoLayerBufferImpl implements VideoLayerBuffer {
 		return _opacity;
 	}
 
+	public int getDissolveSeed() {
+		return _dissolveSeed;
+	}
+
 }
