@@ -41,7 +41,7 @@ import ch.kuramo.javie.core.VideoLayerBuffer;
 import ch.kuramo.javie.core.VideoLayerComposer;
 import ch.kuramo.javie.core.VideoLayerRenderer;
 import ch.kuramo.javie.core.WrappedOperation;
-import ch.kuramo.javie.core.services.VideoRenderContext;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 class VideoLayerComposerImpl implements VideoLayerComposer {
@@ -129,7 +129,7 @@ class VideoLayerComposerImpl implements VideoLayerComposer {
 		}
 	};
 
-	private final VideoRenderContext _vrContext;
+	private final RenderContext _context;
 
 	private final VideoRenderSupport _vrSupport;
 
@@ -145,10 +145,10 @@ class VideoLayerComposerImpl implements VideoLayerComposer {
 
 
 	VideoLayerComposerImpl(
-			VideoRenderContext vrContext, VideoRenderSupport vrSupport,
+			RenderContext context, VideoRenderSupport vrSupport,
 			ColorMode colorMode, Size2i renderSize, Vec3d cameraPosition) {
 
-		_vrContext = vrContext;
+		_context = context;
 		_vrSupport = vrSupport;
 		_colorMode = colorMode;
 		_renderSize = renderSize;
@@ -184,7 +184,7 @@ class VideoLayerComposerImpl implements VideoLayerComposer {
 		}
 
 		for (final Entry e : entries) {
-			VideoLayerBuffer vlb = _vrContext.saveAndExecute(new WrappedOperation<VideoLayerBuffer>() {
+			VideoLayerBuffer vlb = _context.saveAndExecute(new WrappedOperation<VideoLayerBuffer>() {
 				public VideoLayerBuffer execute() {
 					return e.renderer.render(!e.intersectionMembers.isEmpty());
 				}
@@ -195,7 +195,7 @@ class VideoLayerComposerImpl implements VideoLayerComposer {
 				intersectionGroupBuffers.add(vlb);
 
 				for (final Entry ee : e.intersectionMembers) {
-					vlb = _vrContext.saveAndExecute(new WrappedOperation<VideoLayerBuffer>() {
+					vlb = _context.saveAndExecute(new WrappedOperation<VideoLayerBuffer>() {
 						public VideoLayerBuffer execute() {
 							return ee.renderer.render(true);
 						}
@@ -220,7 +220,7 @@ class VideoLayerComposerImpl implements VideoLayerComposer {
 
 		if (intersectionGroupBuffers.size() == 1) {
 			VideoLayerBuffer vlb = intersectionGroupBuffers.iterator().next();
-			_vrSupport.blend(vlb.getVideoBuffer(), vb, vbNew, vlb.getBlendMode(), vlb.getOpacity());
+			_vrSupport.blend(vlb.getVideoBuffer(), vb, vbNew, vlb.getBlendMode(), vlb.getOpacity(), vlb.getDissolveSeed());
 		} else {
 			_vrSupport.blend(intersectionGroupBuffers, vb, vbNew);
 		}
