@@ -41,7 +41,7 @@ import org.slf4j.LoggerFactory;
 import ch.kuramo.javie.api.AudioMode;
 import ch.kuramo.javie.api.ColorMode;
 import ch.kuramo.javie.api.IArray;
-import ch.kuramo.javie.api.RenderResolution;
+import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.services.IArrayPools;
@@ -49,10 +49,9 @@ import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.JavieRuntimeException;
 import ch.kuramo.javie.core.MediaFileInput;
 import ch.kuramo.javie.core.VideoBuffer;
-import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.SynchronousTaskThread;
-import ch.kuramo.javie.core.services.VideoRenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 import ch.kuramo.javie.core.services.SynchronousTaskThread.Task;
 import ch.kuramo.javie.core.services.SynchronousTaskThread.TaskWithoutResult;
@@ -93,14 +92,11 @@ public class WindowsDirectShowInput implements MediaFileInput {
 	private SynchronousTaskThread _audioThread;
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private VideoRenderSupport _vrSupport;
 
-	@Inject
-	private AudioRenderContext _arContext;
-
 	@Inject
 	private AudioRenderSupport _arSupport;
 
@@ -225,7 +221,7 @@ public class WindowsDirectShowInput implements MediaFileInput {
 		return _bounds;
 	}
 
-	public VideoBuffer getVideoFrameImage(Time mediaTime) {
+	public VideoBuffer getVideoFrame(Time mediaTime) {
 		if (_videoInput == 0) {
 			return null;
 		}
@@ -262,9 +258,9 @@ public class WindowsDirectShowInput implements MediaFileInput {
 				return null;
 			}
 
-			RenderResolution resolution = _vrContext.getRenderResolution();
+			Resolution resolution = _context.getVideoResolution();
 			VideoBuffer vb2 = _vrSupport.createVideoBuffer(
-					_vrContext.getColorMode(), resolution.scale(_bounds));
+					_context.getColorMode(), resolution.scale(_bounds));
 
 			_vrSupport.scaleAndFlipVertical(vb, vb2, resolution.scale(1));
 
@@ -277,10 +273,10 @@ public class WindowsDirectShowInput implements MediaFileInput {
 
 	public synchronized AudioBuffer getAudioChunk(Time mediaTime) {
 		try {
-			AudioMode audioMode = _arContext.getAudioMode();
+			AudioMode audioMode = _context.getAudioMode();
 			long frameNumber = mediaTime.toFrameNumber(audioMode.sampleDuration);
 
-			if (-frameNumber >= _arContext.getFrameCount() || !mediaTime.before(_duration)) {
+			if (-frameNumber >= _context.getAudioFrameCount() || !mediaTime.before(_duration)) {
 				AudioBuffer ab = _arSupport.createAudioBuffer();
 				_arSupport.clear(ab);
 				return ab;
@@ -311,7 +307,7 @@ public class WindowsDirectShowInput implements MediaFileInput {
 		// 変換の必要が無い場合、AudioSystem.getAudioInputStream は元のストリームをそのまま返すようなので
 		// 以下のように無条件に変換を試みても無駄な変換は発生しないようである。
 
-		_audioMode = _arContext.getAudioMode();
+		_audioMode = _context.getAudioMode();
 		int bits = _audioMode.sampleSize * 8;
 		int ch = _audioMode.channels;
 
