@@ -46,6 +46,8 @@ public class ArrayPoolsImpl implements IArrayPools {
 
 	private final ArrayPool<float[]> _floatPool = new ArrayPool<float[]>(float.class);
 
+	private final ArrayPool<double[]> _doublePool = new ArrayPool<double[]>(double.class);
+
 	private final ArrayPool<Object[]> _objectPool = new ArrayPool<Object[]>(Object.class);
 
 
@@ -65,6 +67,10 @@ public class ArrayPoolsImpl implements IArrayPools {
 		return new FloatArray(length);
 	}
 
+	public IArray<double[]> getDoubleArray(int length) {
+		return new DoubleArray(length);
+	}
+
 	public <T> IObjectArray<T> getObjectArray(int length) {
 		return new ObjectArray<T>(length);
 	}
@@ -158,6 +164,18 @@ public class ArrayPoolsImpl implements IArrayPools {
 
 	}
 
+	private class DoubleArray extends AbstractArray<double[]> {
+
+		private DoubleArray(int length) {
+			super(_doublePool, length);
+		}
+
+		public void clear() {
+			Arrays.fill(array, 0, length, 0);
+		}
+
+	}
+
 	private class ObjectArray<T> extends AbstractArray<Object[]> implements IObjectArray<T> {
 
 		private ObjectArray(int length) {
