@@ -25,11 +25,9 @@ package ch.kuramo.javie.core.internal.services;
 
 import java.util.List;
 
-import ch.kuramo.javie.api.AudioMode;
 import ch.kuramo.javie.api.IAnimatableValue;
 import ch.kuramo.javie.api.IAudioBuffer;
 import ch.kuramo.javie.api.IObjectArray;
-import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.services.IArrayPools;
 import ch.kuramo.javie.api.services.IAudioEffectContext;
 import ch.kuramo.javie.core.AnimatableValue;
@@ -39,15 +37,19 @@ import ch.kuramo.javie.core.Effect;
 import ch.kuramo.javie.core.Util;
 import ch.kuramo.javie.core.WrappedOperation;
 import ch.kuramo.javie.core.services.AudioEffectPipeline;
-import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
+import ch.kuramo.javie.core.services.RenderContext;
+import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
 
 public class AudioEffectPipelineImpl implements AudioEffectPipeline {
 
 	@Inject
-	private AudioRenderContext _arContext;
+	private RenderContext _context;
+
+	@Inject
+	private VideoRenderSupport _vrSupport;
 
 	@Inject
 	private AudioRenderSupport _arSupport;
@@ -77,7 +79,8 @@ public class AudioEffectPipelineImpl implements AudioEffectPipeline {
 	}
 
 
-	private class AudioEffectContextImpl implements IAudioEffectContext {
+	private class AudioEffectContextImpl
+			extends AbstractEffectContext implements IAudioEffectContext {
 
 		private List<AudioEffect> effects;
 
@@ -85,13 +88,30 @@ public class AudioEffectPipelineImpl implements AudioEffectPipeline {
 
 
 		private AudioEffectContextImpl(List<AudioEffect> effects, WrappedOperation<AudioBuffer> inputOperation) {
+			super(_context, _vrSupport, _arSupport);
+
 			this.effects = effects;
 			this.inputOperation = inputOperation;
 		}
 
+		public <V> IObjectArray<V> values(IAnimatableValue<V> avalue) {
+			return values(avalue, _context.getAudioAnimationRate());
+		}
+
+		public <V> IObjectArray<V> values(IAnimatableValue<V> avalue, int animationRate) {
+			@SuppressWarnings("unchecked")
+			AnimatableValue<V> av = (AnimatableValue<V>) avalue;
+
+			animationRate = Math.max(1, Math.min(animationRate, _context.getAudioAnimationRate()));
+
+			IObjectArray<V> objArray = _arrayPools.getObjectArray(_context.getAudioFrameCount());
+			av.values(objArray, _context.getAudioMode().sampleDuration, animationRate, _context);
+			return objArray;
+		}
+
 		public IAudioBuffer doPreviousEffect() {
 			if (effects.isEmpty()) {
-				AudioBuffer ab = _arContext.saveAndExecute(inputOperation);
+				AudioBuffer ab = _context.saveAndExecute(inputOperation);
 				if (ab == null) {
 					ab = _arSupport.createAudioBuffer();
 					_arSupport.clear(ab);
@@ -113,57 +133,12 @@ public class AudioEffectPipelineImpl implements AudioEffectPipeline {
 			List<AudioEffect> savedEffects = effects;
 			try {
 				effects = effects.subList(0, effects.size() - 1);
-				return _arContext.saveAndExecute(wop);
+				return _context.saveAndExecute(wop);
 			} finally {
 				effects = savedEffects;
 			}
 		}
 
-		public Time getTime() {
-			return _arContext.getTime();
-		}
-
-		public void setTime(Time time) {
-			_arContext.setTime(time);
-		}
-
-		public <V> V value(IAnimatableValue<V> avalue) {
-			@SuppressWarnings("unchecked")
-			AnimatableValue<V> av = (AnimatableValue<V>) avalue;
-			return av.value(_arContext);
-		}
-
-		public AudioMode getAudioMode() {
-			return _arContext.getAudioMode();
-		}
-
-		public int getFrameCount() {
-			return _arContext.getFrameCount();
-		}
-
-		public void setFrameCount(int count) {
-			_arContext.setFrameCount(count);
-		}
-
-		public IAudioBuffer createAudioBuffer() {
-			return (IAudioBuffer) _arSupport.createAudioBuffer();
-		}
-
-		public <V> IObjectArray<V> values(IAnimatableValue<V> avalue) {
-			return values(avalue, _arContext.getEvaluationResolution());
-		}
-
-		public <V> IObjectArray<V> values(IAnimatableValue<V> avalue, int evalResolution) {
-			@SuppressWarnings("unchecked")
-			AnimatableValue<V> av = (AnimatableValue<V>) avalue;
-
-			evalResolution = Math.max(1, Math.min(evalResolution, _arContext.getEvaluationResolution()));
-
-			IObjectArray<V> objArray = _arrayPools.getObjectArray(_arContext.getFrameCount());
-			av.values(objArray, _arContext.getAudioMode().sampleDuration, evalResolution, _arContext);
-			return objArray;
-		}
-
 	}
 
 }
