@@ -29,8 +29,8 @@ import ch.kuramo.javie.api.IObjectArray;
 import ch.kuramo.javie.api.Vec2d;
 import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.internal.AudioBufferImpl;
-import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
+import ch.kuramo.javie.core.services.RenderContext;
 
 import com.google.inject.Inject;
 import com.google.inject.Injector;
@@ -38,18 +38,18 @@ import com.google.inject.Injector;
 public class AudioRenderSupportImpl implements AudioRenderSupport {
 
 	@Inject
-	private AudioRenderContext _arContext;
+	private RenderContext _context;
 
 	@Inject
 	private Injector _injector;
 
 
 	public AudioBuffer createAudioBuffer() {
-		return createAudioBuffer(_arContext.getFrameCount());
+		return createAudioBuffer(_context.getAudioFrameCount());
 	}
 
 	public AudioBuffer createAudioBuffer(int frameCount) {
-		AudioBufferImpl ab = new AudioBufferImpl(_arContext.getAudioMode(), frameCount);
+		AudioBufferImpl ab = new AudioBufferImpl(_context.getAudioMode(), frameCount);
 		_injector.injectMembers(ab);
 		return ab;
 	}
