@@ -42,6 +42,7 @@ import ch.kuramo.javie.api.IAnimatableColor;
 import ch.kuramo.javie.api.IAnimatableDouble;
 import ch.kuramo.javie.api.IAnimatableEnum;
 import ch.kuramo.javie.api.IAnimatableInteger;
+import ch.kuramo.javie.api.IAnimatableLayerReference;
 import ch.kuramo.javie.api.IAnimatableString;
 import ch.kuramo.javie.api.IAnimatableVec2d;
 import ch.kuramo.javie.api.IAnimatableVec3d;
@@ -52,6 +53,7 @@ import ch.kuramo.javie.core.AnimatableBoolean;
 import ch.kuramo.javie.core.AnimatableColor;
 import ch.kuramo.javie.core.AnimatableDouble;
 import ch.kuramo.javie.core.AnimatableInteger;
+import ch.kuramo.javie.core.AnimatableLayerReference;
 import ch.kuramo.javie.core.AnimatableString;
 import ch.kuramo.javie.core.AnimatableValue;
 import ch.kuramo.javie.core.AnimatableVec2d;
@@ -161,6 +163,8 @@ class EffectDescriptorImpl implements EffectDescriptor {
 				map.put(name, new AnimatableBooleanPropertyDescriptor(name, value));
 			} else if (IAnimatableEnum.class.isAssignableFrom(type)) {
 				map.put(name, new AnimatableEnumPropertyDescriptor(name, value));
+			} else if (IAnimatableLayerReference.class.isAssignableFrom(type)) {
+				map.put(name, new AnimatableLayerReferencePropertyDescriptor(name, value));
 //			} else if (String.class.equals(type)) {
 //				map.put(name, new StringPropertyDescriptor(name, value));
 //			} else if (Enum.class.isAssignableFrom(type)) {
@@ -178,6 +182,10 @@ class EffectDescriptorImpl implements EffectDescriptor {
 		return map;
 	}
 
+	public boolean isUnknown() {
+		return false;
+	}
+
 	public String getType() {
 		return _type;
 	}
@@ -443,6 +451,20 @@ class EffectDescriptorImpl implements EffectDescriptor {
 		}
 	}
 
+	private class AnimatableLayerReferencePropertyDescriptor extends AbstractPropertyDescriptor<AnimatableLayerReference> {
+
+		private final String value;
+
+		private AnimatableLayerReferencePropertyDescriptor(String name, String value) {
+			super(AnimatableLayerReference.class, name);
+			this.value = value;
+		}
+
+		public void initValue(Effect effect) {
+			set(effect, new AnimatableLayerReference(value));
+		}
+	}
+
 	@SuppressWarnings("unused")
 	private class StringPropertyDescriptor extends AbstractPropertyDescriptor<String> {
 
