@@ -41,6 +41,7 @@ import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.Vec2d;
 import ch.kuramo.javie.api.Vec3d;
+import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.core.AbstractAnimatableEnum;
 import ch.kuramo.javie.core.AbstractAnimatableValue;
 import ch.kuramo.javie.core.ArithmeticalAnimatableValue;
@@ -141,14 +142,15 @@ public class ProjectDecoderImpl implements ProjectDecoder {
 				} else {
 					String elementType = (String) map.get("TYPE");
 					if (elementType != null) {
-						Class<T> clazz = _elementFactory.getClass(elementType);
-						if (clazz == null) {
+						Class<T> clazz;
+						if (Effect.class.isAssignableFrom(c)) {
 							EffectDescriptor ed = _effectRegistry.getEffectDescriptor(elementType);
-							if (ed != null) {
-								@SuppressWarnings("unchecked")
-								Class<T> effectClass = (Class<T>) ed.getEffectClass();
-								clazz = effectClass;
-							}
+
+							@SuppressWarnings("unchecked")
+							Class<T> effectClass = (Class<T>)((ed != null) ? ed.getEffectClass() : UnknownEffect.class);
+							clazz = effectClass;
+						} else {
+							clazz = _elementFactory.getClass(elementType);
 						}
 						if (clazz == null) {
 							throw new ProjectDecodeException("no such project element found: type=" + elementType);
@@ -169,6 +171,9 @@ public class ProjectDecoderImpl implements ProjectDecoder {
 				} else if (Size2i.class.isAssignableFrom(c)) {
 					return c.cast(createSize2i(context, list));
 
+				} else if (VideoBounds.class.isAssignableFrom(c)) {
+					return c.cast(createVideoBounds(context, list));
+
 				} else if (Vec2d.class.isAssignableFrom(c)) {
 					return c.cast(createVec2d(context, list));
 
@@ -241,6 +246,14 @@ public class ProjectDecoderImpl implements ProjectDecoder {
 					context.convert(1, list.get(1), int.class));			
 		}
 
+		private VideoBounds createVideoBounds(Context context, List<?> list) throws Exception {
+			return new VideoBounds(
+					context.convert(0, list.get(0), double.class),
+					context.convert(1, list.get(1), double.class),
+					context.convert(2, list.get(2), int.class),
+					context.convert(3, list.get(3), int.class));
+		}
+
 		private Vec2d createVec2d(Context context, List<?> list) throws Exception {
 			return new Vec2d(
 					context.convert(0, list.get(0), double.class),
