@@ -50,9 +50,9 @@ import ch.kuramo.javie.api.annotations.ShaderSource;
 import ch.kuramo.javie.api.services.IShaderRegistry;
 import ch.kuramo.javie.core.JavieRuntimeException;
 import ch.kuramo.javie.core.Util;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.ShaderRegistry;
 import ch.kuramo.javie.core.services.ShaderRegistryException;
-import ch.kuramo.javie.core.services.VideoRenderContext;
 
 import com.google.inject.Inject;
 import com.google.inject.Injector;
@@ -65,7 +65,7 @@ public class ShaderRegistryImpl implements ShaderRegistry, IShaderRegistry {
 	private Injector _injector;
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 
 	private void putEntry(String name, ShaderEntry entry) throws ShaderRegistryException {
@@ -438,7 +438,7 @@ public class ShaderRegistryImpl implements ShaderRegistry, IShaderRegistry {
 				}
 
 				public void useProgram(Runnable r) {
-					GL2 gl = _vrContext.getGL().getGL2();
+					GL2 gl = _context.getGL().getGL2();
 
 					synchronized (ShaderEntry.this) {
 						if (program == 0) {
