@@ -25,24 +25,17 @@ package ch.kuramo.javie.core.internal.services;
 
 import java.util.List;
 
-import javax.media.opengl.GL;
-import javax.media.opengl.glu.GLU;
-
-import ch.kuramo.javie.api.ColorMode;
-import ch.kuramo.javie.api.IAnimatableValue;
 import ch.kuramo.javie.api.IVideoBuffer;
-import ch.kuramo.javie.api.RenderResolution;
-import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.services.IVideoEffectContext;
-import ch.kuramo.javie.core.AnimatableValue;
 import ch.kuramo.javie.core.Effect;
 import ch.kuramo.javie.core.Util;
 import ch.kuramo.javie.core.VideoBuffer;
 import ch.kuramo.javie.core.VideoEffect;
 import ch.kuramo.javie.core.WrappedOperation;
+import ch.kuramo.javie.core.services.AudioRenderSupport;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoEffectPipeline;
-import ch.kuramo.javie.core.services.VideoRenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
@@ -50,13 +43,18 @@ import com.google.inject.Inject;
 public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private VideoRenderSupport _vrSupport;
 
+	@Inject
+	private AudioRenderSupport _arSupport;
+
+
+	public VideoBounds getVideoBounds(List<Effect> effects,
+			WrappedOperation<VideoBounds> inputBoundsOperation) {
 
-	public VideoBounds getVideoBounds(List<Effect> effects, WrappedOperation<VideoBounds> inputBoundsOperation) {
 		VideoEffectContextImpl impl = new VideoEffectContextImpl(
 				enabledVideoEffectsOnly(effects), inputBoundsOperation, null);
 		VideoEffectContextProxy.push(impl);
@@ -67,9 +65,12 @@ public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 		}
 	}
 
-	public VideoBuffer doVideoEffects(List<Effect> effects, WrappedOperation<VideoBuffer> inputBufferOperation) {
+	public VideoBuffer doVideoEffects(List<Effect> effects,
+			WrappedOperation<VideoBounds> inputBoundsOperation,
+			WrappedOperation<VideoBuffer> inputBufferOperation) {
+
 		VideoEffectContextImpl impl = new VideoEffectContextImpl(
-				enabledVideoEffectsOnly(effects), null, inputBufferOperation);
+				enabledVideoEffectsOnly(effects), inputBoundsOperation, inputBufferOperation);
 		VideoEffectContextProxy.push(impl);
 		try {
 			return (VideoBuffer) impl.doPreviousEffect();
@@ -89,7 +90,8 @@ public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 	}
 
 
-	private class VideoEffectContextImpl implements IVideoEffectContext {
+	private class VideoEffectContextImpl
+			extends AbstractEffectContext implements IVideoEffectContext {
 
 		private List<VideoEffect> effects;
 
@@ -97,11 +99,16 @@ public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 
 		private final WrappedOperation<VideoBuffer> inputBufferOperation;
 
+		private boolean gettingBounds;
+
 
 		private VideoEffectContextImpl(
 				List<VideoEffect> effects,
 				WrappedOperation<VideoBounds> inputBoundsOperation,
 				WrappedOperation<VideoBuffer> inputBufferOperation) {
+
+			super(_context, _vrSupport, _arSupport);
+
 			this.effects = effects;
 			this.inputBoundsOperation = inputBoundsOperation;
 			this.inputBufferOperation = inputBufferOperation;
@@ -112,27 +119,34 @@ public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 				throw new IllegalStateException();
 			}
 
-			if (effects.isEmpty()) {
-				return _vrContext.saveAndExecute(inputBoundsOperation);
-			}
+			boolean savedGettingBounds = gettingBounds;
+			try {
+				gettingBounds = true;
 
-			final VideoEffect prevEffect = effects.get(effects.size() - 1);
-
-			return executePrevious(new WrappedOperation<VideoBounds>() {
-				public VideoBounds execute() {
-					VideoBounds bounds = prevEffect.getVideoBounds();
-					return (bounds != null) ? bounds : getPreviousBounds();
+				if (effects.isEmpty()) {
+					return _context.saveAndExecute(inputBoundsOperation);
 				}
-			});
+
+				final VideoEffect prevEffect = effects.get(effects.size() - 1);
+
+				return executePrevious(new WrappedOperation<VideoBounds>() {
+					public VideoBounds execute() {
+						VideoBounds bounds = prevEffect.getVideoBounds();
+						return (bounds != null) ? bounds : getPreviousBounds();
+					}
+				});
+			} finally {
+				gettingBounds = savedGettingBounds;
+			}
 		}
 		
 		public IVideoBuffer doPreviousEffect() {
-			if (inputBufferOperation == null) {
+			if (inputBufferOperation == null || gettingBounds) {
 				throw new IllegalStateException();
 			}
 
 			if (effects.isEmpty()) {
-				return (IVideoBuffer) _vrContext.saveAndExecute(inputBufferOperation);
+				return (IVideoBuffer) _context.saveAndExecute(inputBufferOperation);
 			}
 
 			final VideoEffect prevEffect = effects.get(effects.size() - 1);
@@ -151,7 +165,7 @@ public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 
 				effects = effects.subList(0, effects.size() - 1);
 
-				return _vrContext.saveAndExecute(new WrappedOperation<T>() {
+				return _context.saveAndExecute(new WrappedOperation<T>() {
 					public T execute() {
 						return _vrSupport.pushMatrixAndExecute(wop);
 					}
@@ -162,39 +176,6 @@ public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 			}
 		}
 
-		public Time getTime() {
-			return _vrContext.getTime();
-		}
-
-		public void setTime(Time time) {
-			_vrContext.setTime(time);
-		}
-
-		public <V> V value(IAnimatableValue<V> avalue) {
-			@SuppressWarnings("unchecked")
-			AnimatableValue<V> av = (AnimatableValue<V>) avalue;
-			return av.value(_vrContext);
-		}
-
-		public GL getGL() {
-			return _vrContext.getGL();
-		}
-
-		public GLU getGLU() {
-			return _vrContext.getGLU();
-		}
-
-		public RenderResolution getRenderResolution() {
-			return _vrContext.getRenderResolution();
-		}
-
-		public ColorMode getColorMode() {
-			return _vrContext.getColorMode();
-		}
-
-		public IVideoBuffer createVideoBuffer(VideoBounds bounds) {
-			return (IVideoBuffer) _vrSupport.createVideoBuffer(_vrContext.getColorMode(), bounds);
-		}
 
 	}
 
