@@ -63,7 +63,7 @@ import ch.kuramo.javie.core.WrappedOperation;
 import ch.kuramo.javie.core.internal.DepthBufferImpl;
 import ch.kuramo.javie.core.internal.VideoBufferImpl;
 import ch.kuramo.javie.core.services.GLGlobal;
-import ch.kuramo.javie.core.services.VideoRenderContext;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 import ch.kuramo.javie.core.shaders.AccumulationShaders;
 import ch.kuramo.javie.core.shaders.BlendModeShaders;
@@ -89,7 +89,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	private GLGlobal _glGlobal;
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private IShaderRegistry _shaders;
@@ -120,7 +120,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	}
 
 	public int createTexture(ColorMode colorMode, Size2i textureSize) {
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 
 		int[] tex = new int[1];
 		gl.glGenTextures(1, tex, 0);
@@ -140,7 +140,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	}
 
 	public int createDepthTexture(Size2i textureSize) {
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 
 		int[] tex = new int[1];
 		gl.glGenTextures(1, tex, 0);
@@ -160,7 +160,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	}
 
 	public void deleteTexture(int texture) {
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 		gl.glDeleteTextures(1, new int[] { texture }, 0);
 	}
 
@@ -186,7 +186,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 		lock.lock();
 		try {
 
-			GL2 gl = _vrContext.getGL().getGL2();
+			GL2 gl = _context.getGL().getGL2();
 
 			int[] pbo = new int[1];
 			gl.glGenBuffers(1, pbo, 0);
@@ -233,7 +233,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 		lock.lock();
 		try {
 
-			GL2 gl = _vrContext.getGL().getGL2();
+			GL2 gl = _context.getGL().getGL2();
 
 			int[] pbo = new int[1];
 			gl.glGenBuffers(1, pbo, 0);
@@ -338,7 +338,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	}
 
 	private void fill(int texture, Color color) {
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 
 		gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
 				GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, texture, 0);
@@ -371,7 +371,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 		pushMatrixAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
-				final GL2 gl = _vrContext.getGL().getGL2();
+				final GL2 gl = _context.getGL().getGL2();
 
 				gl.glViewport(0, 0, resultImageSize.width, resultImageSize.height);
 				gl.glMatrixMode(GL2.GL_PROJECTION);
@@ -444,9 +444,9 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 		pushMatrixAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
-				final GL2 gl = _vrContext.getGL().getGL2();
+				final GL2 gl = _context.getGL().getGL2();
 
-				ortho2D(gl, _vrContext.getGLU(), imageSize);
+				ortho2D(gl, _context.getGLU(), imageSize);
 
 				// レンダリング先を resultTexture に設定
 				gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
@@ -492,7 +492,9 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 		});
 	}
 
-	public void blend(VideoBuffer srcBuffer, VideoBuffer dstBuffer, VideoBuffer resultBuffer, final BlendMode blendMode, final double opacity) {
+	public void blend(
+			VideoBuffer srcBuffer, VideoBuffer dstBuffer, VideoBuffer resultBuffer,
+			final BlendMode blendMode, final double opacity, final int dissolveSeed) {
 
 		final int srcTexture = srcBuffer.getTexture();
 		final int dstTexture = dstBuffer.getTexture();
@@ -501,9 +503,9 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 		pushMatrixAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
-				final GL2 gl = _vrContext.getGL().getGL2();
+				final GL2 gl = _context.getGL().getGL2();
 
-				ortho2D(gl, _vrContext.getGLU(), imageSize);
+				ortho2D(gl, _context.getGLU(), imageSize);
 
 				// レンダリング先を resultTexture に設定
 				gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
@@ -522,8 +524,14 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 						gl.glUniform1i(program.getUniformLocation("texDst"), 0);
 						gl.glUniform1i(program.getUniformLocation("texSrc"), 1);
 						gl.glUniform1f(program.getUniformLocation("opacity"), (float)opacity);
-						if (blendMode == BlendMode.DANCING_DISSOLVE) {
-							gl.glUniform1f(program.getUniformLocation("time"), (float)(_vrContext.getTime().toSecond()));
+
+						switch (blendMode) {
+							case DISSOLVE:
+								gl.glUniform1f(program.getUniformLocation("dissolveSeed"), 100f*dissolveSeed/Integer.MAX_VALUE);
+								break;
+							case DANCING_DISSOLVE:
+								gl.glUniform1f(program.getUniformLocation("dissolveSeed"), 100f*dissolveSeed/Integer.MAX_VALUE + (float)_context.getTime().toSecond());
+								break;
 						}
 
 						gl.glBegin(GL2.GL_QUADS);
@@ -559,9 +567,9 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 		pushMatrixAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
-				final GL2 gl = _vrContext.getGL().getGL2();
+				final GL2 gl = _context.getGL().getGL2();
 
-				ortho2D(gl, _vrContext.getGLU(), imageSize);
+				ortho2D(gl, _context.getGLU(), imageSize);
 
 				final int maxLayers = BlendModeShaders.getMaxIntersectingLayers();
 
@@ -573,6 +581,8 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 				final int[] blendMode = new int[nLayers];
 				final float[] opacity = new float[maxLayers];
+				final float[] dissolveSeed = new float[maxLayers];
+				float time = (float)_context.getTime().toSecond();
 
 				// レンダリング先を resultTexture に設定
 				gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
@@ -591,6 +601,16 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 					gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, vlb.getDepthBuffer().getTexture());
 					blendMode[i] = vlb.getBlendMode().ordinal();
 					opacity[i] = (float)vlb.getOpacity();
+
+					switch (vlb.getBlendMode()) {
+						case DISSOLVE:
+							dissolveSeed[i] = 100f*vlb.getDissolveSeed()/Integer.MAX_VALUE;
+							break;
+						case DANCING_DISSOLVE:
+							dissolveSeed[i] = 100f*vlb.getDissolveSeed()/Integer.MAX_VALUE + time;
+							break;
+					}
+
 					++i;
 					if (i >= nLayers) break;
 				}
@@ -609,7 +629,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 							gl.glUniform1i(program.getUniformLocation("blendMode" + i), blendMode[i]);
 						}
 						gl.glUniform1fv(program.getUniformLocation("opacity[0]"), maxLayers, opacity, 0);
-						gl.glUniform1f(program.getUniformLocation("time"), (float)(_vrContext.getTime().toSecond()));
+						gl.glUniform1fv(program.getUniformLocation("dissolveSeed[0]"), maxLayers, dissolveSeed, 0);
 
 						gl.glBegin(GL2.GL_QUADS);
 						gl.glTexCoord2f(0, 0);
@@ -641,8 +661,8 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	public void premultiply(final VideoBuffer vb) {
 		pushMatrixAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
-				GL2 gl = _vrContext.getGL().getGL2();
-				GLU glu = _vrContext.getGLU();
+				GL2 gl = _context.getGL().getGL2();
+				GLU glu = _context.getGLU();
 
 				VideoBounds bounds = vb.getBounds();
 				ortho2D(gl, glu, bounds.width, bounds.height);
@@ -681,9 +701,9 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 		pushMatrixAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
-				GL2 gl = _vrContext.getGL().getGL2();
+				GL2 gl = _context.getGL().getGL2();
 
-				ortho2D(gl, _vrContext.getGLU(), dstBounds.width, dstBounds.height);
+				ortho2D(gl, _context.getGLU(), dstBounds.width, dstBounds.height);
 				gl.glTranslatef((float) -dstBounds.x, (float) -dstBounds.y, 0);
 
 
@@ -724,7 +744,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	}
 
 	public <T> T pushMatrixAndExecute(WrappedOperation<T> operation) {
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 
 		int[] viewport = new int[4];
 		gl.glGetIntegerv(GL2.GL_VIEWPORT, viewport, 0);
@@ -750,7 +770,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	public void multModelViewMatrix(
 			Vec3d anchorPoint, Vec3d scale, Vec3d orientation, Vec3d rotate, Vec3d position) {
 
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 		gl.glMatrixMode(GL2.GL_MODELVIEW);
 
 		// 位置
@@ -776,7 +796,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	public void multModelViewMatrixInverse(
 			Vec3d anchorPoint, Vec3d scale, Vec3d orientation, Vec3d rotate, Vec3d position) {
 
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 		gl.glMatrixMode(GL2.GL_MODELVIEW);
 
 		// アンカーポイント
@@ -808,7 +828,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 		float _1 = flipZ ? -1 : 1;
 
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 		gl.glMatrixMode(GL2.GL_MODELVIEW);
 
 		// 回転
@@ -840,7 +860,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 		double dy = pointOfInterest.y - position.y;
 		double dz = pointOfInterest.z - position.z;
 
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 		gl.glMatrixMode(GL2.GL_MODELVIEW);
 
 		// 位置
@@ -862,13 +882,13 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	}
 
 	public void multModelViewMatrix(double[] mvMatrix) {
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 		gl.glMatrixMode(GL2.GL_MODELVIEW);
 		gl.glMultMatrixd(mvMatrix, 0);
 	}
 
 	public void getMatrix(double[] mvMatrix, double[] prjMatrix) {
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 		if (mvMatrix != null) {
 			gl.glGetDoublev(GL2.GL_MODELVIEW_MATRIX, mvMatrix, 0);
 		}
@@ -878,7 +898,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	}
 
 	public void setMatrix(double[] mvMatrix, double[] prjMatrix) {
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 		if (prjMatrix != null) {
 			gl.glMatrixMode(GL2.GL_PROJECTION);
 			gl.glLoadMatrixd(prjMatrix, 0);
@@ -890,7 +910,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	}
 
 	public void resetMatrix() {
-		GL2 gl = _vrContext.getGL().getGL2();
+		GL2 gl = _context.getGL().getGL2();
 		gl.glMatrixMode(GL2.GL_PROJECTION);
 		gl.glLoadIdentity();
 		gl.glMatrixMode(GL2.GL_MODELVIEW);
@@ -900,7 +920,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	public Vec3d project(Vec3d point, double[] mvMatrix, double[] prjMatrix, Size2i viewportSize) {
 		int[] viewport = new int[] { 0, 0, viewportSize.width, viewportSize.height };
 		double[] result = new double[3];
-		_vrContext.getGLU().gluProject(
+		_context.getGLU().gluProject(
 				point.x, point.y, point.z,
 				mvMatrix, 0, prjMatrix, 0, viewport, 0,
 				result, 0);
@@ -922,7 +942,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 		pushMatrixAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
-				GL2 gl = _vrContext.getGL().getGL2();
+				GL2 gl = _context.getGL().getGL2();
 
 				gl.glViewport(0, 0, resultImageSize.width, resultImageSize.height);
 				gl.glMatrixMode(GL2.GL_PROJECTION);
@@ -989,8 +1009,8 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 		pushMatrixAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
-				GL2 gl = _vrContext.getGL().getGL2();
-				GLU glu = _vrContext.getGLU();
+				GL2 gl = _context.getGL().getGL2();
+				GLU glu = _context.getGLU();
 
 				gl.glViewport(0, 0, resultImageSize.width, resultImageSize.height);
 
@@ -1054,9 +1074,9 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 		pushMatrixAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
-				final GL2 gl = _vrContext.getGL().getGL2();
+				final GL2 gl = _context.getGL().getGL2();
 
-				ortho2D(gl, _vrContext.getGLU(), bounds.width, bounds.height);
+				ortho2D(gl, _context.getGLU(), bounds.width, bounds.height);
 
 				gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
 						GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, dstTexture, 0);
@@ -1147,7 +1167,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 		int[] viewport = new int[] { 0, 0, w, h };
 		double[][] unprj = new double[8][3];
 
-		GLU glu = _vrContext.getGLU();
+		GLU glu = _context.getGLU();
 		glu.gluUnProject(0, 0, 0, mvMatrix, 0, prjMatrix, 0, viewport, 0, unprj[0], 0);
 		glu.gluUnProject(0, 0, 1, mvMatrix, 0, prjMatrix, 0, viewport, 0, unprj[1], 0);
 		glu.gluUnProject(w, 0, 0, mvMatrix, 0, prjMatrix, 0, viewport, 0, unprj[2], 0);
@@ -1221,7 +1241,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 			pushMatrixAndExecute(new WrappedOperation<Object>() {
 				public Object execute() {
-					GL2 gl = _vrContext.getGL().getGL2();
+					GL2 gl = _context.getGL().getGL2();
 
 					gl.glViewport(0, 0, w, h);
 					gl.glMatrixMode(GL2.GL_PROJECTION);
@@ -1276,10 +1296,10 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 		pushMatrixAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
-				GL2 gl = _vrContext.getGL().getGL2();
-				GLU glu = _vrContext.getGLU();
+				GL2 gl = _context.getGL().getGL2();
+				GLU glu = _context.getGLU();
 
-				float scale = (float) _vrContext.getRenderResolution().scale;
+				float scale = (float) _context.getVideoResolution().scale;
 
 				ortho2D(gl, glu, resultBounds.width, resultBounds.height);
 				gl.glTranslatef((float) -resultBounds.x, (float) -resultBounds.y, 0);
@@ -1333,9 +1353,9 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 
 		pushMatrixAndExecute(new WrappedOperation<Object>() {
 			public Object execute() {
-				final GL2 gl = _vrContext.getGL().getGL2();
+				final GL2 gl = _context.getGL().getGL2();
 
-				final float scale = (float) _vrContext.getRenderResolution().scale;
+				final float scale = (float) _context.getVideoResolution().scale;
 
 				gl.glViewport(0, 0, resultImageSize.width, resultImageSize.height);
 				gl.glMatrixMode(GL2.GL_PROJECTION);
