@@ -32,16 +32,15 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import ch.kuramo.javie.api.AudioMode;
-import ch.kuramo.javie.api.RenderResolution;
+import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.Composition;
 import ch.kuramo.javie.core.VideoBuffer;
 import ch.kuramo.javie.core.misc.AtiIntelLock;
-import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
 import ch.kuramo.javie.core.services.GLGlobal;
-import ch.kuramo.javie.core.services.VideoRenderContext;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
@@ -83,14 +82,11 @@ public abstract class PullSourceOutput {
 	private final BlockingQueue<Object> _audioResponseQueue = new ArrayBlockingQueue<Object>(1);
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private VideoRenderSupport _vrSupport;
 
-	@Inject
-	private AudioRenderContext _arContext;
-
 	@Inject
 	private AudioRenderSupport _arSupport;
 
@@ -99,7 +95,7 @@ public abstract class PullSourceOutput {
 
 
 	public void doOutput(final Composition comp, final AudioMode audioMode, File file, ProgressMonitor progMon) {
-		Thread videoThread = new Thread(new Runnable() { public void run() { videoLoop(comp); } });
+		Thread videoThread = new Thread(new Runnable() { public void run() { videoLoop(comp, audioMode); } });
 		videoThread.start();
 
 		Thread audioThread = new Thread(new Runnable() { public void run() { audioLoop(comp, audioMode); } });
@@ -124,12 +120,12 @@ public abstract class PullSourceOutput {
 	protected abstract void doOutput(Composition comp, AudioMode audioMode, File file);
 
 
-	protected void videoLoop(Composition comp) {
+	protected void videoLoop(Composition comp, AudioMode audioMode) {
 		AtiIntelLock atiIntelLock = AtiIntelLock.get(_glGlobal);
 
-		_vrContext.activate();
+		_context.activate();
 		try {
-			comp.prepareExpression(_vrContext.createInitialExpressionScope(comp));
+			comp.prepareExpression(_context.createInitialExpressionScope(comp));
 
 			while (true) {
 				VideoBuffer vb = null;
@@ -139,10 +135,12 @@ public abstract class PullSourceOutput {
 
 					if (time == null) break;
 
-					_vrContext.reset();
-					_vrContext.setRenderResolution(RenderResolution.FULL);
-					_vrContext.setFrameDuration(comp.getFrameDuration());
-					_vrContext.setTime(time);
+					_context.reset();
+					_context.setVideoResolution(Resolution.FULL);
+					_context.setVideoFrameDuration(comp.getFrameDuration());
+					_context.setAudioMode(audioMode);
+					_context.setAudioAnimationRate(audioMode.sampleRate/100);
+					_context.setTime(time);
 
 					atiIntelLock.lock();
 					try {
@@ -169,7 +167,7 @@ public abstract class PullSourceOutput {
 				}
 			}
 		} finally {
-			_vrContext.deactivate();
+			_context.deactivate();
 		}
 	}
 
@@ -184,9 +182,9 @@ public abstract class PullSourceOutput {
 	protected void audioLoop(Composition comp, AudioMode audioMode) {
 		long totalFrames = comp.getDuration().toFrameNumber(audioMode.sampleDuration);
 
-		_arContext.activate();
+		_context.activate();
 		try {
-			comp.prepareExpression(_arContext.createInitialExpressionScope(comp));
+			comp.prepareExpression(_context.createInitialExpressionScope(comp));
 
 			while (true) {
 				AudioBuffer ab = null;
@@ -196,11 +194,13 @@ public abstract class PullSourceOutput {
 
 					if (time == null) break;
 
-					_arContext.reset();
-					_arContext.setAudioMode(audioMode);
-					_arContext.setTime(time);
-					_arContext.setFrameCount((int) Math.min(request.frameCount, totalFrames-time.timeValue));
-					_arContext.setEvaluationResolution(audioMode.sampleRate/100);
+					_context.reset();
+					_context.setAudioMode(audioMode);
+					_context.setAudioAnimationRate(audioMode.sampleRate/100);
+					_context.setAudioFrameCount((int) Math.min(request.frameCount, totalFrames-time.timeValue));
+					_context.setVideoResolution(Resolution.FULL);
+					_context.setVideoFrameDuration(comp.getFrameDuration());
+					_context.setTime(time);
 
 					ab = comp.renderAudioChunk();
 					if (ab == null) {
@@ -217,7 +217,7 @@ public abstract class PullSourceOutput {
 				}
 			}
 		} finally {
-			_arContext.deactivate();
+			_context.deactivate();
 		}
 	}
 
