@@ -27,16 +27,15 @@ import java.io.File;
 import java.util.Arrays;
 
 import ch.kuramo.javie.api.AudioMode;
-import ch.kuramo.javie.api.RenderResolution;
+import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.Composition;
 import ch.kuramo.javie.core.VideoBuffer;
 import ch.kuramo.javie.core.misc.AtiIntelLock;
-import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
 import ch.kuramo.javie.core.services.GLGlobal;
-import ch.kuramo.javie.core.services.VideoRenderContext;
+import ch.kuramo.javie.core.services.RenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
@@ -44,14 +43,11 @@ import com.google.inject.Inject;
 public abstract class PushSourceOutput {
 
 	@Inject
-	private VideoRenderContext _vrContext;
+	private RenderContext _context;
 
 	@Inject
 	private VideoRenderSupport _vrSupport;
 
-	@Inject
-	private AudioRenderContext _arContext;
-
 	@Inject
 	private AudioRenderSupport _arSupport;
 
@@ -66,16 +62,40 @@ public abstract class PushSourceOutput {
 
 		final ProgressMonitor monitor = (progMon != null) ? progMon : ProgressMonitor.NULL;
 
-		Thread audioThread = new Thread() { public void run() { audioLoop(comp, audioMode, monitor); } };
-		audioThread.start();
+		if (isVideoOutputting()) {
+			Thread audioThread = null;
 
-		try {
-			videoLoop(comp, monitor);
-		} finally {
-			// TODO writeAudioでブロックされているときは永久に待ち続けるかもしれない。
-			try { audioThread.join(); } catch (InterruptedException e) { }
+			if (isAudioOutputting()) {
+				final ProgressMonitor audioMon = new ProgressMonitor() {
+					public void beginTask(int totalWork) { }
+					public void currentWork(int currentWork) { }
+					public void done() { }
+					public boolean isCanceled() { return monitor.isCanceled(); }
+				};
+				audioThread = new Thread() { public void run() { audioLoop(comp, audioMode, audioMon); } };
+				audioThread.start();
+			}
 
-			finish();
+			try {
+				videoLoop(comp, audioMode, monitor);
+			} finally {
+				if (audioThread != null) {
+					// TODO writeAudioでブロックされているときは永久に待ち続けるかもしれない。
+					try { audioThread.join(); } catch (InterruptedException e) { }
+				}
+
+				finish();
+			}
+
+		} else if (isAudioOutputting()) {
+			try {
+				audioLoop(comp, audioMode, monitor);
+			} finally {
+				finish();
+			}
+
+		} else {
+			throw new IllegalStateException("neither video nor audio is outputting.");
 		}
 	}
 
@@ -83,8 +103,12 @@ public abstract class PushSourceOutput {
 
 	protected abstract void finish();
 
+	protected abstract boolean isVideoOutputting();
 
-	protected void videoLoop(Composition comp, ProgressMonitor monitor) {
+	protected abstract boolean isAudioOutputting();
+
+
+	protected void videoLoop(Composition comp, AudioMode audioMode, ProgressMonitor monitor) {
 		AtiIntelLock atiIntelLock = AtiIntelLock.get(_glGlobal);
 
 		Time frameDuration = comp.getFrameDuration();
@@ -92,16 +116,18 @@ public abstract class PushSourceOutput {
 
 		monitor.beginTask((int)numFrames);
 
-		_vrContext.activate();
+		_context.activate();
 		try {
-			comp.prepareExpression(_vrContext.createInitialExpressionScope(comp));
+			comp.prepareExpression(_context.createInitialExpressionScope(comp));
 
 			for (long i = 0; i < numFrames && !monitor.isCanceled(); ++i) {
 				Time time = Time.fromFrameNumber(i, frameDuration);
-				_vrContext.reset();
-				_vrContext.setRenderResolution(RenderResolution.FULL);
-				_vrContext.setFrameDuration(comp.getFrameDuration());
-				_vrContext.setTime(time);
+				_context.reset();
+				_context.setVideoResolution(Resolution.FULL);
+				_context.setVideoFrameDuration(comp.getFrameDuration());
+				_context.setAudioMode(audioMode);
+				_context.setAudioAnimationRate(audioMode.sampleRate/100);
+				_context.setTime(time);
 
 				VideoBuffer vb = null;
 				try {
@@ -116,7 +142,7 @@ public abstract class PushSourceOutput {
 						// glFinishしておけば writeVideo は AtiIntelLock の外でいいはず。
 						//gl.glFinish();
 
-						writeVideo(time, vb);
+						writeVideo(i, time, vb);
 
 					} finally {
 						atiIntelLock.unlock();
@@ -128,13 +154,13 @@ public abstract class PushSourceOutput {
 				monitor.currentWork((int)i);
 			}
 		} finally {
-			_vrContext.deactivate();
+			_context.deactivate();
 		}
 
 		monitor.done();
 	}
 
-	protected abstract void writeVideo(Time time, VideoBuffer vb);
+	protected abstract void writeVideo(long frameNumber, Time time, VideoBuffer vb);
 
 
 	protected void audioLoop(Composition comp, AudioMode audioMode, ProgressMonitor monitor) {
@@ -143,35 +169,43 @@ public abstract class PushSourceOutput {
 		// １回あたりの処理量を１秒分のフレーム数（＝サンプルレートの値と同じ数）とする。
 		int chunkFrames = audioMode.sampleRate;
 
-		_arContext.activate();
+		monitor.beginTask((int)totalFrames);
+
+		_context.activate();
 		try {
-			comp.prepareExpression(_arContext.createInitialExpressionScope(comp));
+			comp.prepareExpression(_context.createInitialExpressionScope(comp));
 
 			for (long i = 0; i < totalFrames && !monitor.isCanceled(); ) {
 				Time time = Time.fromFrameNumber(i, audioMode.sampleDuration);
-				_arContext.reset();
-				_arContext.setAudioMode(audioMode);
-				_arContext.setTime(time);
-				_arContext.setFrameCount((int) Math.min(chunkFrames, totalFrames-i));
-				_arContext.setEvaluationResolution(audioMode.sampleRate/100);
+				_context.reset();
+				_context.setAudioMode(audioMode);
+				_context.setAudioAnimationRate(audioMode.sampleRate/100);
+				_context.setAudioFrameCount((int) Math.min(chunkFrames, totalFrames-i));
+				_context.setVideoResolution(Resolution.FULL);
+				_context.setVideoFrameDuration(comp.getFrameDuration());
+				_context.setTime(time);
 
 				AudioBuffer ab = comp.renderAudioChunk();
 				try {
 					if (ab == null) {
 						ab = createAudioBufferClear();
 					}
-					writeAudio(time, ab);
+					writeAudio(i, time, ab);
 					i+= ab.getFrameCount();
 				} finally {
 					ab.dispose();
 				}
+
+				monitor.currentWork((int)i);
 			}
 		} finally {
-			_arContext.deactivate();
+			_context.deactivate();
 		}
+
+		monitor.done();
 	}
 
-	protected abstract void writeAudio(Time time, AudioBuffer ab);
+	protected abstract void writeAudio(long frameNumber, Time time, AudioBuffer ab);
 
 
 	private AudioBuffer createAudioBufferClear() {
