@@ -1,3 +1,26 @@
+/*
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * All rights reserved.
+ * 
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ * 
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ * 
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
+ */
+
 package ch.kuramo.javie.core.output;
 
 import java.io.File;
@@ -73,13 +96,23 @@ public class WindowsDirectShowOutput extends PushSourceOutput {
 	}
 
 	@Override
-	protected void videoLoop(Composition comp, ProgressMonitor monitor) {
-		super.videoLoop(comp, monitor);
+	protected boolean isVideoOutputting() {
+		return true;
+	}
+
+	@Override
+	protected boolean isAudioOutputting() {
+		return true;
+	}
+
+	@Override
+	protected void videoLoop(Composition comp, AudioMode audioMode, ProgressMonitor monitor) {
+		super.videoLoop(comp, audioMode, monitor);
 		_videoTime = comp.getDuration();
 	}
 
 	@Override
-	protected void writeVideo(Time time, VideoBuffer vb) {
+	protected void writeVideo(long frameNumber, Time time, VideoBuffer vb) {
 		long dsTimeStart = (long)(DS_TIME_SCALE*time.toSecond());
 		long dsTimeEnd = (long)(DS_TIME_SCALE*time.add(_frameDuration).toSecond());
 		writeVideo(_nativeObjPointer, dsTimeStart, dsTimeEnd, (byte[])vb.getArray());
@@ -96,7 +129,7 @@ public class WindowsDirectShowOutput extends PushSourceOutput {
 	}
 
 	@Override
-	protected void writeAudio(Time time, AudioBuffer ab) {
+	protected void writeAudio(long frameNumber, Time time, AudioBuffer ab) {
 		// インターリーブの設定をするとなぜか書き出し途中で固まる。
 		// オーディオの書き出しに適当なスリープを挟んでやるとひとまず回避できるようなので今はそうしている。
 		// （でも、問題が再現しにくくなっているだけだと思うが...）
