@@ -35,7 +35,6 @@ import ch.kuramo.javie.core.internal.services.AntiAliasSupportProxy;
 import ch.kuramo.javie.core.internal.services.ArrayPoolsImpl;
 import ch.kuramo.javie.core.internal.services.AudioEffectContextProxy;
 import ch.kuramo.javie.core.internal.services.AudioEffectPipelineImpl;
-import ch.kuramo.javie.core.internal.services.AudioRenderContextProxy;
 import ch.kuramo.javie.core.internal.services.AudioRenderSupportImpl;
 import ch.kuramo.javie.core.internal.services.EffectRegistryImpl;
 import ch.kuramo.javie.core.internal.services.FontListImpl;
@@ -46,11 +45,11 @@ import ch.kuramo.javie.core.internal.services.ProjectDecoderImpl;
 import ch.kuramo.javie.core.internal.services.ProjectElementFactoryImpl;
 import ch.kuramo.javie.core.internal.services.ProjectEncoderImpl;
 import ch.kuramo.javie.core.internal.services.RenderBufferPoolImpl;
+import ch.kuramo.javie.core.internal.services.RenderContextProxy;
 import ch.kuramo.javie.core.internal.services.ShaderRegistryImpl;
 import ch.kuramo.javie.core.internal.services.SynchronousTaskThreadImpl;
 import ch.kuramo.javie.core.internal.services.VideoEffectContextProxy;
 import ch.kuramo.javie.core.internal.services.VideoEffectPipelineImpl;
-import ch.kuramo.javie.core.internal.services.VideoRenderContextProxy;
 import ch.kuramo.javie.core.internal.services.VideoRenderSupportImpl;
 
 import com.google.inject.AbstractModule;
@@ -95,8 +94,8 @@ public class JavieCoreModule extends AbstractModule {
 		bind(IShaderRegistry.class)
 				.toInstance(shaderRegistry);
 
-		bind(VideoRenderContext.class)
-				.to(VideoRenderContextProxy.class)
+		bind(RenderContext.class)
+				.to(RenderContextProxy.class)
 				.in(Scopes.SINGLETON);
 
 		bind(VideoRenderSupport.class)
@@ -111,10 +110,6 @@ public class JavieCoreModule extends AbstractModule {
 				.to(VideoEffectContextProxy.class)
 				.in(Scopes.SINGLETON);
 
-		bind(AudioRenderContext.class)
-				.to(AudioRenderContextProxy.class)
-				.in(Scopes.SINGLETON);
-
 		bind(AudioRenderSupport.class)
 				.to(AudioRenderSupportImpl.class)
 				.in(Scopes.SINGLETON);
