@@ -32,8 +32,11 @@ import ch.kuramo.javie.core.WrappedOperation;
 
 public interface VideoEffectPipeline {
 
-	VideoBounds getVideoBounds(List<Effect> effects, WrappedOperation<VideoBounds> inputBoundsOperation);
+	VideoBounds getVideoBounds(List<Effect> effects,
+			WrappedOperation<VideoBounds> inputBoundsOperation);
 
-	VideoBuffer doVideoEffects(List<Effect> effects, WrappedOperation<VideoBuffer> inputBufferOperation);
+	VideoBuffer doVideoEffects(List<Effect> effects,
+			WrappedOperation<VideoBounds> inputBoundsOperation,
+			WrappedOperation<VideoBuffer> inputBufferOperation);
 
 }
