@@ -74,7 +74,9 @@ public interface VideoRenderSupport {
 			VideoBuffer matteBuffer, VideoBuffer fillBuffer, VideoBuffer resultBuffer,
 			TrackMatte trackMatte, double matteOpacity);
 
-	void blend(VideoBuffer srcBuffer, VideoBuffer dstBuffer, VideoBuffer resultBuffer, BlendMode blendMode, double opacity);
+	void blend(
+			VideoBuffer srcBuffer, VideoBuffer dstBuffer, VideoBuffer resultBuffer,
+			BlendMode blendMode, double opacity, int dissolveSeed);
 
 	void blend(Collection<VideoLayerBuffer> srcBuffers, VideoBuffer dstBuffer, VideoBuffer resultBuffer);
 
