@@ -37,21 +37,21 @@ import com.google.inject.Inject;
 
 public class BlendModeShaders {
 
-	private static final String[] createProgramSource(String name, boolean temporal) {
+	private static final String[] createProgramSource(String name, boolean dissolve) {
 		return new String[] {
 								"uniform sampler2DRect texDst;",
 								"uniform sampler2DRect texSrc;",
 								"uniform float opacity;",
-				temporal ?		"uniform float time;" : "",
+				dissolve ?		"uniform float dissolveSeed;" : "",
 								"",
-				String.format(	"vec4 blend_%s(vec4 pDst, vec4 pSrc, float opacity%s);", name, temporal ? ", float time" : ""),
+				String.format(	"vec4 blend_%s(vec4 pDst, vec4 pSrc, float opacity%s);", name, dissolve ? ", float dissolveSeed" : ""),
 								"",
 								"void main(void)",
 								"{",
 								"	vec2 texCoord = gl_TexCoord[0].st;",
 								"	vec4 dst = texture2DRect(texDst, texCoord);",
 								"	vec4 src = texture2DRect(texSrc, texCoord);",
-				String.format(	"	dst = blend_%s(vec4(dst.rgb*dst.a, dst.a), src, opacity%s);", name, temporal ? ", time" : ""),
+				String.format(	"	dst = blend_%s(vec4(dst.rgb*dst.a, dst.a), src, opacity%s);", name, dissolve ? ", dissolveSeed" : ""),
 								"	gl_FragColor = (dst.a != 0.0) ? vec4(dst.rgb/dst.a, dst.a) : vec4(0.0);",
 								"}"
 		};
@@ -70,10 +70,10 @@ public class BlendModeShaders {
 	public static final String[] NORMAL = createProgramSource("normal");
 
 	@ShaderSource(attach="blend_functions")
-	public static final String[] DISSOLVE = createProgramSource("dissolve");
+	public static final String[] DISSOLVE = createProgramSource("dissolve", true);
 
 	@ShaderSource(attach="blend_functions")
-	public static final String[] DANCING_DISSOLVE = createProgramSource("dancing_dissolve", true);
+	public static final String[] DANCING_DISSOLVE = DISSOLVE;
 
 	@ShaderSource(attach="blend_functions")
 	public static final String[] DARKEN = createProgramSource("darken");
@@ -197,7 +197,7 @@ public class BlendModeShaders {
 		uniform sampler2DRect texDepN;
 		uniform int blendModeN;
 		uniform float opacity[maxLayers];
-		uniform float time;
+		uniform float dissolveSeed[maxLayers];
 
 		vec2 texCoord = gl_TexCoord[0].st;
 		********************/
@@ -214,7 +214,7 @@ public class BlendModeShaders {
 		}
 
 		source.add("uniform float opacity[maxLayers];");
-		source.add("uniform float time;");
+		source.add("uniform float dissolveSeed[maxLayers];");
 
 		source.add("vec2 texCoord = gl_TexCoord[0].st;");
 
@@ -325,7 +325,7 @@ public class BlendModeShaders {
 		/********************/
 
 		source.addAll(Arrays.asList(new String[] {
-				"vec4 blend(int mode, vec4 pDst, vec4 pSrc, float opacity, float time);",
+				"vec4 blend(int mode, vec4 pDst, vec4 pSrc, float opacity, float dissolveSeed);",
 				"",
 				"void main(void)",
 				"{",
@@ -348,7 +348,7 @@ public class BlendModeShaders {
 				"	}",
 				"	if (nzaCount == 1) {",
 				"		dst = vec4(dst.rgb*dst.a, dst.a);",
-				"		dst = blend(getBlendMode(nzaLayer), dst, nzaColor, opacity[nzaLayer], time);",
+				"		dst = blend(getBlendMode(nzaLayer), dst, nzaColor, opacity[nzaLayer], dissolveSeed[nzaLayer]);",
 				"		dst = (dst.a != 0.0) ? vec4(dst.rgb/dst.a, dst.a) : vec4(0.0);",
 				"",
 				"	} else if (nzaCount > 1) {",
@@ -366,7 +366,7 @@ public class BlendModeShaders {
 				"		",
 				"		for (int i = 0; i < nLayers; ++i) {",
 				"			int ord = getOrd(i);",
-				"			dst = blend(getBlendMode(ord), dst, getSrc(ord), opacity[ord], time);",
+				"			dst = blend(getBlendMode(ord), dst, getSrc(ord), opacity[ord], dissolveSeed[ord]);",
 				"		}",
 				"		dst = (dst.a != 0.0) ? vec4(dst.rgb/dst.a, dst.a) : vec4(0.0);",
 				"	}",
@@ -421,8 +421,8 @@ public class BlendModeShaders {
 			public String[] getSource() {
 				return new String[] {
 										"vec4 blend_normal(vec4 pDst, vec4 pSrc, float opacity);",
-					 set.contains(1)  ? "vec4 blend_dissolve(vec4 pDst, vec4 pSrc, float opacity);" : "",
-					 set.contains(2)  ? "vec4 blend_dancing_dissolve(vec4 pDst, vec4 pSrc, float opacity, float time);" : "",
+					 set.contains(1) ||
+					 set.contains(2)  ? "vec4 blend_dissolve(vec4 pDst, vec4 pSrc, float opacity, float seed);" : "",
 
 					 set.contains(3)  ? "vec4 blend_darken(vec4 pDst, vec4 pSrc, float opacity);" : "",
 					 set.contains(4)  ? "vec4 blend_multiply(vec4 pDst, vec4 pSrc, float opacity);" : "",
@@ -458,12 +458,12 @@ public class BlendModeShaders {
 					 set.contains(29) ? "vec4 blend_silhouette_alpha(vec4 pDst, vec4 pSrc, float opacity);" : "",
 					 set.contains(30) ? "vec4 blend_silhouette_luma(vec4 pDst, vec4 pSrc, float opacity);" : "",
 
-										"vec4 blend(int mode, vec4 pDst, vec4 pSrc, float opacity, float time)",
+										"vec4 blend(int mode, vec4 pDst, vec4 pSrc, float opacity, float dissolveSeed)",
 										"{",
 										"	return",
 					 set.contains(0)  ? "		(mode == 0) ? blend_normal(pDst, pSrc, opacity) :" : "",
-					 set.contains(1)  ? "		(mode == 1) ? blend_dissolve(pDst, pSrc, opacity) :" : "",
-					 set.contains(2)  ? "		(mode == 2) ? blend_dancing_dissolve(pDst, pSrc, opacity, time) :" : "",
+					 set.contains(1)  ? "		(mode == 1) ? blend_dissolve(pDst, pSrc, opacity, dissolveSeed) :" : "",
+					 set.contains(2)  ? "		(mode == 2) ? blend_dissolve(pDst, pSrc, opacity, dissolveSeed) :" : "",
 
 					 set.contains(3)  ? "		(mode == 3) ? blend_darken(pDst, pSrc, opacity) :" : "",
 					 set.contains(4)  ? "		(mode == 4) ? blend_multiply(pDst, pSrc, opacity) :" : "",
