@@ -34,7 +34,7 @@ import ch.kuramo.javie.api.IAnimatableInteger;
 import ch.kuramo.javie.api.IAnimatableVec2d;
 import ch.kuramo.javie.api.IShaderProgram;
 import ch.kuramo.javie.api.IVideoBuffer;
-import ch.kuramo.javie.api.RenderResolution;
+import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Vec2d;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.annotations.Effect;
@@ -42,6 +42,8 @@ import ch.kuramo.javie.api.annotations.Property;
 import ch.kuramo.javie.api.annotations.ShaderSource;
 import ch.kuramo.javie.api.services.IShaderRegistry;
 import ch.kuramo.javie.api.services.IVideoEffectContext;
+import ch.kuramo.javie.effects.BlendMode;
+import ch.kuramo.javie.effects.BlendModeShaders;
 import ch.kuramo.javie.effects.VideoEffectUtil;
 
 import com.google.inject.Inject;
@@ -121,47 +123,6 @@ public class FractalNoise {
 
 	public enum Overflow { CLIP, SOFT_CLAMP, WRAP_BACK, HDR }
 
-	public enum BlendMode {
-		NONE,
-		NORMAL,
-		//DISSOLVE,
-		//DANCING_DISSOLVE,
-
-		DARKEN,
-		MULTIPLY,
-		COLOR_BURN,
-		LINEAR_BURN,
-		DARKER_COLOR,
-
-		ADD,
-		LIGHTEN,
-		SCREEN,
-		COLOR_DODGE,
-		LINEAR_DODGE,
-		LIGHTER_COLOR,
-
-		OVERLAY,
-		SOFT_LIGHT,
-		HARD_LIGHT,
-		LINEAR_LIGHT,
-		VIVID_LIGHT,
-		PIN_LIGHT,
-		HARD_MIX,
-
-		DIFFERENCE,
-		EXCLUSION,
-
-		HUE,
-		SATURATION,
-		//COLOR,
-		LUMINOSITY,
-
-		//STENCIL_ALPHA,
-		STENCIL_LUMA,
-		//SILHOUETTE_ALPHA,
-		SILHOUETTE_LUMA;
-	}
-
 
 	@Property
 	private IAnimatableEnum<FractalType> fractalType;
@@ -226,15 +187,19 @@ public class FractalNoise {
 
 	private final IVideoEffectContext context;
 
-	private final IShaderRegistry shaders;
-
 	private final IShaderProgram program;
 
+	private final BlendModeShaders blendModeShaders;
+
 	@Inject
 	public FractalNoise(IVideoEffectContext context, IShaderRegistry shaders) {
 		this.context = context;
-		this.shaders = shaders;
+
 		program = shaders.getProgram(FractalNoise.class, "FRACTAL_NOISE");
+
+		blendModeShaders = BlendModeShaders.forPremult(context, shaders);
+		blendModeShaders.replace(BlendMode.HUE, shaders.getProgram(FractalNoise.class, "HUE"));
+		blendModeShaders.replace(BlendMode.SATURATION, shaders.getProgram(FractalNoise.class, "SATURATION"));
 	}
 
 	public IVideoBuffer doVideoEffect() {
@@ -260,7 +225,7 @@ public class FractalNoise {
 				buf2 = buf1;
 				buf1 = null;
 			} else {
-				buf2 = doBlend(gl, glu, buf1, input, blendMode, opacity);
+				buf2 = blendModeShaders.blend(buf1, input, blendMode, opacity);
 			}
 
 			IVideoBuffer result = buf2;
@@ -281,7 +246,7 @@ public class FractalNoise {
 		final int w = bounds.width;
 		final int h = bounds.height;
 
-		RenderResolution resolution = context.getRenderResolution();
+		Resolution resolution = context.getVideoResolution();
 
 
 		final FractalType fractalType = context.value(this.fractalType);
@@ -375,8 +340,8 @@ public class FractalNoise {
 
 			if (!centerSubscale) {
 				subOffsetMat.mul(new Matrix3d(
-						1.0, 0.0, w/resolution.scale/128,	// TODO ここの値はこれでいいのか？
-						0.0, 1.0, h/resolution.scale/128,	//      あと、128で割らないとなぜか1/3解像度だけおかしくなる。
+						1.0, 0.0, 179,		// TODO ここの値はこれでいいのか？
+						0.0, 1.0, 179,		//      179は256以下の適当な素数。256がちょうど1周期分？
 						0.0, 0.0, 1.0));
 				subOffsetMat.mul(subOffsetMat1);
 			}
@@ -439,78 +404,6 @@ public class FractalNoise {
 		}
 	}
 
-	private IVideoBuffer doBlend(
-			final GL2 gl, GLU glu, IVideoBuffer noise, IVideoBuffer input,
-			final BlendMode blendMode, final double opacity) {
-
-		VideoBounds bounds = input.getBounds();
-		final int w = bounds.width;
-		final int h = bounds.height;
-
-		VideoEffectUtil.ortho2D(gl, glu, w, h);
-
-		IVideoBuffer buffer = context.createVideoBuffer(bounds);
-		try {
-			gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
-					GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, buffer.getTexture(), 0);
-			gl.glDrawBuffer(GL2.GL_COLOR_ATTACHMENT0);
-
-			gl.glActiveTexture(GL2.GL_TEXTURE0);
-			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, noise.getTexture());
-			gl.glActiveTexture(GL2.GL_TEXTURE1);
-			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, input.getTexture());
-
-			final IShaderProgram program = shaders.getProgram(FractalNoise.class, blendMode.name());
-			program.useProgram(new Runnable() {
-				public void run() {
-					gl.glUniform1i(program.getUniformLocation("texNoise"), 0);
-					if (blendMode != BlendMode.NONE) {
-						gl.glUniform1i(program.getUniformLocation("texOrig"), 1);
-					}
-					gl.glUniform1f(program.getUniformLocation("opacity"), (float)opacity);
-
-					gl.glBegin(GL2.GL_QUADS);
-					gl.glTexCoord2f(0, 0);
-					gl.glVertex2f(0, 0);
-					gl.glTexCoord2f(w, 0);
-					gl.glVertex2f(w, 0);
-					gl.glTexCoord2f(w, h);
-					gl.glVertex2f(w, h);
-					gl.glTexCoord2f(0, h);
-					gl.glVertex2f(0, h);
-					gl.glEnd();
-				}
-			});
-
-			gl.glActiveTexture(GL2.GL_TEXTURE1);
-			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, 0);
-			gl.glActiveTexture(GL2.GL_TEXTURE0);
-			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, 0);
-
-			gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
-					GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, 0, 0);
-
-			IVideoBuffer result = buffer;
-			buffer = null;
-			return result;
-
-		} finally {
-			if (buffer != null) buffer.dispose();
-		}
-	}
-
-	@ShaderSource
-	public static final String[] NONE = {
-		"uniform sampler2DRect texNoise;",
-		"uniform float opacity;",
-		"",
-		"void main(void)",
-		"{",
-		"	vec3 rgb = texture2DRect(texNoise, gl_TexCoord[0].st).rgb;",
-		"	gl_FragColor = vec4(rgb*opacity, 1.0);",
-		"}"
-	};
-
 	@ShaderSource(program=false)
 	public static final String[] hsl2rgb = {
 		"float hue2rgb(float t1, float t2, float hue)",
@@ -548,8 +441,8 @@ public class FractalNoise {
 
 	private static String[] createHueOrSaturationBlendSource(boolean hue) {
 		return new String[] {
-				"uniform sampler2DRect texNoise;",
-				"uniform sampler2DRect texOrig;",
+				"uniform sampler2DRect texDst;",	// original
+				"uniform sampler2DRect texSrc;",	// noise
 				"uniform float opacity;",
 				"",
 				"const vec3 lumaVec = vec3(0.299, 0.587, 0.114);",
@@ -562,8 +455,8 @@ public class FractalNoise {
 				"void main(void)",
 				"{",
 				"	vec2 texCoord = gl_TexCoord[0].st;",
-				"	vec4 pSrc = texture2DRect(texNoise, texCoord);",
-				"	vec4 pDst = texture2DRect(texOrig, texCoord);",
+				"	vec4 pDst = texture2DRect(texDst, texCoord);",
+				"	vec4 pSrc = texture2DRect(texSrc, texCoord);",
 				"",
 				"	float da = pDst.a;",
 				"	float sa = pSrc.a*opacity;",
@@ -588,116 +481,4 @@ public class FractalNoise {
 	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
 	public static final String[] SATURATION = createHueOrSaturationBlendSource(false);
 
-
-	private static String[] createBlendSource(String name) {
-		return new String[] {
-								"uniform sampler2DRect texNoise;",
-								"uniform sampler2DRect texOrig;",
-								"uniform float opacity;",
-								"",
-				String.format(	"vec4 blend_%s(vec4 pDst, vec4 pSrc, float opacity);", name),
-								"",
-								"void main(void)",
-								"{",
-								"	vec2 texCoord = gl_TexCoord[0].st;",
-								"	vec4 noise = texture2DRect(texNoise, texCoord);",
-								"	vec4 orig = texture2DRect(texOrig, texCoord);",
-				String.format(	"	gl_FragColor = blend_%s(orig, noise, opacity);", name),
-								"}"
-		};
-	}
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] NORMAL = createBlendSource("normal");
-
-//	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-//	public static final String[] DISSOLVE = createBlendSource("dissolve");
-//
-//	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-//	public static final String[] DANCING_DISSOLVE = createBlendSource("dancing_dissolve");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] DARKEN = createBlendSource("darken");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] MULTIPLY = createBlendSource("multiply");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] COLOR_BURN = createBlendSource("color_burn");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] LINEAR_BURN = createBlendSource("linear_burn");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] DARKER_COLOR = createBlendSource("darker_color");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] ADD = createBlendSource("add");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] LIGHTEN = createBlendSource("lighten");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] SCREEN = createBlendSource("screen");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] COLOR_DODGE = createBlendSource("color_dodge");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] LINEAR_DODGE = createBlendSource("linear_dodge");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] LIGHTER_COLOR = createBlendSource("lighter_color");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] OVERLAY = createBlendSource("overlay");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] SOFT_LIGHT = createBlendSource("soft_light");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] HARD_LIGHT = createBlendSource("hard_light");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] LINEAR_LIGHT = createBlendSource("linear_light");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] VIVID_LIGHT = createBlendSource("vivid_light");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] PIN_LIGHT = createBlendSource("pin_light");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] HARD_MIX = createBlendSource("hard_mix");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] DIFFERENCE = createBlendSource("difference");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] EXCLUSION = createBlendSource("exclusion");
-
-//	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-//	public static final String[] HUE = createBlendSource("hue");
-//
-//	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-//	public static final String[] SATURATION = createBlendSource("saturation");
-//
-//	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-//	public static final String[] COLOR = createBlendSource("color");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] LUMINOSITY = createBlendSource("luminosity");
-
-//	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-//	public static final String[] STENCIL_ALPHA = createBlendSource("stencil_alpha");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] STENCIL_LUMA = createBlendSource("stencil_luma");
-
-//	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-//	public static final String[] SILHOUETTE_ALPHA = createBlendSource("silhouette_alpha");
-
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] SILHOUETTE_LUMA = createBlendSource("silhouette_luma");
-
 }
