@@ -39,6 +39,8 @@ import ch.kuramo.javie.api.annotations.Property;
 import ch.kuramo.javie.api.annotations.ShaderSource;
 import ch.kuramo.javie.api.services.IShaderRegistry;
 import ch.kuramo.javie.api.services.IVideoEffectContext;
+import ch.kuramo.javie.effects.BlendMode;
+import ch.kuramo.javie.effects.BlendModeShaders;
 import ch.kuramo.javie.effects.VideoEffectUtil;
 import ch.kuramo.javie.effects.blurSharpen.BlurUtil;
 
@@ -53,47 +55,6 @@ public class Glow {
 
 	public enum GlowDimensions { BOTH, HORIZONTAL, VERTICAL }
 
-	public enum GlowOperation {
-		NONE,
-		NORMAL,
-		DISSOLVE,
-		//DANCING_DISSOLVE,
-
-		DARKEN,
-		MULTIPLY,
-		COLOR_BURN,
-		LINEAR_BURN,		// AEには無い
-		DARKER_COLOR,		// AEには無い
-
-		ADD,
-		LIGHTEN,
-		SCREEN,
-		COLOR_DODGE,
-		LINEAR_DODGE,		// AEには無い
-		LIGHTER_COLOR,		// AEには無い
-
-		OVERLAY,
-		SOFT_LIGHT,
-		HARD_LIGHT,
-		LINEAR_LIGHT,		// AEには無い
-		VIVID_LIGHT,		// AEには無い
-		PIN_LIGHT,			// AEには無い
-		HARD_MIX,			// AEには無い
-
-		DIFFERENCE,
-		EXCLUSION,
-
-		HUE,
-		SATURATION,
-		COLOR,
-		LUMINOSITY,
-
-		STENCIL_ALPHA,
-		STENCIL_LUMA,
-		SILHOUETTE_ALPHA,
-		SILHOUETTE_LUMA;
-	}
-
 	public enum GlowLooping { SAWTOOTH_AB, SAWTOOTH_BA, TRIANGLE_ABA, TRIANGLE_BAB }
 
 
@@ -113,7 +74,7 @@ public class Glow {
 	private IAnimatableEnum<GlowComposite> composite;
 
 	@Property("ADD")
-	private IAnimatableEnum<GlowOperation> operation;
+	private IAnimatableEnum<BlendMode> operation;
 
 	@Property("TRIANGLE_ABA")
 	private IAnimatableEnum<GlowLooping> colorLooping;
@@ -156,6 +117,8 @@ public class Glow {
 
 	private final IShaderProgram oColorsIntensityProgram;
 
+	private final IShaderProgram oColorsIntensityFloatProgram;
+
 	private final IShaderProgram abColorsIntensityProgram;
 
 	@Inject
@@ -168,6 +131,7 @@ public class Glow {
 		sawtoothProgram = shaders.getProgram(Glow.class, "SAWTOOTH");
 		triangleProgram = shaders.getProgram(Glow.class, "TRIANGLE");
 		oColorsIntensityProgram = shaders.getProgram(Glow.class, "OCOLORS_INTENSITY");
+		oColorsIntensityFloatProgram = shaders.getProgram(Glow.class, "OCOLORS_INTENSITY_FLOAT");
 		abColorsIntensityProgram = shaders.getProgram(Glow.class, "ABCOLORS_INTENSITY");
 	}
 
@@ -186,8 +150,8 @@ public class Glow {
 		// blurが50より大きい場合はfastプロパティの値にかかわらず高速モード
 		boolean fast = (radius > 50) || context.value(this.fast);
 
-		// レンダリング解像度に合わせてblurの値を変換
-		radius = context.getRenderResolution().scale(radius);
+		// 解像度に合わせてblurの値を変換
+		radius = context.getVideoResolution().scale(radius);
 
 
 		VideoBounds bounds = context.getPreviousBounds();
@@ -273,16 +237,13 @@ public class Glow {
 		"uniform float upper;",
 		"uniform float lower;",
 		"",
-		"const vec3 vec3_000 = vec3(0.0);",
-		"const vec3 vec3_111 = vec3(1.0);",
-		"",
 		"void main(void)",
 		"{",
 		"	vec4 color = texture2DRect(texture, gl_TexCoord[0].st);",
 		"	float a = color.a;",
 		"	vec3 rgb = (a != 0.0) ? color.rgb/a : vec3(0.0);",
 		"",
-		"	rgb = clamp((rgb - lower) / (upper - lower), vec3_000, vec3_111);",
+		"	rgb = clamp((rgb - lower) / (upper - lower), 0.0, 1.0);",
 		"",
 		"	gl_FragColor = vec4(rgb*a, a);",
 		"}"
@@ -397,7 +358,7 @@ public class Glow {
 
 		boolean fast = (radius > 50) || context.value(this.fast);
 
-		radius = context.getRenderResolution().scale(radius);
+		radius = context.getVideoResolution().scale(radius);
 
 		GL2 gl = context.getGL().getGL2();
 		GLU glu = context.getGLU();
@@ -666,6 +627,18 @@ public class Glow {
 
 	@ShaderSource
 	public static final String[] OCOLORS_INTENSITY = {
+		"uniform sampler2DRect texture;",
+		"uniform float intensity;",
+		"",
+		"void main(void)",
+		"{",
+		"	vec4 color = texture2DRect(texture, gl_TexCoord[0].st);",
+		"	gl_FragColor = vec4(min(color.rgb*intensity, color.a), color.a);",
+		"}"
+	};
+
+	@ShaderSource
+	public static final String[] OCOLORS_INTENSITY_FLOAT = {
 		"uniform sampler2DRect texture;",
 		"uniform float intensity;",
 		"",
@@ -673,7 +646,6 @@ public class Glow {
 		"{",
 		"	vec4 color = texture2DRect(texture, gl_TexCoord[0].st);",
 		"	gl_FragColor = vec4(color.rgb*intensity, color.a);",
-//		"	gl_FragColor = vec4(min(color.rgb*intensity, color.a), color.a);",	// TODO 8bit/16bit整数コンポはこっちにした方がいかも？
 		"}"
 	};
 
@@ -685,7 +657,7 @@ public class Glow {
 		"void main(void)",
 		"{",
 		"	vec4 color = texture2DRect(texture, gl_TexCoord[0].st);",
-		"	gl_FragColor = vec4(color.rgb*intensity, min(color.a*intensity, 1.0));",	// minは浮動小数コンポ用。整数コンポでは勝手にクリップされる。
+		"	gl_FragColor = vec4(color.rgb*intensity, min(color.a*intensity, 1.0));",
 		"}"
 	};
 
@@ -696,8 +668,9 @@ public class Glow {
 		}
 
 		// A_AND_B_COLORS と A_AND_B_COLORS_ALPHA_BASE のシェーダは同じ
-		final IShaderProgram program = (colors == GlowColors.ORIGINAL_COLORS)
-				? oColorsIntensityProgram : abColorsIntensityProgram;
+		final IShaderProgram program
+				= (colors != GlowColors.ORIGINAL_COLORS) ? abColorsIntensityProgram
+				: input.getColorMode().isFloat() ? oColorsIntensityFloatProgram : oColorsIntensityProgram;
 
 		final GL2 gl = context.getGL().getGL2();
 
@@ -753,9 +726,9 @@ public class Glow {
 
 	private IVideoBuffer composite(IVideoBuffer glow, IVideoBuffer orig) {
 		final GlowComposite composite = context.value(this.composite);
-		GlowOperation operation = context.value(this.operation);
+		BlendMode operation = context.value(this.operation);
 
-		if (composite == GlowComposite.NONE && operation == GlowOperation.NONE) {
+		if (composite == GlowComposite.NONE && operation == BlendMode.NONE) {
 			return glow;
 		}
 
@@ -854,100 +827,100 @@ public class Glow {
 		};
 	}
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] NONE = createCompositeSource("none");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] NORMAL = createCompositeSource("normal");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
-	public static final String[] DISSOLVE = createCompositeSource("dissolve");
-
-//	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+//	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
+//	public static final String[] DISSOLVE = createCompositeSource("dissolve");
+//
+//	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 //	public static final String[] DANCING_DISSOLVE = createCompositeSource("dancing_dissolve");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] DARKEN = createCompositeSource("darken");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] MULTIPLY = createCompositeSource("multiply");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] COLOR_BURN = createCompositeSource("color_burn");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] LINEAR_BURN = createCompositeSource("linear_burn");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] DARKER_COLOR = createCompositeSource("darker_color");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] ADD = createCompositeSource("add");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] LIGHTEN = createCompositeSource("lighten");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] SCREEN = createCompositeSource("screen");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] COLOR_DODGE = createCompositeSource("color_dodge");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] LINEAR_DODGE = createCompositeSource("linear_dodge");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] LIGHTER_COLOR = createCompositeSource("lighter_color");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] OVERLAY = createCompositeSource("overlay");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] SOFT_LIGHT = createCompositeSource("soft_light");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] HARD_LIGHT = createCompositeSource("hard_light");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] LINEAR_LIGHT = createCompositeSource("linear_light");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] VIVID_LIGHT = createCompositeSource("vivid_light");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] PIN_LIGHT = createCompositeSource("pin_light");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] HARD_MIX = createCompositeSource("hard_mix");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] DIFFERENCE = createCompositeSource("difference");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] EXCLUSION = createCompositeSource("exclusion");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] HUE = createCompositeSource("hue");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] SATURATION = createCompositeSource("saturation");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] COLOR = createCompositeSource("color");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] LUMINOSITY = createCompositeSource("luminosity");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] STENCIL_ALPHA = createCompositeSource("stencil_alpha");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] STENCIL_LUMA = createCompositeSource("stencil_luma");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] SILHOUETTE_ALPHA = createCompositeSource("silhouette_alpha");
 
-	@ShaderSource(attach="ch.kuramo.javie.core.shaders.BlendModeShaders.blend_functions")
+	@ShaderSource(attach=BlendModeShaders.BLEND_FUNCTIONS)
 	public static final String[] SILHOUETTE_LUMA = createCompositeSource("silhouette_luma");
 
 }
