@@ -96,6 +96,10 @@ public class Mosaic {
 	private IVideoBuffer doSharpColorsMosaic(int hBlocks, int vBlocks) {
 		IVideoBuffer input = context.doPreviousEffect();
 		VideoBounds bounds = input.getBounds();
+		if (bounds.isEmpty()) {
+			return input;
+		}
+
 		final int w = bounds.width;
 		final int h = bounds.height;
 
@@ -164,6 +168,12 @@ public class Mosaic {
 		IVideoBuffer buffer = null;
 		try {
 			VideoBounds bounds = input.getBounds();
+			if (bounds.isEmpty()) {
+				IVideoBuffer output = input;
+				input = null;
+				return output;
+			}
+
 			int w = bounds.width;
 			int h = bounds.height;
 
