@@ -69,9 +69,7 @@ public class LinearWipe {
 		if (completion == 0) {
 			return null;
 		} else if (completion == 1) {
-			// TODO context.doPreviousEffect()をしなくてもVideoBoundsを取得できる方法が必要。
-			//      context.getPreviousBounds()をここで呼ぶとIllegalStateExceptionが発生する。
-			IVideoBuffer vb = context.doPreviousEffect();
+			IVideoBuffer vb = context.createVideoBuffer(context.getPreviousBounds());
 			VideoEffectUtil.clearTexture(vb, context.getGL().getGL2());
 			return vb;
 		}
@@ -80,7 +78,7 @@ public class LinearWipe {
 		if (wipeAngle < 0) wipeAngle += 360;
 
 		double feather = context.value(this.feather);
-		feather = context.getRenderResolution().scale(feather);
+		feather = context.getVideoResolution().scale(feather);
 
 
 		IVideoBuffer input = context.doPreviousEffect();
