@@ -28,7 +28,7 @@ import javax.media.opengl.glu.GLU;
 
 import ch.kuramo.javie.api.IAnimatableInteger;
 import ch.kuramo.javie.api.IVideoBuffer;
-import ch.kuramo.javie.api.RenderResolution;
+import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.annotations.Effect;
 import ch.kuramo.javie.api.annotations.Property;
@@ -61,7 +61,7 @@ public class ChangeBounds {
 	}
 
 	public VideoBounds getVideoBounds() {
-		RenderResolution resolution = context.getRenderResolution();
+		Resolution resolution = context.getVideoResolution();
 		int left = (int) resolution.scale(context.value(this.left));
 		int top = (int) resolution.scale(context.value(this.top));
 		int right = (int) resolution.scale(context.value(this.right));
@@ -77,7 +77,7 @@ public class ChangeBounds {
 	}
 
 	public IVideoBuffer doVideoEffect() {
-		RenderResolution resolution = context.getRenderResolution();
+		Resolution resolution = context.getVideoResolution();
 		int left = (int) resolution.scale(context.value(this.left));
 		int top = (int) resolution.scale(context.value(this.top));
 		int right = (int) resolution.scale(context.value(this.right));
